#define _CFFI_

/* We try to define Py_LIMITED_API before including Python.h.

   Mess: we can only define it if Py_DEBUG, Py_TRACE_REFS and
   Py_REF_DEBUG are not defined.  This is a best-effort approximation:
   we can learn about Py_DEBUG from pyconfig.h, but it is unclear if
   the same works for the other two macros.  Py_DEBUG implies them,
   but not the other way around.

   The implementation is messy (issue #350): on Windows, with _MSC_VER,
   we have to define Py_LIMITED_API even before including pyconfig.h.
   In that case, we guess what pyconfig.h will do to the macros above,
   and check our guess after the #include.

   Note that on Windows, with CPython 3.x, you need >= 3.5 and virtualenv
   version >= 16.0.0.  With older versions of either, you don't get a
   copy of PYTHON3.DLL in the virtualenv.  We can't check the version of
   CPython *before* we even include pyconfig.h.  ffi.set_source() puts
   a ``#define _CFFI_NO_LIMITED_API'' at the start of this file if it is
   running on Windows < 3.5, as an attempt at fixing it, but that's
   arguably wrong because it may not be the target version of Python.
   Still better than nothing I guess.  As another workaround, you can
   remove the definition of Py_LIMITED_API here.

   See also 'py_limited_api' in cffi/setuptools_ext.py.
*/
#if !defined(_CFFI_USE_EMBEDDING) && !defined(Py_LIMITED_API)
#  ifdef _MSC_VER
#    if !defined(_DEBUG) && !defined(Py_DEBUG) && !defined(Py_TRACE_REFS) && !defined(Py_REF_DEBUG) && !defined(_CFFI_NO_LIMITED_API)
#      define Py_LIMITED_API
#    endif
#    include <pyconfig.h>
     /* sanity-check: Py_LIMITED_API will cause crashes if any of these
        are also defined.  Normally, the Python file PC/pyconfig.h does not
        cause any of these to be defined, with the exception that _DEBUG
        causes Py_DEBUG.  Double-check that. */
#    ifdef Py_LIMITED_API
#      if defined(Py_DEBUG)
#        error "pyconfig.h unexpectedly defines Py_DEBUG, but Py_LIMITED_API is set"
#      endif
#      if defined(Py_TRACE_REFS)
#        error "pyconfig.h unexpectedly defines Py_TRACE_REFS, but Py_LIMITED_API is set"
#      endif
#      if defined(Py_REF_DEBUG)
#        error "pyconfig.h unexpectedly defines Py_REF_DEBUG, but Py_LIMITED_API is set"
#      endif
#    endif
#  else
#    include <pyconfig.h>
#    if !defined(Py_DEBUG) && !defined(Py_TRACE_REFS) && !defined(Py_REF_DEBUG) && !defined(_CFFI_NO_LIMITED_API)
#      define Py_LIMITED_API
#    endif
#  endif
#endif

#include <Python.h>
#ifdef __cplusplus
extern "C" {
#endif
#include <stddef.h>

/* This part is from file 'cffi/parse_c_type.h'.  It is copied at the
   beginning of C sources generated by CFFI's ffi.set_source(). */

typedef void *_cffi_opcode_t;

#define _CFFI_OP(opcode, arg)   (_cffi_opcode_t)(opcode | (((uintptr_t)(arg)) << 8))
#define _CFFI_GETOP(cffi_opcode)    ((unsigned char)(uintptr_t)cffi_opcode)
#define _CFFI_GETARG(cffi_opcode)   (((intptr_t)cffi_opcode) >> 8)

#define _CFFI_OP_PRIMITIVE       1
#define _CFFI_OP_POINTER         3
#define _CFFI_OP_ARRAY           5
#define _CFFI_OP_OPEN_ARRAY      7
#define _CFFI_OP_STRUCT_UNION    9
#define _CFFI_OP_ENUM           11
#define _CFFI_OP_FUNCTION       13
#define _CFFI_OP_FUNCTION_END   15
#define _CFFI_OP_NOOP           17
#define _CFFI_OP_BITFIELD       19
#define _CFFI_OP_TYPENAME       21
#define _CFFI_OP_CPYTHON_BLTN_V 23   // varargs
#define _CFFI_OP_CPYTHON_BLTN_N 25   // noargs
#define _CFFI_OP_CPYTHON_BLTN_O 27   // O  (i.e. a single arg)
#define _CFFI_OP_CONSTANT       29
#define _CFFI_OP_CONSTANT_INT   31
#define _CFFI_OP_GLOBAL_VAR     33
#define _CFFI_OP_DLOPEN_FUNC    35
#define _CFFI_OP_DLOPEN_CONST   37
#define _CFFI_OP_GLOBAL_VAR_F   39
#define _CFFI_OP_EXTERN_PYTHON  41

#define _CFFI_PRIM_VOID          0
#define _CFFI_PRIM_BOOL          1
#define _CFFI_PRIM_CHAR          2
#define _CFFI_PRIM_SCHAR         3
#define _CFFI_PRIM_UCHAR         4
#define _CFFI_PRIM_SHORT         5
#define _CFFI_PRIM_USHORT        6
#define _CFFI_PRIM_INT           7
#define _CFFI_PRIM_UINT          8
#define _CFFI_PRIM_LONG          9
#define _CFFI_PRIM_ULONG        10
#define _CFFI_PRIM_LONGLONG     11
#define _CFFI_PRIM_ULONGLONG    12
#define _CFFI_PRIM_FLOAT        13
#define _CFFI_PRIM_DOUBLE       14
#define _CFFI_PRIM_LONGDOUBLE   15

#define _CFFI_PRIM_WCHAR        16
#define _CFFI_PRIM_INT8         17
#define _CFFI_PRIM_UINT8        18
#define _CFFI_PRIM_INT16        19
#define _CFFI_PRIM_UINT16       20
#define _CFFI_PRIM_INT32        21
#define _CFFI_PRIM_UINT32       22
#define _CFFI_PRIM_INT64        23
#define _CFFI_PRIM_UINT64       24
#define _CFFI_PRIM_INTPTR       25
#define _CFFI_PRIM_UINTPTR      26
#define _CFFI_PRIM_PTRDIFF      27
#define _CFFI_PRIM_SIZE         28
#define _CFFI_PRIM_SSIZE        29
#define _CFFI_PRIM_INT_LEAST8   30
#define _CFFI_PRIM_UINT_LEAST8  31
#define _CFFI_PRIM_INT_LEAST16  32
#define _CFFI_PRIM_UINT_LEAST16 33
#define _CFFI_PRIM_INT_LEAST32  34
#define _CFFI_PRIM_UINT_LEAST32 35
#define _CFFI_PRIM_INT_LEAST64  36
#define _CFFI_PRIM_UINT_LEAST64 37
#define _CFFI_PRIM_INT_FAST8    38
#define _CFFI_PRIM_UINT_FAST8   39
#define _CFFI_PRIM_INT_FAST16   40
#define _CFFI_PRIM_UINT_FAST16  41
#define _CFFI_PRIM_INT_FAST32   42
#define _CFFI_PRIM_UINT_FAST32  43
#define _CFFI_PRIM_INT_FAST64   44
#define _CFFI_PRIM_UINT_FAST64  45
#define _CFFI_PRIM_INTMAX       46
#define _CFFI_PRIM_UINTMAX      47
#define _CFFI_PRIM_FLOATCOMPLEX 48
#define _CFFI_PRIM_DOUBLECOMPLEX 49
#define _CFFI_PRIM_CHAR16       50
#define _CFFI_PRIM_CHAR32       51

#define _CFFI__NUM_PRIM         52
#define _CFFI__UNKNOWN_PRIM           (-1)
#define _CFFI__UNKNOWN_FLOAT_PRIM     (-2)
#define _CFFI__UNKNOWN_LONG_DOUBLE    (-3)

#define _CFFI__IO_FILE_STRUCT         (-1)


struct _cffi_global_s {
    const char *name;
    void *address;
    _cffi_opcode_t type_op;
    void *size_or_direct_fn;  // OP_GLOBAL_VAR: size, or 0 if unknown
                              // OP_CPYTHON_BLTN_*: addr of direct function
};

struct _cffi_getconst_s {
    unsigned long long value;
    const struct _cffi_type_context_s *ctx;
    int gindex;
};

struct _cffi_struct_union_s {
    const char *name;
    int type_index;          // -> _cffi_types, on a OP_STRUCT_UNION
    int flags;               // _CFFI_F_* flags below
    size_t size;
    int alignment;
    int first_field_index;   // -> _cffi_fields array
    int num_fields;
};
#define _CFFI_F_UNION         0x01   // is a union, not a struct
#define _CFFI_F_CHECK_FIELDS  0x02   // complain if fields are not in the
                                     // "standard layout" or if some are missing
#define _CFFI_F_PACKED        0x04   // for CHECK_FIELDS, assume a packed struct
#define _CFFI_F_EXTERNAL      0x08   // in some other ffi.include()
#define _CFFI_F_OPAQUE        0x10   // opaque

struct _cffi_field_s {
    const char *name;
    size_t field_offset;
    size_t field_size;
    _cffi_opcode_t field_type_op;
};

struct _cffi_enum_s {
    const char *name;
    int type_index;          // -> _cffi_types, on a OP_ENUM
    int type_prim;           // _CFFI_PRIM_xxx
    const char *enumerators; // comma-delimited string
};

struct _cffi_typename_s {
    const char *name;
    int type_index;   /* if opaque, points to a possibly artificial
                         OP_STRUCT which is itself opaque */
};

struct _cffi_type_context_s {
    _cffi_opcode_t *types;
    const struct _cffi_global_s *globals;
    const struct _cffi_field_s *fields;
    const struct _cffi_struct_union_s *struct_unions;
    const struct _cffi_enum_s *enums;
    const struct _cffi_typename_s *typenames;
    int num_globals;
    int num_struct_unions;
    int num_enums;
    int num_typenames;
    const char *const *includes;
    int num_types;
    int flags;      /* future extension */
};

struct _cffi_parse_info_s {
    const struct _cffi_type_context_s *ctx;
    _cffi_opcode_t *output;
    unsigned int output_size;
    size_t error_location;
    const char *error_message;
};

struct _cffi_externpy_s {
    const char *name;
    size_t size_of_result;
    void *reserved1, *reserved2;
};

#ifdef _CFFI_INTERNAL
static int parse_c_type(struct _cffi_parse_info_s *info, const char *input);
static int search_in_globals(const struct _cffi_type_context_s *ctx,
                             const char *search, size_t search_len);
static int search_in_struct_unions(const struct _cffi_type_context_s *ctx,
                                   const char *search, size_t search_len);
#endif

/* this block of #ifs should be kept exactly identical between
   c/_cffi_backend.c, cffi/vengine_cpy.py, cffi/vengine_gen.py
   and cffi/_cffi_include.h */
#if defined(_MSC_VER)
# include <malloc.h>   /* for alloca() */
# if _MSC_VER < 1600   /* MSVC < 2010 */
   typedef __int8 int8_t;
   typedef __int16 int16_t;
   typedef __int32 int32_t;
   typedef __int64 int64_t;
   typedef unsigned __int8 uint8_t;
   typedef unsigned __int16 uint16_t;
   typedef unsigned __int32 uint32_t;
   typedef unsigned __int64 uint64_t;
   typedef __int8 int_least8_t;
   typedef __int16 int_least16_t;
   typedef __int32 int_least32_t;
   typedef __int64 int_least64_t;
   typedef unsigned __int8 uint_least8_t;
   typedef unsigned __int16 uint_least16_t;
   typedef unsigned __int32 uint_least32_t;
   typedef unsigned __int64 uint_least64_t;
   typedef __int8 int_fast8_t;
   typedef __int16 int_fast16_t;
   typedef __int32 int_fast32_t;
   typedef __int64 int_fast64_t;
   typedef unsigned __int8 uint_fast8_t;
   typedef unsigned __int16 uint_fast16_t;
   typedef unsigned __int32 uint_fast32_t;
   typedef unsigned __int64 uint_fast64_t;
   typedef __int64 intmax_t;
   typedef unsigned __int64 uintmax_t;
# else
#  include <stdint.h>
# endif
# if _MSC_VER < 1800   /* MSVC < 2013 */
#  ifndef __cplusplus
    typedef unsigned char _Bool;
#  endif
# endif
# define _cffi_float_complex_t   _Fcomplex    /* include <complex.h> for it */
# define _cffi_double_complex_t  _Dcomplex    /* include <complex.h> for it */
#else
# include <stdint.h>
# if (defined (__SVR4) && defined (__sun)) || defined(_AIX) || defined(__hpux)
#  include <alloca.h>
# endif
# define _cffi_float_complex_t   float _Complex
# define _cffi_double_complex_t  double _Complex
#endif

#ifdef __GNUC__
# define _CFFI_UNUSED_FN  __attribute__((unused))
#else
# define _CFFI_UNUSED_FN  /* nothing */
#endif

#ifdef __cplusplus
# ifndef _Bool
   typedef bool _Bool;   /* semi-hackish: C++ has no _Bool; bool is builtin */
# endif
#endif

/**********  CPython-specific section  **********/
#ifndef PYPY_VERSION


#if PY_MAJOR_VERSION >= 3
# define PyInt_FromLong PyLong_FromLong
#endif

#define _cffi_from_c_double PyFloat_FromDouble
#define _cffi_from_c_float PyFloat_FromDouble
#define _cffi_from_c_long PyInt_FromLong
#define _cffi_from_c_ulong PyLong_FromUnsignedLong
#define _cffi_from_c_longlong PyLong_FromLongLong
#define _cffi_from_c_ulonglong PyLong_FromUnsignedLongLong
#define _cffi_from_c__Bool PyBool_FromLong

#define _cffi_to_c_double PyFloat_AsDouble
#define _cffi_to_c_float PyFloat_AsDouble

#define _cffi_from_c_int(x, type)                                        \
    (((type)-1) > 0 ? /* unsigned */                                     \
        (sizeof(type) < sizeof(long) ?                                   \
            PyInt_FromLong((long)x) :                                    \
         sizeof(type) == sizeof(long) ?                                  \
            PyLong_FromUnsignedLong((unsigned long)x) :                  \
            PyLong_FromUnsignedLongLong((unsigned long long)x)) :        \
        (sizeof(type) <= sizeof(long) ?                                  \
            PyInt_FromLong((long)x) :                                    \
            PyLong_FromLongLong((long long)x)))

#define _cffi_to_c_int(o, type)                                          \
    ((type)(                                                             \
     sizeof(type) == 1 ? (((type)-1) > 0 ? (type)_cffi_to_c_u8(o)        \
                                         : (type)_cffi_to_c_i8(o)) :     \
     sizeof(type) == 2 ? (((type)-1) > 0 ? (type)_cffi_to_c_u16(o)       \
                                         : (type)_cffi_to_c_i16(o)) :    \
     sizeof(type) == 4 ? (((type)-1) > 0 ? (type)_cffi_to_c_u32(o)       \
                                         : (type)_cffi_to_c_i32(o)) :    \
     sizeof(type) == 8 ? (((type)-1) > 0 ? (type)_cffi_to_c_u64(o)       \
                                         : (type)_cffi_to_c_i64(o)) :    \
     (Py_FatalError("unsupported size for type " #type), (type)0)))

#define _cffi_to_c_i8                                                    \
                 ((int(*)(PyObject *))_cffi_exports[1])
#define _cffi_to_c_u8                                                    \
                 ((int(*)(PyObject *))_cffi_exports[2])
#define _cffi_to_c_i16                                                   \
                 ((int(*)(PyObject *))_cffi_exports[3])
#define _cffi_to_c_u16                                                   \
                 ((int(*)(PyObject *))_cffi_exports[4])
#define _cffi_to_c_i32                                                   \
                 ((int(*)(PyObject *))_cffi_exports[5])
#define _cffi_to_c_u32                                                   \
                 ((unsigned int(*)(PyObject *))_cffi_exports[6])
#define _cffi_to_c_i64                                                   \
                 ((long long(*)(PyObject *))_cffi_exports[7])
#define _cffi_to_c_u64                                                   \
                 ((unsigned long long(*)(PyObject *))_cffi_exports[8])
#define _cffi_to_c_char                                                  \
                 ((int(*)(PyObject *))_cffi_exports[9])
#define _cffi_from_c_pointer                                             \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[10])
#define _cffi_to_c_pointer                                               \
    ((char *(*)(PyObject *, struct _cffi_ctypedescr *))_cffi_exports[11])
#define _cffi_get_struct_layout                                          \
    not used any more
#define _cffi_restore_errno                                              \
    ((void(*)(void))_cffi_exports[13])
#define _cffi_save_errno                                                 \
    ((void(*)(void))_cffi_exports[14])
#define _cffi_from_c_char                                                \
    ((PyObject *(*)(char))_cffi_exports[15])
#define _cffi_from_c_deref                                               \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[16])
#define _cffi_to_c                                                       \
    ((int(*)(char *, struct _cffi_ctypedescr *, PyObject *))_cffi_exports[17])
#define _cffi_from_c_struct                                              \
    ((PyObject *(*)(char *, struct _cffi_ctypedescr *))_cffi_exports[18])
#define _cffi_to_c_wchar_t                                               \
    ((_cffi_wchar_t(*)(PyObject *))_cffi_exports[19])
#define _cffi_from_c_wchar_t                                             \
    ((PyObject *(*)(_cffi_wchar_t))_cffi_exports[20])
#define _cffi_to_c_long_double                                           \
    ((long double(*)(PyObject *))_cffi_exports[21])
#define _cffi_to_c__Bool                                                 \
    ((_Bool(*)(PyObject *))_cffi_exports[22])
#define _cffi_prepare_pointer_call_argument                              \
    ((Py_ssize_t(*)(struct _cffi_ctypedescr *,                           \
                    PyObject *, char **))_cffi_exports[23])
#define _cffi_convert_array_from_object                                  \
    ((int(*)(char *, struct _cffi_ctypedescr *, PyObject *))_cffi_exports[24])
#define _CFFI_CPIDX  25
#define _cffi_call_python                                                \
    ((void(*)(struct _cffi_externpy_s *, char *))_cffi_exports[_CFFI_CPIDX])
#define _cffi_to_c_wchar3216_t                                           \
    ((int(*)(PyObject *))_cffi_exports[26])
#define _cffi_from_c_wchar3216_t                                         \
    ((PyObject *(*)(int))_cffi_exports[27])
#define _CFFI_NUM_EXPORTS 28

struct _cffi_ctypedescr;

static void *_cffi_exports[_CFFI_NUM_EXPORTS];

#define _cffi_type(index)   (                           \
    assert((((uintptr_t)_cffi_types[index]) & 1) == 0), \
    (struct _cffi_ctypedescr *)_cffi_types[index])

static PyObject *_cffi_init(const char *module_name, Py_ssize_t version,
                            const struct _cffi_type_context_s *ctx)
{
    PyObject *module, *o_arg, *new_module;
    void *raw[] = {
        (void *)module_name,
        (void *)version,
        (void *)_cffi_exports,
        (void *)ctx,
    };

    module = PyImport_ImportModule("_cffi_backend");
    if (module == NULL)
        goto failure;

    o_arg = PyLong_FromVoidPtr((void *)raw);
    if (o_arg == NULL)
        goto failure;

    new_module = PyObject_CallMethod(
        module, (char *)"_init_cffi_1_0_external_module", (char *)"O", o_arg);

    Py_DECREF(o_arg);
    Py_DECREF(module);
    return new_module;

  failure:
    Py_XDECREF(module);
    return NULL;
}


#ifdef HAVE_WCHAR_H
typedef wchar_t _cffi_wchar_t;
#else
typedef uint16_t _cffi_wchar_t;   /* same random pick as _cffi_backend.c */
#endif

_CFFI_UNUSED_FN static uint16_t _cffi_to_c_char16_t(PyObject *o)
{
    if (sizeof(_cffi_wchar_t) == 2)
        return (uint16_t)_cffi_to_c_wchar_t(o);
    else
        return (uint16_t)_cffi_to_c_wchar3216_t(o);
}

_CFFI_UNUSED_FN static PyObject *_cffi_from_c_char16_t(uint16_t x)
{
    if (sizeof(_cffi_wchar_t) == 2)
        return _cffi_from_c_wchar_t((_cffi_wchar_t)x);
    else
        return _cffi_from_c_wchar3216_t((int)x);
}

_CFFI_UNUSED_FN static int _cffi_to_c_char32_t(PyObject *o)
{
    if (sizeof(_cffi_wchar_t) == 4)
        return (int)_cffi_to_c_wchar_t(o);
    else
        return (int)_cffi_to_c_wchar3216_t(o);
}

_CFFI_UNUSED_FN static PyObject *_cffi_from_c_char32_t(unsigned int x)
{
    if (sizeof(_cffi_wchar_t) == 4)
        return _cffi_from_c_wchar_t((_cffi_wchar_t)x);
    else
        return _cffi_from_c_wchar3216_t((int)x);
}

union _cffi_union_alignment_u {
    unsigned char m_char;
    unsigned short m_short;
    unsigned int m_int;
    unsigned long m_long;
    unsigned long long m_longlong;
    float m_float;
    double m_double;
    long double m_longdouble;
};

struct _cffi_freeme_s {
    struct _cffi_freeme_s *next;
    union _cffi_union_alignment_u alignment;
};

_CFFI_UNUSED_FN static int
_cffi_convert_array_argument(struct _cffi_ctypedescr *ctptr, PyObject *arg,
                             char **output_data, Py_ssize_t datasize,
                             struct _cffi_freeme_s **freeme)
{
    char *p;
    if (datasize < 0)
        return -1;

    p = *output_data;
    if (p == NULL) {
        struct _cffi_freeme_s *fp = (struct _cffi_freeme_s *)PyObject_Malloc(
            offsetof(struct _cffi_freeme_s, alignment) + (size_t)datasize);
        if (fp == NULL)
            return -1;
        fp->next = *freeme;
        *freeme = fp;
        p = *output_data = (char *)&fp->alignment;
    }
    memset((void *)p, 0, (size_t)datasize);
    return _cffi_convert_array_from_object(p, ctptr, arg);
}

_CFFI_UNUSED_FN static void
_cffi_free_array_arguments(struct _cffi_freeme_s *freeme)
{
    do {
        void *p = (void *)freeme;
        freeme = freeme->next;
        PyObject_Free(p);
    } while (freeme != NULL);
}

/**********  end CPython-specific section  **********/
#else
_CFFI_UNUSED_FN
static void (*_cffi_call_python_org)(struct _cffi_externpy_s *, char *);
# define _cffi_call_python  _cffi_call_python_org
#endif


#define _cffi_array_len(array)   (sizeof(array) / sizeof((array)[0]))

#define _cffi_prim_int(size, sign)                                      \
    ((size) == 1 ? ((sign) ? _CFFI_PRIM_INT8  : _CFFI_PRIM_UINT8)  :    \
     (size) == 2 ? ((sign) ? _CFFI_PRIM_INT16 : _CFFI_PRIM_UINT16) :    \
     (size) == 4 ? ((sign) ? _CFFI_PRIM_INT32 : _CFFI_PRIM_UINT32) :    \
     (size) == 8 ? ((sign) ? _CFFI_PRIM_INT64 : _CFFI_PRIM_UINT64) :    \
     _CFFI__UNKNOWN_PRIM)

#define _cffi_prim_float(size)                                          \
    ((size) == sizeof(float) ? _CFFI_PRIM_FLOAT :                       \
     (size) == sizeof(double) ? _CFFI_PRIM_DOUBLE :                     \
     (size) == sizeof(long double) ? _CFFI__UNKNOWN_LONG_DOUBLE :       \
     _CFFI__UNKNOWN_FLOAT_PRIM)

#define _cffi_check_int(got, got_nonpos, expected)      \
    ((got_nonpos) == (expected <= 0) &&                 \
     (got) == (unsigned long long)expected)

#ifdef MS_WIN32
# define _cffi_stdcall  __stdcall
#else
# define _cffi_stdcall  /* nothing */
#endif

#ifdef __cplusplus
}
#endif

/************************************************************/

#include <libcpuid.h>

/************************************************************/

static void *_cffi_types[] = {
/*  0 */ _CFFI_OP(_CFFI_OP_FUNCTION, 5), // char *()(cpu_affinity_mask_t *)
/*  1 */ _CFFI_OP(_CFFI_OP_POINTER, 143), // cpu_affinity_mask_t *
/*  2 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/*  3 */ _CFFI_OP(_CFFI_OP_FUNCTION, 5), // char *()(cpu_affinity_mask_t *, char *, unsigned int)
/*  4 */ _CFFI_OP(_CFFI_OP_NOOP, 1),
/*  5 */ _CFFI_OP(_CFFI_OP_POINTER, 138), // char *
/*  6 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8), // unsigned int
/*  7 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/*  8 */ _CFFI_OP(_CFFI_OP_FUNCTION, 45), // char const *()(cpu_architecture_t)
/*  9 */ _CFFI_OP(_CFFI_OP_ENUM, 0), // cpu_architecture_t
/* 10 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 11 */ _CFFI_OP(_CFFI_OP_FUNCTION, 45), // char const *()(cpu_feature_level_t)
/* 12 */ _CFFI_OP(_CFFI_OP_ENUM, 2), // cpu_feature_level_t
/* 13 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 14 */ _CFFI_OP(_CFFI_OP_FUNCTION, 45), // char const *()(cpu_feature_t)
/* 15 */ _CFFI_OP(_CFFI_OP_ENUM, 3), // cpu_feature_t
/* 16 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 17 */ _CFFI_OP(_CFFI_OP_FUNCTION, 45), // char const *()(cpu_purpose_t)
/* 18 */ _CFFI_OP(_CFFI_OP_ENUM, 6), // cpu_purpose_t
/* 19 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 20 */ _CFFI_OP(_CFFI_OP_FUNCTION, 45), // char const *()(void)
/* 21 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 22 */ _CFFI_OP(_CFFI_OP_FUNCTION, 104), // cpu_vendor_t()(void)
/* 23 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 24 */ _CFFI_OP(_CFFI_OP_FUNCTION, 148), // hypervisor_vendor_t()(struct cpu_raw_data_t *, struct cpu_id_t *)
/* 25 */ _CFFI_OP(_CFFI_OP_POINTER, 160), // struct cpu_raw_data_t *
/* 26 */ _CFFI_OP(_CFFI_OP_POINTER, 156), // struct cpu_id_t *
/* 27 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 28 */ _CFFI_OP(_CFFI_OP_FUNCTION, 34), // int()(cpu_purpose_t, struct cpu_raw_data_array_t *, struct cpu_id_t *)
/* 29 */ _CFFI_OP(_CFFI_OP_NOOP, 18),
/* 30 */ _CFFI_OP(_CFFI_OP_POINTER, 159), // struct cpu_raw_data_array_t *
/* 31 */ _CFFI_OP(_CFFI_OP_NOOP, 26),
/* 32 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 33 */ _CFFI_OP(_CFFI_OP_FUNCTION, 34), // int()(int, int)
/* 34 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7), // int
/* 35 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 36 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 37 */ _CFFI_OP(_CFFI_OP_FUNCTION, 34), // int()(struct cpu_mark_t *)
/* 38 */ _CFFI_OP(_CFFI_OP_POINTER, 158), // struct cpu_mark_t *
/* 39 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 40 */ _CFFI_OP(_CFFI_OP_FUNCTION, 34), // int()(struct cpu_raw_data_array_t *)
/* 41 */ _CFFI_OP(_CFFI_OP_NOOP, 30),
/* 42 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 43 */ _CFFI_OP(_CFFI_OP_FUNCTION, 34), // int()(struct cpu_raw_data_array_t *, char const *)
/* 44 */ _CFFI_OP(_CFFI_OP_NOOP, 30),
/* 45 */ _CFFI_OP(_CFFI_OP_POINTER, 138), // char const *
/* 46 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 47 */ _CFFI_OP(_CFFI_OP_FUNCTION, 34), // int()(struct cpu_raw_data_array_t *, struct system_id_t *)
/* 48 */ _CFFI_OP(_CFFI_OP_NOOP, 30),
/* 49 */ _CFFI_OP(_CFFI_OP_POINTER, 163), // struct system_id_t *
/* 50 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 51 */ _CFFI_OP(_CFFI_OP_FUNCTION, 34), // int()(struct cpu_raw_data_t *)
/* 52 */ _CFFI_OP(_CFFI_OP_NOOP, 25),
/* 53 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 54 */ _CFFI_OP(_CFFI_OP_FUNCTION, 34), // int()(struct cpu_raw_data_t *, char const *)
/* 55 */ _CFFI_OP(_CFFI_OP_NOOP, 25),
/* 56 */ _CFFI_OP(_CFFI_OP_NOOP, 45),
/* 57 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 58 */ _CFFI_OP(_CFFI_OP_FUNCTION, 34), // int()(struct cpu_raw_data_t *, struct cpu_id_t *)
/* 59 */ _CFFI_OP(_CFFI_OP_NOOP, 25),
/* 60 */ _CFFI_OP(_CFFI_OP_NOOP, 26),
/* 61 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 62 */ _CFFI_OP(_CFFI_OP_FUNCTION, 34), // int()(struct cpu_raw_data_t *, unsigned short)
/* 63 */ _CFFI_OP(_CFFI_OP_NOOP, 25),
/* 64 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 6), // unsigned short
/* 65 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 66 */ _CFFI_OP(_CFFI_OP_FUNCTION, 34), // int()(struct msr_driver_t *)
/* 67 */ _CFFI_OP(_CFFI_OP_POINTER, 162), // struct msr_driver_t *
/* 68 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 69 */ _CFFI_OP(_CFFI_OP_FUNCTION, 34), // int()(struct msr_driver_t *, char const *)
/* 70 */ _CFFI_OP(_CFFI_OP_NOOP, 67),
/* 71 */ _CFFI_OP(_CFFI_OP_NOOP, 45),
/* 72 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 73 */ _CFFI_OP(_CFFI_OP_FUNCTION, 34), // int()(struct msr_driver_t *, cpu_msrinfo_request_t)
/* 74 */ _CFFI_OP(_CFFI_OP_NOOP, 67),
/* 75 */ _CFFI_OP(_CFFI_OP_ENUM, 5), // cpu_msrinfo_request_t
/* 76 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 77 */ _CFFI_OP(_CFFI_OP_FUNCTION, 34), // int()(struct msr_driver_t *, unsigned int, unsigned char, unsigned char, unsigned long *)
/* 78 */ _CFFI_OP(_CFFI_OP_NOOP, 67),
/* 79 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 80 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4), // unsigned char
/* 81 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 4),
/* 82 */ _CFFI_OP(_CFFI_OP_POINTER, 191), // unsigned long *
/* 83 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 84 */ _CFFI_OP(_CFFI_OP_FUNCTION, 34), // int()(struct msr_driver_t *, unsigned int, unsigned long *)
/* 85 */ _CFFI_OP(_CFFI_OP_NOOP, 67),
/* 86 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 87 */ _CFFI_OP(_CFFI_OP_NOOP, 82),
/* 88 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 89 */ _CFFI_OP(_CFFI_OP_FUNCTION, 34), // int()(void)
/* 90 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 91 */ _CFFI_OP(_CFFI_OP_FUNCTION, 155), // struct cpu_epc_t()(int, struct cpu_raw_data_t const *)
/* 92 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 93 */ _CFFI_OP(_CFFI_OP_POINTER, 160), // struct cpu_raw_data_t const *
/* 94 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 95 */ _CFFI_OP(_CFFI_OP_FUNCTION, 67), // struct msr_driver_t *()(unsigned int)
/* 96 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 97 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 98 */ _CFFI_OP(_CFFI_OP_FUNCTION, 67), // struct msr_driver_t *()(void)
/* 99 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 100 */ _CFFI_OP(_CFFI_OP_FUNCTION, 201), // void()(char const *)
/* 101 */ _CFFI_OP(_CFFI_OP_NOOP, 45),
/* 102 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 103 */ _CFFI_OP(_CFFI_OP_FUNCTION, 201), // void()(cpu_vendor_t, struct cpu_list_t *)
/* 104 */ _CFFI_OP(_CFFI_OP_ENUM, 9), // cpu_vendor_t
/* 105 */ _CFFI_OP(_CFFI_OP_POINTER, 157), // struct cpu_list_t *
/* 106 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 107 */ _CFFI_OP(_CFFI_OP_FUNCTION, 201), // void()(int)
/* 108 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 7),
/* 109 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 110 */ _CFFI_OP(_CFFI_OP_FUNCTION, 201), // void()(struct cpu_list_t *)
/* 111 */ _CFFI_OP(_CFFI_OP_NOOP, 105),
/* 112 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 113 */ _CFFI_OP(_CFFI_OP_FUNCTION, 201), // void()(struct cpu_mark_t *)
/* 114 */ _CFFI_OP(_CFFI_OP_NOOP, 38),
/* 115 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 116 */ _CFFI_OP(_CFFI_OP_FUNCTION, 201), // void()(struct cpu_raw_data_array_t *)
/* 117 */ _CFFI_OP(_CFFI_OP_NOOP, 30),
/* 118 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 119 */ _CFFI_OP(_CFFI_OP_FUNCTION, 201), // void()(struct system_id_t *)
/* 120 */ _CFFI_OP(_CFFI_OP_NOOP, 49),
/* 121 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 122 */ _CFFI_OP(_CFFI_OP_FUNCTION, 201), // void()(unsigned int *)
/* 123 */ _CFFI_OP(_CFFI_OP_POINTER, 6), // unsigned int *
/* 124 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 125 */ _CFFI_OP(_CFFI_OP_FUNCTION, 201), // void()(unsigned int, unsigned int *)
/* 126 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 8),
/* 127 */ _CFFI_OP(_CFFI_OP_NOOP, 123),
/* 128 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 129 */ _CFFI_OP(_CFFI_OP_FUNCTION, 201), // void()(unsigned long *)
/* 130 */ _CFFI_OP(_CFFI_OP_NOOP, 82),
/* 131 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 132 */ _CFFI_OP(_CFFI_OP_FUNCTION, 133), // void(*()(void(*)(char const *)))(char const *)
/* 133 */ _CFFI_OP(_CFFI_OP_POINTER, 100), // void(*)(char const *)
/* 134 */ _CFFI_OP(_CFFI_OP_FUNCTION_END, 0),
/* 135 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 1), // _Bool
/* 136 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 0), // __fsid_t
/* 137 */ _CFFI_OP(_CFFI_OP_POINTER, 5), // char * *
/* 138 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 2), // char
/* 139 */ _CFFI_OP(_CFFI_OP_ARRAY, 138), // char[16]
/* 140 */ (_cffi_opcode_t)(16),
/* 141 */ _CFFI_OP(_CFFI_OP_ARRAY, 138), // char[64]
/* 142 */ (_cffi_opcode_t)(64),
/* 143 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 1), // cpu_affinity_mask_t
/* 144 */ _CFFI_OP(_CFFI_OP_ENUM, 1), // cpu_error_t
/* 145 */ _CFFI_OP(_CFFI_OP_ENUM, 4), // cpu_hint_t
/* 146 */ _CFFI_OP(_CFFI_OP_ENUM, 7), // cpu_registers_t
/* 147 */ _CFFI_OP(_CFFI_OP_ENUM, 8), // cpu_sgx_feature_t
/* 148 */ _CFFI_OP(_CFFI_OP_ENUM, 10), // hypervisor_vendor_t
/* 149 */ _CFFI_OP(_CFFI_OP_ARRAY, 34), // int[2]
/* 150 */ (_cffi_opcode_t)(2),
/* 151 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 9), // long
/* 152 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 5), // short
/* 153 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 3), // signed char
/* 154 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 2), // struct arm_id_t
/* 155 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 3), // struct cpu_epc_t
/* 156 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 4), // struct cpu_id_t
/* 157 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 5), // struct cpu_list_t
/* 158 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 6), // struct cpu_mark_t
/* 159 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 7), // struct cpu_raw_data_array_t
/* 160 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 8), // struct cpu_raw_data_t
/* 161 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 9), // struct cpu_sgx_t
/* 162 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 10), // struct msr_driver_t
/* 163 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 11), // struct system_id_t
/* 164 */ _CFFI_OP(_CFFI_OP_STRUCT_UNION, 12), // struct x86_id_t
/* 165 */ _CFFI_OP(_CFFI_OP_ARRAY, 80), // unsigned char[14]
/* 166 */ (_cffi_opcode_t)(14),
/* 167 */ _CFFI_OP(_CFFI_OP_ARRAY, 80), // unsigned char[16]
/* 168 */ (_cffi_opcode_t)(16),
/* 169 */ _CFFI_OP(_CFFI_OP_ARRAY, 80), // unsigned char[384]
/* 170 */ (_cffi_opcode_t)(384),
/* 171 */ _CFFI_OP(_CFFI_OP_ARRAY, 80), // unsigned char[8192]
/* 172 */ (_cffi_opcode_t)(8192),
/* 173 */ _CFFI_OP(_CFFI_OP_ARRAY, 6), // unsigned int[1]
/* 174 */ (_cffi_opcode_t)(1),
/* 175 */ _CFFI_OP(_CFFI_OP_ARRAY, 6), // unsigned int[2]
/* 176 */ (_cffi_opcode_t)(2),
/* 177 */ _CFFI_OP(_CFFI_OP_ARRAY, 181), // unsigned int[32][4]
/* 178 */ (_cffi_opcode_t)(32),
/* 179 */ _CFFI_OP(_CFFI_OP_ARRAY, 6), // unsigned int[3]
/* 180 */ (_cffi_opcode_t)(3),
/* 181 */ _CFFI_OP(_CFFI_OP_ARRAY, 6), // unsigned int[4]
/* 182 */ (_cffi_opcode_t)(4),
/* 183 */ _CFFI_OP(_CFFI_OP_ARRAY, 181), // unsigned int[4][4]
/* 184 */ (_cffi_opcode_t)(4),
/* 185 */ _CFFI_OP(_CFFI_OP_ARRAY, 6), // unsigned int[6]
/* 186 */ (_cffi_opcode_t)(6),
/* 187 */ _CFFI_OP(_CFFI_OP_ARRAY, 6), // unsigned int[7]
/* 188 */ (_cffi_opcode_t)(7),
/* 189 */ _CFFI_OP(_CFFI_OP_ARRAY, 181), // unsigned int[8][4]
/* 190 */ (_cffi_opcode_t)(8),
/* 191 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 10), // unsigned long
/* 192 */ _CFFI_OP(_CFFI_OP_ARRAY, 191), // unsigned long[1]
/* 193 */ (_cffi_opcode_t)(1),
/* 194 */ _CFFI_OP(_CFFI_OP_ARRAY, 191), // unsigned long[2]
/* 195 */ (_cffi_opcode_t)(2),
/* 196 */ _CFFI_OP(_CFFI_OP_ARRAY, 191), // unsigned long[3]
/* 197 */ (_cffi_opcode_t)(3),
/* 198 */ _CFFI_OP(_CFFI_OP_ARRAY, 191), // unsigned long[5]
/* 199 */ (_cffi_opcode_t)(5),
/* 200 */ _CFFI_OP(_CFFI_OP_POINTER, 201), // void *
/* 201 */ _CFFI_OP(_CFFI_OP_PRIMITIVE, 0), // void
};

_CFFI_UNUSED_FN
static void _cffi_checkfld_typedef___fsid_t(__fsid_t *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { int(*tmp)[2] = &p->__val; (void)tmp; }
}
struct _cffi_align_typedef___fsid_t { char x; __fsid_t y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_typedef_cpu_affinity_mask_t(cpu_affinity_mask_t *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { unsigned char(*tmp)[8192] = &p->__bits; (void)tmp; }
}
struct _cffi_align_typedef_cpu_affinity_mask_t { char x; cpu_affinity_mask_t y; };

static int _cffi_const_ARCHITECTURE_X86(unsigned long long *o)
{
  int n = (ARCHITECTURE_X86) <= 0;
  *o = (unsigned long long)((ARCHITECTURE_X86) | 0);  /* check that ARCHITECTURE_X86 is an integer */
  return n;
}

static int _cffi_const_ARCHITECTURE_ARM(unsigned long long *o)
{
  int n = (ARCHITECTURE_ARM) <= 0;
  *o = (unsigned long long)((ARCHITECTURE_ARM) | 0);  /* check that ARCHITECTURE_ARM is an integer */
  return n;
}

static int _cffi_const_NUM_CPU_ARCHITECTURES(unsigned long long *o)
{
  int n = (NUM_CPU_ARCHITECTURES) <= 0;
  *o = (unsigned long long)((NUM_CPU_ARCHITECTURES) | 0);  /* check that NUM_CPU_ARCHITECTURES is an integer */
  return n;
}

static int _cffi_const_ARCHITECTURE_UNKNOWN(unsigned long long *o)
{
  int n = (ARCHITECTURE_UNKNOWN) <= 0;
  *o = (unsigned long long)((ARCHITECTURE_UNKNOWN) | 0);  /* check that ARCHITECTURE_UNKNOWN is an integer */
  return n;
}

static int _cffi_const_ERR_OK(unsigned long long *o)
{
  int n = (ERR_OK) <= 0;
  *o = (unsigned long long)((ERR_OK) | 0);  /* check that ERR_OK is an integer */
  return n;
}

static int _cffi_const_ERR_NO_CPUID(unsigned long long *o)
{
  int n = (ERR_NO_CPUID) <= 0;
  *o = (unsigned long long)((ERR_NO_CPUID) | 0);  /* check that ERR_NO_CPUID is an integer */
  return n;
}

static int _cffi_const_ERR_NO_RDTSC(unsigned long long *o)
{
  int n = (ERR_NO_RDTSC) <= 0;
  *o = (unsigned long long)((ERR_NO_RDTSC) | 0);  /* check that ERR_NO_RDTSC is an integer */
  return n;
}

static int _cffi_const_ERR_NO_MEM(unsigned long long *o)
{
  int n = (ERR_NO_MEM) <= 0;
  *o = (unsigned long long)((ERR_NO_MEM) | 0);  /* check that ERR_NO_MEM is an integer */
  return n;
}

static int _cffi_const_ERR_OPEN(unsigned long long *o)
{
  int n = (ERR_OPEN) <= 0;
  *o = (unsigned long long)((ERR_OPEN) | 0);  /* check that ERR_OPEN is an integer */
  return n;
}

static int _cffi_const_ERR_BADFMT(unsigned long long *o)
{
  int n = (ERR_BADFMT) <= 0;
  *o = (unsigned long long)((ERR_BADFMT) | 0);  /* check that ERR_BADFMT is an integer */
  return n;
}

static int _cffi_const_ERR_NOT_IMP(unsigned long long *o)
{
  int n = (ERR_NOT_IMP) <= 0;
  *o = (unsigned long long)((ERR_NOT_IMP) | 0);  /* check that ERR_NOT_IMP is an integer */
  return n;
}

static int _cffi_const_ERR_CPU_UNKN(unsigned long long *o)
{
  int n = (ERR_CPU_UNKN) <= 0;
  *o = (unsigned long long)((ERR_CPU_UNKN) | 0);  /* check that ERR_CPU_UNKN is an integer */
  return n;
}

static int _cffi_const_ERR_NO_RDMSR(unsigned long long *o)
{
  int n = (ERR_NO_RDMSR) <= 0;
  *o = (unsigned long long)((ERR_NO_RDMSR) | 0);  /* check that ERR_NO_RDMSR is an integer */
  return n;
}

static int _cffi_const_ERR_NO_DRIVER(unsigned long long *o)
{
  int n = (ERR_NO_DRIVER) <= 0;
  *o = (unsigned long long)((ERR_NO_DRIVER) | 0);  /* check that ERR_NO_DRIVER is an integer */
  return n;
}

static int _cffi_const_ERR_NO_PERMS(unsigned long long *o)
{
  int n = (ERR_NO_PERMS) <= 0;
  *o = (unsigned long long)((ERR_NO_PERMS) | 0);  /* check that ERR_NO_PERMS is an integer */
  return n;
}

static int _cffi_const_ERR_EXTRACT(unsigned long long *o)
{
  int n = (ERR_EXTRACT) <= 0;
  *o = (unsigned long long)((ERR_EXTRACT) | 0);  /* check that ERR_EXTRACT is an integer */
  return n;
}

static int _cffi_const_ERR_HANDLE(unsigned long long *o)
{
  int n = (ERR_HANDLE) <= 0;
  *o = (unsigned long long)((ERR_HANDLE) | 0);  /* check that ERR_HANDLE is an integer */
  return n;
}

static int _cffi_const_ERR_INVMSR(unsigned long long *o)
{
  int n = (ERR_INVMSR) <= 0;
  *o = (unsigned long long)((ERR_INVMSR) | 0);  /* check that ERR_INVMSR is an integer */
  return n;
}

static int _cffi_const_ERR_INVCNB(unsigned long long *o)
{
  int n = (ERR_INVCNB) <= 0;
  *o = (unsigned long long)((ERR_INVCNB) | 0);  /* check that ERR_INVCNB is an integer */
  return n;
}

static int _cffi_const_ERR_HANDLE_R(unsigned long long *o)
{
  int n = (ERR_HANDLE_R) <= 0;
  *o = (unsigned long long)((ERR_HANDLE_R) | 0);  /* check that ERR_HANDLE_R is an integer */
  return n;
}

static int _cffi_const_ERR_INVRANGE(unsigned long long *o)
{
  int n = (ERR_INVRANGE) <= 0;
  *o = (unsigned long long)((ERR_INVRANGE) | 0);  /* check that ERR_INVRANGE is an integer */
  return n;
}

static int _cffi_const_ERR_NOT_FOUND(unsigned long long *o)
{
  int n = (ERR_NOT_FOUND) <= 0;
  *o = (unsigned long long)((ERR_NOT_FOUND) | 0);  /* check that ERR_NOT_FOUND is an integer */
  return n;
}

static int _cffi_const_ERR_IOCTL(unsigned long long *o)
{
  int n = (ERR_IOCTL) <= 0;
  *o = (unsigned long long)((ERR_IOCTL) | 0);  /* check that ERR_IOCTL is an integer */
  return n;
}

static int _cffi_const_ERR_REQUEST(unsigned long long *o)
{
  int n = (ERR_REQUEST) <= 0;
  *o = (unsigned long long)((ERR_REQUEST) | 0);  /* check that ERR_REQUEST is an integer */
  return n;
}

static int _cffi_const_FEATURE_LEVEL_I386(unsigned long long *o)
{
  int n = (FEATURE_LEVEL_I386) <= 0;
  *o = (unsigned long long)((FEATURE_LEVEL_I386) | 0);  /* check that FEATURE_LEVEL_I386 is an integer */
  return n;
}

static int _cffi_const_FEATURE_LEVEL_I486(unsigned long long *o)
{
  int n = (FEATURE_LEVEL_I486) <= 0;
  *o = (unsigned long long)((FEATURE_LEVEL_I486) | 0);  /* check that FEATURE_LEVEL_I486 is an integer */
  return n;
}

static int _cffi_const_FEATURE_LEVEL_I586(unsigned long long *o)
{
  int n = (FEATURE_LEVEL_I586) <= 0;
  *o = (unsigned long long)((FEATURE_LEVEL_I586) | 0);  /* check that FEATURE_LEVEL_I586 is an integer */
  return n;
}

static int _cffi_const_FEATURE_LEVEL_I686(unsigned long long *o)
{
  int n = (FEATURE_LEVEL_I686) <= 0;
  *o = (unsigned long long)((FEATURE_LEVEL_I686) | 0);  /* check that FEATURE_LEVEL_I686 is an integer */
  return n;
}

static int _cffi_const_FEATURE_LEVEL_X86_64_V1(unsigned long long *o)
{
  int n = (FEATURE_LEVEL_X86_64_V1) <= 0;
  *o = (unsigned long long)((FEATURE_LEVEL_X86_64_V1) | 0);  /* check that FEATURE_LEVEL_X86_64_V1 is an integer */
  return n;
}

static int _cffi_const_FEATURE_LEVEL_X86_64_V2(unsigned long long *o)
{
  int n = (FEATURE_LEVEL_X86_64_V2) <= 0;
  *o = (unsigned long long)((FEATURE_LEVEL_X86_64_V2) | 0);  /* check that FEATURE_LEVEL_X86_64_V2 is an integer */
  return n;
}

static int _cffi_const_FEATURE_LEVEL_X86_64_V3(unsigned long long *o)
{
  int n = (FEATURE_LEVEL_X86_64_V3) <= 0;
  *o = (unsigned long long)((FEATURE_LEVEL_X86_64_V3) | 0);  /* check that FEATURE_LEVEL_X86_64_V3 is an integer */
  return n;
}

static int _cffi_const_FEATURE_LEVEL_X86_64_V4(unsigned long long *o)
{
  int n = (FEATURE_LEVEL_X86_64_V4) <= 0;
  *o = (unsigned long long)((FEATURE_LEVEL_X86_64_V4) | 0);  /* check that FEATURE_LEVEL_X86_64_V4 is an integer */
  return n;
}

static int _cffi_const_FEATURE_LEVEL_ARM_V1(unsigned long long *o)
{
  int n = (FEATURE_LEVEL_ARM_V1) <= 0;
  *o = (unsigned long long)((FEATURE_LEVEL_ARM_V1) | 0);  /* check that FEATURE_LEVEL_ARM_V1 is an integer */
  return n;
}

static int _cffi_const_FEATURE_LEVEL_ARM_V2(unsigned long long *o)
{
  int n = (FEATURE_LEVEL_ARM_V2) <= 0;
  *o = (unsigned long long)((FEATURE_LEVEL_ARM_V2) | 0);  /* check that FEATURE_LEVEL_ARM_V2 is an integer */
  return n;
}

static int _cffi_const_FEATURE_LEVEL_ARM_V3(unsigned long long *o)
{
  int n = (FEATURE_LEVEL_ARM_V3) <= 0;
  *o = (unsigned long long)((FEATURE_LEVEL_ARM_V3) | 0);  /* check that FEATURE_LEVEL_ARM_V3 is an integer */
  return n;
}

static int _cffi_const_FEATURE_LEVEL_ARM_V4(unsigned long long *o)
{
  int n = (FEATURE_LEVEL_ARM_V4) <= 0;
  *o = (unsigned long long)((FEATURE_LEVEL_ARM_V4) | 0);  /* check that FEATURE_LEVEL_ARM_V4 is an integer */
  return n;
}

static int _cffi_const_FEATURE_LEVEL_ARM_V4T(unsigned long long *o)
{
  int n = (FEATURE_LEVEL_ARM_V4T) <= 0;
  *o = (unsigned long long)((FEATURE_LEVEL_ARM_V4T) | 0);  /* check that FEATURE_LEVEL_ARM_V4T is an integer */
  return n;
}

static int _cffi_const_FEATURE_LEVEL_ARM_V5(unsigned long long *o)
{
  int n = (FEATURE_LEVEL_ARM_V5) <= 0;
  *o = (unsigned long long)((FEATURE_LEVEL_ARM_V5) | 0);  /* check that FEATURE_LEVEL_ARM_V5 is an integer */
  return n;
}

static int _cffi_const_FEATURE_LEVEL_ARM_V5T(unsigned long long *o)
{
  int n = (FEATURE_LEVEL_ARM_V5T) <= 0;
  *o = (unsigned long long)((FEATURE_LEVEL_ARM_V5T) | 0);  /* check that FEATURE_LEVEL_ARM_V5T is an integer */
  return n;
}

static int _cffi_const_FEATURE_LEVEL_ARM_V5TE(unsigned long long *o)
{
  int n = (FEATURE_LEVEL_ARM_V5TE) <= 0;
  *o = (unsigned long long)((FEATURE_LEVEL_ARM_V5TE) | 0);  /* check that FEATURE_LEVEL_ARM_V5TE is an integer */
  return n;
}

static int _cffi_const_FEATURE_LEVEL_ARM_V5TEJ(unsigned long long *o)
{
  int n = (FEATURE_LEVEL_ARM_V5TEJ) <= 0;
  *o = (unsigned long long)((FEATURE_LEVEL_ARM_V5TEJ) | 0);  /* check that FEATURE_LEVEL_ARM_V5TEJ is an integer */
  return n;
}

static int _cffi_const_FEATURE_LEVEL_ARM_V6(unsigned long long *o)
{
  int n = (FEATURE_LEVEL_ARM_V6) <= 0;
  *o = (unsigned long long)((FEATURE_LEVEL_ARM_V6) | 0);  /* check that FEATURE_LEVEL_ARM_V6 is an integer */
  return n;
}

static int _cffi_const_FEATURE_LEVEL_ARM_V6_M(unsigned long long *o)
{
  int n = (FEATURE_LEVEL_ARM_V6_M) <= 0;
  *o = (unsigned long long)((FEATURE_LEVEL_ARM_V6_M) | 0);  /* check that FEATURE_LEVEL_ARM_V6_M is an integer */
  return n;
}

static int _cffi_const_FEATURE_LEVEL_ARM_V7_A(unsigned long long *o)
{
  int n = (FEATURE_LEVEL_ARM_V7_A) <= 0;
  *o = (unsigned long long)((FEATURE_LEVEL_ARM_V7_A) | 0);  /* check that FEATURE_LEVEL_ARM_V7_A is an integer */
  return n;
}

static int _cffi_const_FEATURE_LEVEL_ARM_V7_M(unsigned long long *o)
{
  int n = (FEATURE_LEVEL_ARM_V7_M) <= 0;
  *o = (unsigned long long)((FEATURE_LEVEL_ARM_V7_M) | 0);  /* check that FEATURE_LEVEL_ARM_V7_M is an integer */
  return n;
}

static int _cffi_const_FEATURE_LEVEL_ARM_V7_R(unsigned long long *o)
{
  int n = (FEATURE_LEVEL_ARM_V7_R) <= 0;
  *o = (unsigned long long)((FEATURE_LEVEL_ARM_V7_R) | 0);  /* check that FEATURE_LEVEL_ARM_V7_R is an integer */
  return n;
}

static int _cffi_const_FEATURE_LEVEL_ARM_V7E_M(unsigned long long *o)
{
  int n = (FEATURE_LEVEL_ARM_V7E_M) <= 0;
  *o = (unsigned long long)((FEATURE_LEVEL_ARM_V7E_M) | 0);  /* check that FEATURE_LEVEL_ARM_V7E_M is an integer */
  return n;
}

static int _cffi_const_FEATURE_LEVEL_ARM_V8_0_A(unsigned long long *o)
{
  int n = (FEATURE_LEVEL_ARM_V8_0_A) <= 0;
  *o = (unsigned long long)((FEATURE_LEVEL_ARM_V8_0_A) | 0);  /* check that FEATURE_LEVEL_ARM_V8_0_A is an integer */
  return n;
}

static int _cffi_const_FEATURE_LEVEL_ARM_V8_0_M(unsigned long long *o)
{
  int n = (FEATURE_LEVEL_ARM_V8_0_M) <= 0;
  *o = (unsigned long long)((FEATURE_LEVEL_ARM_V8_0_M) | 0);  /* check that FEATURE_LEVEL_ARM_V8_0_M is an integer */
  return n;
}

static int _cffi_const_FEATURE_LEVEL_ARM_V8_0_R(unsigned long long *o)
{
  int n = (FEATURE_LEVEL_ARM_V8_0_R) <= 0;
  *o = (unsigned long long)((FEATURE_LEVEL_ARM_V8_0_R) | 0);  /* check that FEATURE_LEVEL_ARM_V8_0_R is an integer */
  return n;
}

static int _cffi_const_FEATURE_LEVEL_ARM_V8_1_A(unsigned long long *o)
{
  int n = (FEATURE_LEVEL_ARM_V8_1_A) <= 0;
  *o = (unsigned long long)((FEATURE_LEVEL_ARM_V8_1_A) | 0);  /* check that FEATURE_LEVEL_ARM_V8_1_A is an integer */
  return n;
}

static int _cffi_const_FEATURE_LEVEL_ARM_V8_1_M(unsigned long long *o)
{
  int n = (FEATURE_LEVEL_ARM_V8_1_M) <= 0;
  *o = (unsigned long long)((FEATURE_LEVEL_ARM_V8_1_M) | 0);  /* check that FEATURE_LEVEL_ARM_V8_1_M is an integer */
  return n;
}

static int _cffi_const_FEATURE_LEVEL_ARM_V8_2_A(unsigned long long *o)
{
  int n = (FEATURE_LEVEL_ARM_V8_2_A) <= 0;
  *o = (unsigned long long)((FEATURE_LEVEL_ARM_V8_2_A) | 0);  /* check that FEATURE_LEVEL_ARM_V8_2_A is an integer */
  return n;
}

static int _cffi_const_FEATURE_LEVEL_ARM_V8_3_A(unsigned long long *o)
{
  int n = (FEATURE_LEVEL_ARM_V8_3_A) <= 0;
  *o = (unsigned long long)((FEATURE_LEVEL_ARM_V8_3_A) | 0);  /* check that FEATURE_LEVEL_ARM_V8_3_A is an integer */
  return n;
}

static int _cffi_const_FEATURE_LEVEL_ARM_V8_4_A(unsigned long long *o)
{
  int n = (FEATURE_LEVEL_ARM_V8_4_A) <= 0;
  *o = (unsigned long long)((FEATURE_LEVEL_ARM_V8_4_A) | 0);  /* check that FEATURE_LEVEL_ARM_V8_4_A is an integer */
  return n;
}

static int _cffi_const_FEATURE_LEVEL_ARM_V8_5_A(unsigned long long *o)
{
  int n = (FEATURE_LEVEL_ARM_V8_5_A) <= 0;
  *o = (unsigned long long)((FEATURE_LEVEL_ARM_V8_5_A) | 0);  /* check that FEATURE_LEVEL_ARM_V8_5_A is an integer */
  return n;
}

static int _cffi_const_FEATURE_LEVEL_ARM_V8_6_A(unsigned long long *o)
{
  int n = (FEATURE_LEVEL_ARM_V8_6_A) <= 0;
  *o = (unsigned long long)((FEATURE_LEVEL_ARM_V8_6_A) | 0);  /* check that FEATURE_LEVEL_ARM_V8_6_A is an integer */
  return n;
}

static int _cffi_const_FEATURE_LEVEL_ARM_V8_7_A(unsigned long long *o)
{
  int n = (FEATURE_LEVEL_ARM_V8_7_A) <= 0;
  *o = (unsigned long long)((FEATURE_LEVEL_ARM_V8_7_A) | 0);  /* check that FEATURE_LEVEL_ARM_V8_7_A is an integer */
  return n;
}

static int _cffi_const_FEATURE_LEVEL_ARM_V8_8_A(unsigned long long *o)
{
  int n = (FEATURE_LEVEL_ARM_V8_8_A) <= 0;
  *o = (unsigned long long)((FEATURE_LEVEL_ARM_V8_8_A) | 0);  /* check that FEATURE_LEVEL_ARM_V8_8_A is an integer */
  return n;
}

static int _cffi_const_FEATURE_LEVEL_ARM_V8_9_A(unsigned long long *o)
{
  int n = (FEATURE_LEVEL_ARM_V8_9_A) <= 0;
  *o = (unsigned long long)((FEATURE_LEVEL_ARM_V8_9_A) | 0);  /* check that FEATURE_LEVEL_ARM_V8_9_A is an integer */
  return n;
}

static int _cffi_const_FEATURE_LEVEL_ARM_V9_0_A(unsigned long long *o)
{
  int n = (FEATURE_LEVEL_ARM_V9_0_A) <= 0;
  *o = (unsigned long long)((FEATURE_LEVEL_ARM_V9_0_A) | 0);  /* check that FEATURE_LEVEL_ARM_V9_0_A is an integer */
  return n;
}

static int _cffi_const_FEATURE_LEVEL_ARM_V9_1_A(unsigned long long *o)
{
  int n = (FEATURE_LEVEL_ARM_V9_1_A) <= 0;
  *o = (unsigned long long)((FEATURE_LEVEL_ARM_V9_1_A) | 0);  /* check that FEATURE_LEVEL_ARM_V9_1_A is an integer */
  return n;
}

static int _cffi_const_FEATURE_LEVEL_ARM_V9_2_A(unsigned long long *o)
{
  int n = (FEATURE_LEVEL_ARM_V9_2_A) <= 0;
  *o = (unsigned long long)((FEATURE_LEVEL_ARM_V9_2_A) | 0);  /* check that FEATURE_LEVEL_ARM_V9_2_A is an integer */
  return n;
}

static int _cffi_const_FEATURE_LEVEL_ARM_V9_3_A(unsigned long long *o)
{
  int n = (FEATURE_LEVEL_ARM_V9_3_A) <= 0;
  *o = (unsigned long long)((FEATURE_LEVEL_ARM_V9_3_A) | 0);  /* check that FEATURE_LEVEL_ARM_V9_3_A is an integer */
  return n;
}

static int _cffi_const_FEATURE_LEVEL_ARM_V9_4_A(unsigned long long *o)
{
  int n = (FEATURE_LEVEL_ARM_V9_4_A) <= 0;
  *o = (unsigned long long)((FEATURE_LEVEL_ARM_V9_4_A) | 0);  /* check that FEATURE_LEVEL_ARM_V9_4_A is an integer */
  return n;
}

static int _cffi_const_NUM_FEATURE_LEVELS(unsigned long long *o)
{
  int n = (NUM_FEATURE_LEVELS) <= 0;
  *o = (unsigned long long)((NUM_FEATURE_LEVELS) | 0);  /* check that NUM_FEATURE_LEVELS is an integer */
  return n;
}

static int _cffi_const_FEATURE_LEVEL_UNKNOWN(unsigned long long *o)
{
  int n = (FEATURE_LEVEL_UNKNOWN) <= 0;
  *o = (unsigned long long)((FEATURE_LEVEL_UNKNOWN) | 0);  /* check that FEATURE_LEVEL_UNKNOWN is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_FPU(unsigned long long *o)
{
  int n = (CPU_FEATURE_FPU) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_FPU) | 0);  /* check that CPU_FEATURE_FPU is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_VME(unsigned long long *o)
{
  int n = (CPU_FEATURE_VME) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_VME) | 0);  /* check that CPU_FEATURE_VME is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_DE(unsigned long long *o)
{
  int n = (CPU_FEATURE_DE) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_DE) | 0);  /* check that CPU_FEATURE_DE is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_PSE(unsigned long long *o)
{
  int n = (CPU_FEATURE_PSE) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_PSE) | 0);  /* check that CPU_FEATURE_PSE is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_TSC(unsigned long long *o)
{
  int n = (CPU_FEATURE_TSC) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_TSC) | 0);  /* check that CPU_FEATURE_TSC is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_MSR(unsigned long long *o)
{
  int n = (CPU_FEATURE_MSR) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_MSR) | 0);  /* check that CPU_FEATURE_MSR is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_PAE(unsigned long long *o)
{
  int n = (CPU_FEATURE_PAE) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_PAE) | 0);  /* check that CPU_FEATURE_PAE is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_MCE(unsigned long long *o)
{
  int n = (CPU_FEATURE_MCE) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_MCE) | 0);  /* check that CPU_FEATURE_MCE is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_CX8(unsigned long long *o)
{
  int n = (CPU_FEATURE_CX8) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_CX8) | 0);  /* check that CPU_FEATURE_CX8 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_APIC(unsigned long long *o)
{
  int n = (CPU_FEATURE_APIC) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_APIC) | 0);  /* check that CPU_FEATURE_APIC is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_MTRR(unsigned long long *o)
{
  int n = (CPU_FEATURE_MTRR) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_MTRR) | 0);  /* check that CPU_FEATURE_MTRR is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SEP(unsigned long long *o)
{
  int n = (CPU_FEATURE_SEP) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SEP) | 0);  /* check that CPU_FEATURE_SEP is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_PGE(unsigned long long *o)
{
  int n = (CPU_FEATURE_PGE) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_PGE) | 0);  /* check that CPU_FEATURE_PGE is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_MCA(unsigned long long *o)
{
  int n = (CPU_FEATURE_MCA) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_MCA) | 0);  /* check that CPU_FEATURE_MCA is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_CMOV(unsigned long long *o)
{
  int n = (CPU_FEATURE_CMOV) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_CMOV) | 0);  /* check that CPU_FEATURE_CMOV is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_PAT(unsigned long long *o)
{
  int n = (CPU_FEATURE_PAT) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_PAT) | 0);  /* check that CPU_FEATURE_PAT is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_PSE36(unsigned long long *o)
{
  int n = (CPU_FEATURE_PSE36) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_PSE36) | 0);  /* check that CPU_FEATURE_PSE36 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_PN(unsigned long long *o)
{
  int n = (CPU_FEATURE_PN) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_PN) | 0);  /* check that CPU_FEATURE_PN is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_CLFLUSH(unsigned long long *o)
{
  int n = (CPU_FEATURE_CLFLUSH) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_CLFLUSH) | 0);  /* check that CPU_FEATURE_CLFLUSH is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_DTS(unsigned long long *o)
{
  int n = (CPU_FEATURE_DTS) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_DTS) | 0);  /* check that CPU_FEATURE_DTS is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_ACPI(unsigned long long *o)
{
  int n = (CPU_FEATURE_ACPI) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_ACPI) | 0);  /* check that CPU_FEATURE_ACPI is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_MMX(unsigned long long *o)
{
  int n = (CPU_FEATURE_MMX) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_MMX) | 0);  /* check that CPU_FEATURE_MMX is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_FXSR(unsigned long long *o)
{
  int n = (CPU_FEATURE_FXSR) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_FXSR) | 0);  /* check that CPU_FEATURE_FXSR is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SSE(unsigned long long *o)
{
  int n = (CPU_FEATURE_SSE) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SSE) | 0);  /* check that CPU_FEATURE_SSE is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SSE2(unsigned long long *o)
{
  int n = (CPU_FEATURE_SSE2) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SSE2) | 0);  /* check that CPU_FEATURE_SSE2 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SS(unsigned long long *o)
{
  int n = (CPU_FEATURE_SS) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SS) | 0);  /* check that CPU_FEATURE_SS is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_HT(unsigned long long *o)
{
  int n = (CPU_FEATURE_HT) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_HT) | 0);  /* check that CPU_FEATURE_HT is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_TM(unsigned long long *o)
{
  int n = (CPU_FEATURE_TM) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_TM) | 0);  /* check that CPU_FEATURE_TM is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_IA64(unsigned long long *o)
{
  int n = (CPU_FEATURE_IA64) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_IA64) | 0);  /* check that CPU_FEATURE_IA64 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_PBE(unsigned long long *o)
{
  int n = (CPU_FEATURE_PBE) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_PBE) | 0);  /* check that CPU_FEATURE_PBE is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_PNI(unsigned long long *o)
{
  int n = (CPU_FEATURE_PNI) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_PNI) | 0);  /* check that CPU_FEATURE_PNI is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_PCLMUL(unsigned long long *o)
{
  int n = (CPU_FEATURE_PCLMUL) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_PCLMUL) | 0);  /* check that CPU_FEATURE_PCLMUL is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_DTS64(unsigned long long *o)
{
  int n = (CPU_FEATURE_DTS64) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_DTS64) | 0);  /* check that CPU_FEATURE_DTS64 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_MONITOR(unsigned long long *o)
{
  int n = (CPU_FEATURE_MONITOR) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_MONITOR) | 0);  /* check that CPU_FEATURE_MONITOR is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_DS_CPL(unsigned long long *o)
{
  int n = (CPU_FEATURE_DS_CPL) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_DS_CPL) | 0);  /* check that CPU_FEATURE_DS_CPL is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_VMX(unsigned long long *o)
{
  int n = (CPU_FEATURE_VMX) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_VMX) | 0);  /* check that CPU_FEATURE_VMX is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SMX(unsigned long long *o)
{
  int n = (CPU_FEATURE_SMX) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SMX) | 0);  /* check that CPU_FEATURE_SMX is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_EST(unsigned long long *o)
{
  int n = (CPU_FEATURE_EST) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_EST) | 0);  /* check that CPU_FEATURE_EST is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_TM2(unsigned long long *o)
{
  int n = (CPU_FEATURE_TM2) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_TM2) | 0);  /* check that CPU_FEATURE_TM2 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SSSE3(unsigned long long *o)
{
  int n = (CPU_FEATURE_SSSE3) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SSSE3) | 0);  /* check that CPU_FEATURE_SSSE3 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_CID(unsigned long long *o)
{
  int n = (CPU_FEATURE_CID) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_CID) | 0);  /* check that CPU_FEATURE_CID is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_CX16(unsigned long long *o)
{
  int n = (CPU_FEATURE_CX16) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_CX16) | 0);  /* check that CPU_FEATURE_CX16 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_XTPR(unsigned long long *o)
{
  int n = (CPU_FEATURE_XTPR) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_XTPR) | 0);  /* check that CPU_FEATURE_XTPR is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_PDCM(unsigned long long *o)
{
  int n = (CPU_FEATURE_PDCM) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_PDCM) | 0);  /* check that CPU_FEATURE_PDCM is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_DCA(unsigned long long *o)
{
  int n = (CPU_FEATURE_DCA) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_DCA) | 0);  /* check that CPU_FEATURE_DCA is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SSE4_1(unsigned long long *o)
{
  int n = (CPU_FEATURE_SSE4_1) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SSE4_1) | 0);  /* check that CPU_FEATURE_SSE4_1 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SSE4_2(unsigned long long *o)
{
  int n = (CPU_FEATURE_SSE4_2) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SSE4_2) | 0);  /* check that CPU_FEATURE_SSE4_2 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SYSCALL(unsigned long long *o)
{
  int n = (CPU_FEATURE_SYSCALL) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SYSCALL) | 0);  /* check that CPU_FEATURE_SYSCALL is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_XD(unsigned long long *o)
{
  int n = (CPU_FEATURE_XD) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_XD) | 0);  /* check that CPU_FEATURE_XD is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_MOVBE(unsigned long long *o)
{
  int n = (CPU_FEATURE_MOVBE) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_MOVBE) | 0);  /* check that CPU_FEATURE_MOVBE is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_POPCNT(unsigned long long *o)
{
  int n = (CPU_FEATURE_POPCNT) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_POPCNT) | 0);  /* check that CPU_FEATURE_POPCNT is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_AES(unsigned long long *o)
{
  int n = (CPU_FEATURE_AES) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_AES) | 0);  /* check that CPU_FEATURE_AES is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_XSAVE(unsigned long long *o)
{
  int n = (CPU_FEATURE_XSAVE) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_XSAVE) | 0);  /* check that CPU_FEATURE_XSAVE is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_OSXSAVE(unsigned long long *o)
{
  int n = (CPU_FEATURE_OSXSAVE) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_OSXSAVE) | 0);  /* check that CPU_FEATURE_OSXSAVE is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_AVX(unsigned long long *o)
{
  int n = (CPU_FEATURE_AVX) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_AVX) | 0);  /* check that CPU_FEATURE_AVX is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_MMXEXT(unsigned long long *o)
{
  int n = (CPU_FEATURE_MMXEXT) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_MMXEXT) | 0);  /* check that CPU_FEATURE_MMXEXT is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_3DNOW(unsigned long long *o)
{
  int n = (CPU_FEATURE_3DNOW) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_3DNOW) | 0);  /* check that CPU_FEATURE_3DNOW is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_3DNOWEXT(unsigned long long *o)
{
  int n = (CPU_FEATURE_3DNOWEXT) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_3DNOWEXT) | 0);  /* check that CPU_FEATURE_3DNOWEXT is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_NX(unsigned long long *o)
{
  int n = (CPU_FEATURE_NX) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_NX) | 0);  /* check that CPU_FEATURE_NX is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_FXSR_OPT(unsigned long long *o)
{
  int n = (CPU_FEATURE_FXSR_OPT) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_FXSR_OPT) | 0);  /* check that CPU_FEATURE_FXSR_OPT is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_RDTSCP(unsigned long long *o)
{
  int n = (CPU_FEATURE_RDTSCP) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_RDTSCP) | 0);  /* check that CPU_FEATURE_RDTSCP is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_LM(unsigned long long *o)
{
  int n = (CPU_FEATURE_LM) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_LM) | 0);  /* check that CPU_FEATURE_LM is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_LAHF_LM(unsigned long long *o)
{
  int n = (CPU_FEATURE_LAHF_LM) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_LAHF_LM) | 0);  /* check that CPU_FEATURE_LAHF_LM is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_CMP_LEGACY(unsigned long long *o)
{
  int n = (CPU_FEATURE_CMP_LEGACY) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_CMP_LEGACY) | 0);  /* check that CPU_FEATURE_CMP_LEGACY is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SVM(unsigned long long *o)
{
  int n = (CPU_FEATURE_SVM) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SVM) | 0);  /* check that CPU_FEATURE_SVM is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_ABM(unsigned long long *o)
{
  int n = (CPU_FEATURE_ABM) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_ABM) | 0);  /* check that CPU_FEATURE_ABM is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_MISALIGNSSE(unsigned long long *o)
{
  int n = (CPU_FEATURE_MISALIGNSSE) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_MISALIGNSSE) | 0);  /* check that CPU_FEATURE_MISALIGNSSE is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SSE4A(unsigned long long *o)
{
  int n = (CPU_FEATURE_SSE4A) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SSE4A) | 0);  /* check that CPU_FEATURE_SSE4A is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_3DNOWPREFETCH(unsigned long long *o)
{
  int n = (CPU_FEATURE_3DNOWPREFETCH) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_3DNOWPREFETCH) | 0);  /* check that CPU_FEATURE_3DNOWPREFETCH is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_OSVW(unsigned long long *o)
{
  int n = (CPU_FEATURE_OSVW) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_OSVW) | 0);  /* check that CPU_FEATURE_OSVW is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_IBS(unsigned long long *o)
{
  int n = (CPU_FEATURE_IBS) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_IBS) | 0);  /* check that CPU_FEATURE_IBS is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SSE5(unsigned long long *o)
{
  int n = (CPU_FEATURE_SSE5) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SSE5) | 0);  /* check that CPU_FEATURE_SSE5 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SKINIT(unsigned long long *o)
{
  int n = (CPU_FEATURE_SKINIT) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SKINIT) | 0);  /* check that CPU_FEATURE_SKINIT is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_WDT(unsigned long long *o)
{
  int n = (CPU_FEATURE_WDT) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_WDT) | 0);  /* check that CPU_FEATURE_WDT is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_TS(unsigned long long *o)
{
  int n = (CPU_FEATURE_TS) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_TS) | 0);  /* check that CPU_FEATURE_TS is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_FID(unsigned long long *o)
{
  int n = (CPU_FEATURE_FID) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_FID) | 0);  /* check that CPU_FEATURE_FID is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_VID(unsigned long long *o)
{
  int n = (CPU_FEATURE_VID) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_VID) | 0);  /* check that CPU_FEATURE_VID is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_TTP(unsigned long long *o)
{
  int n = (CPU_FEATURE_TTP) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_TTP) | 0);  /* check that CPU_FEATURE_TTP is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_TM_AMD(unsigned long long *o)
{
  int n = (CPU_FEATURE_TM_AMD) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_TM_AMD) | 0);  /* check that CPU_FEATURE_TM_AMD is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_STC(unsigned long long *o)
{
  int n = (CPU_FEATURE_STC) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_STC) | 0);  /* check that CPU_FEATURE_STC is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_100MHZSTEPS(unsigned long long *o)
{
  int n = (CPU_FEATURE_100MHZSTEPS) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_100MHZSTEPS) | 0);  /* check that CPU_FEATURE_100MHZSTEPS is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_HWPSTATE(unsigned long long *o)
{
  int n = (CPU_FEATURE_HWPSTATE) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_HWPSTATE) | 0);  /* check that CPU_FEATURE_HWPSTATE is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_CONSTANT_TSC(unsigned long long *o)
{
  int n = (CPU_FEATURE_CONSTANT_TSC) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_CONSTANT_TSC) | 0);  /* check that CPU_FEATURE_CONSTANT_TSC is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_XOP(unsigned long long *o)
{
  int n = (CPU_FEATURE_XOP) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_XOP) | 0);  /* check that CPU_FEATURE_XOP is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_FMA3(unsigned long long *o)
{
  int n = (CPU_FEATURE_FMA3) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_FMA3) | 0);  /* check that CPU_FEATURE_FMA3 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_FMA4(unsigned long long *o)
{
  int n = (CPU_FEATURE_FMA4) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_FMA4) | 0);  /* check that CPU_FEATURE_FMA4 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_TBM(unsigned long long *o)
{
  int n = (CPU_FEATURE_TBM) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_TBM) | 0);  /* check that CPU_FEATURE_TBM is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_F16C(unsigned long long *o)
{
  int n = (CPU_FEATURE_F16C) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_F16C) | 0);  /* check that CPU_FEATURE_F16C is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_RDRAND(unsigned long long *o)
{
  int n = (CPU_FEATURE_RDRAND) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_RDRAND) | 0);  /* check that CPU_FEATURE_RDRAND is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_X2APIC(unsigned long long *o)
{
  int n = (CPU_FEATURE_X2APIC) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_X2APIC) | 0);  /* check that CPU_FEATURE_X2APIC is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_CPB(unsigned long long *o)
{
  int n = (CPU_FEATURE_CPB) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_CPB) | 0);  /* check that CPU_FEATURE_CPB is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_APERFMPERF(unsigned long long *o)
{
  int n = (CPU_FEATURE_APERFMPERF) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_APERFMPERF) | 0);  /* check that CPU_FEATURE_APERFMPERF is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_PFI(unsigned long long *o)
{
  int n = (CPU_FEATURE_PFI) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_PFI) | 0);  /* check that CPU_FEATURE_PFI is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_PA(unsigned long long *o)
{
  int n = (CPU_FEATURE_PA) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_PA) | 0);  /* check that CPU_FEATURE_PA is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_AVX2(unsigned long long *o)
{
  int n = (CPU_FEATURE_AVX2) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_AVX2) | 0);  /* check that CPU_FEATURE_AVX2 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_BMI1(unsigned long long *o)
{
  int n = (CPU_FEATURE_BMI1) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_BMI1) | 0);  /* check that CPU_FEATURE_BMI1 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_BMI2(unsigned long long *o)
{
  int n = (CPU_FEATURE_BMI2) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_BMI2) | 0);  /* check that CPU_FEATURE_BMI2 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_HLE(unsigned long long *o)
{
  int n = (CPU_FEATURE_HLE) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_HLE) | 0);  /* check that CPU_FEATURE_HLE is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_RTM(unsigned long long *o)
{
  int n = (CPU_FEATURE_RTM) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_RTM) | 0);  /* check that CPU_FEATURE_RTM is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_AVX512F(unsigned long long *o)
{
  int n = (CPU_FEATURE_AVX512F) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_AVX512F) | 0);  /* check that CPU_FEATURE_AVX512F is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_AVX512DQ(unsigned long long *o)
{
  int n = (CPU_FEATURE_AVX512DQ) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_AVX512DQ) | 0);  /* check that CPU_FEATURE_AVX512DQ is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_AVX512PF(unsigned long long *o)
{
  int n = (CPU_FEATURE_AVX512PF) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_AVX512PF) | 0);  /* check that CPU_FEATURE_AVX512PF is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_AVX512ER(unsigned long long *o)
{
  int n = (CPU_FEATURE_AVX512ER) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_AVX512ER) | 0);  /* check that CPU_FEATURE_AVX512ER is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_AVX512CD(unsigned long long *o)
{
  int n = (CPU_FEATURE_AVX512CD) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_AVX512CD) | 0);  /* check that CPU_FEATURE_AVX512CD is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SHA_NI(unsigned long long *o)
{
  int n = (CPU_FEATURE_SHA_NI) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SHA_NI) | 0);  /* check that CPU_FEATURE_SHA_NI is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_AVX512BW(unsigned long long *o)
{
  int n = (CPU_FEATURE_AVX512BW) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_AVX512BW) | 0);  /* check that CPU_FEATURE_AVX512BW is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_AVX512VL(unsigned long long *o)
{
  int n = (CPU_FEATURE_AVX512VL) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_AVX512VL) | 0);  /* check that CPU_FEATURE_AVX512VL is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SGX(unsigned long long *o)
{
  int n = (CPU_FEATURE_SGX) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SGX) | 0);  /* check that CPU_FEATURE_SGX is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_RDSEED(unsigned long long *o)
{
  int n = (CPU_FEATURE_RDSEED) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_RDSEED) | 0);  /* check that CPU_FEATURE_RDSEED is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_ADX(unsigned long long *o)
{
  int n = (CPU_FEATURE_ADX) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_ADX) | 0);  /* check that CPU_FEATURE_ADX is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_AVX512VNNI(unsigned long long *o)
{
  int n = (CPU_FEATURE_AVX512VNNI) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_AVX512VNNI) | 0);  /* check that CPU_FEATURE_AVX512VNNI is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_AVX512VBMI(unsigned long long *o)
{
  int n = (CPU_FEATURE_AVX512VBMI) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_AVX512VBMI) | 0);  /* check that CPU_FEATURE_AVX512VBMI is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_AVX512VBMI2(unsigned long long *o)
{
  int n = (CPU_FEATURE_AVX512VBMI2) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_AVX512VBMI2) | 0);  /* check that CPU_FEATURE_AVX512VBMI2 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_HYPERVISOR(unsigned long long *o)
{
  int n = (CPU_FEATURE_HYPERVISOR) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_HYPERVISOR) | 0);  /* check that CPU_FEATURE_HYPERVISOR is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SWAP(unsigned long long *o)
{
  int n = (CPU_FEATURE_SWAP) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SWAP) | 0);  /* check that CPU_FEATURE_SWAP is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_THUMB(unsigned long long *o)
{
  int n = (CPU_FEATURE_THUMB) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_THUMB) | 0);  /* check that CPU_FEATURE_THUMB is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_ADVMULTU(unsigned long long *o)
{
  int n = (CPU_FEATURE_ADVMULTU) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_ADVMULTU) | 0);  /* check that CPU_FEATURE_ADVMULTU is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_ADVMULTS(unsigned long long *o)
{
  int n = (CPU_FEATURE_ADVMULTS) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_ADVMULTS) | 0);  /* check that CPU_FEATURE_ADVMULTS is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_JAZELLE(unsigned long long *o)
{
  int n = (CPU_FEATURE_JAZELLE) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_JAZELLE) | 0);  /* check that CPU_FEATURE_JAZELLE is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_DEBUGV6(unsigned long long *o)
{
  int n = (CPU_FEATURE_DEBUGV6) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_DEBUGV6) | 0);  /* check that CPU_FEATURE_DEBUGV6 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_DEBUGV6P1(unsigned long long *o)
{
  int n = (CPU_FEATURE_DEBUGV6P1) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_DEBUGV6P1) | 0);  /* check that CPU_FEATURE_DEBUGV6P1 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_THUMB2(unsigned long long *o)
{
  int n = (CPU_FEATURE_THUMB2) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_THUMB2) | 0);  /* check that CPU_FEATURE_THUMB2 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_DEBUGV7(unsigned long long *o)
{
  int n = (CPU_FEATURE_DEBUGV7) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_DEBUGV7) | 0);  /* check that CPU_FEATURE_DEBUGV7 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_DEBUGV7P1(unsigned long long *o)
{
  int n = (CPU_FEATURE_DEBUGV7P1) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_DEBUGV7P1) | 0);  /* check that CPU_FEATURE_DEBUGV7P1 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_THUMBEE(unsigned long long *o)
{
  int n = (CPU_FEATURE_THUMBEE) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_THUMBEE) | 0);  /* check that CPU_FEATURE_THUMBEE is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_DIVIDE(unsigned long long *o)
{
  int n = (CPU_FEATURE_DIVIDE) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_DIVIDE) | 0);  /* check that CPU_FEATURE_DIVIDE is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_LPAE(unsigned long long *o)
{
  int n = (CPU_FEATURE_LPAE) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_LPAE) | 0);  /* check that CPU_FEATURE_LPAE is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_PMUV1(unsigned long long *o)
{
  int n = (CPU_FEATURE_PMUV1) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_PMUV1) | 0);  /* check that CPU_FEATURE_PMUV1 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_PMUV2(unsigned long long *o)
{
  int n = (CPU_FEATURE_PMUV2) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_PMUV2) | 0);  /* check that CPU_FEATURE_PMUV2 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_ASID16(unsigned long long *o)
{
  int n = (CPU_FEATURE_ASID16) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_ASID16) | 0);  /* check that CPU_FEATURE_ASID16 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_ADVSIMD(unsigned long long *o)
{
  int n = (CPU_FEATURE_ADVSIMD) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_ADVSIMD) | 0);  /* check that CPU_FEATURE_ADVSIMD is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_CRC32(unsigned long long *o)
{
  int n = (CPU_FEATURE_CRC32) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_CRC32) | 0);  /* check that CPU_FEATURE_CRC32 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_CSV2_1P1(unsigned long long *o)
{
  int n = (CPU_FEATURE_CSV2_1P1) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_CSV2_1P1) | 0);  /* check that CPU_FEATURE_CSV2_1P1 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_CSV2_1P2(unsigned long long *o)
{
  int n = (CPU_FEATURE_CSV2_1P2) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_CSV2_1P2) | 0);  /* check that CPU_FEATURE_CSV2_1P2 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_CSV2_2(unsigned long long *o)
{
  int n = (CPU_FEATURE_CSV2_2) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_CSV2_2) | 0);  /* check that CPU_FEATURE_CSV2_2 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_CSV2_3(unsigned long long *o)
{
  int n = (CPU_FEATURE_CSV2_3) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_CSV2_3) | 0);  /* check that CPU_FEATURE_CSV2_3 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_DOUBLELOCK(unsigned long long *o)
{
  int n = (CPU_FEATURE_DOUBLELOCK) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_DOUBLELOCK) | 0);  /* check that CPU_FEATURE_DOUBLELOCK is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_ETS2(unsigned long long *o)
{
  int n = (CPU_FEATURE_ETS2) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_ETS2) | 0);  /* check that CPU_FEATURE_ETS2 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_FP(unsigned long long *o)
{
  int n = (CPU_FEATURE_FP) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_FP) | 0);  /* check that CPU_FEATURE_FP is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_MIXEDEND(unsigned long long *o)
{
  int n = (CPU_FEATURE_MIXEDEND) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_MIXEDEND) | 0);  /* check that CPU_FEATURE_MIXEDEND is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_MIXEDENDEL0(unsigned long long *o)
{
  int n = (CPU_FEATURE_MIXEDENDEL0) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_MIXEDENDEL0) | 0);  /* check that CPU_FEATURE_MIXEDENDEL0 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_PMULL(unsigned long long *o)
{
  int n = (CPU_FEATURE_PMULL) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_PMULL) | 0);  /* check that CPU_FEATURE_PMULL is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_PMUV3(unsigned long long *o)
{
  int n = (CPU_FEATURE_PMUV3) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_PMUV3) | 0);  /* check that CPU_FEATURE_PMUV3 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SHA1(unsigned long long *o)
{
  int n = (CPU_FEATURE_SHA1) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SHA1) | 0);  /* check that CPU_FEATURE_SHA1 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SHA256(unsigned long long *o)
{
  int n = (CPU_FEATURE_SHA256) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SHA256) | 0);  /* check that CPU_FEATURE_SHA256 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_NTLBPA(unsigned long long *o)
{
  int n = (CPU_FEATURE_NTLBPA) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_NTLBPA) | 0);  /* check that CPU_FEATURE_NTLBPA is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_HAFDBS(unsigned long long *o)
{
  int n = (CPU_FEATURE_HAFDBS) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_HAFDBS) | 0);  /* check that CPU_FEATURE_HAFDBS is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_HPDS(unsigned long long *o)
{
  int n = (CPU_FEATURE_HPDS) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_HPDS) | 0);  /* check that CPU_FEATURE_HPDS is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_LOR(unsigned long long *o)
{
  int n = (CPU_FEATURE_LOR) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_LOR) | 0);  /* check that CPU_FEATURE_LOR is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_LSE(unsigned long long *o)
{
  int n = (CPU_FEATURE_LSE) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_LSE) | 0);  /* check that CPU_FEATURE_LSE is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_PAN(unsigned long long *o)
{
  int n = (CPU_FEATURE_PAN) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_PAN) | 0);  /* check that CPU_FEATURE_PAN is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_PMUV3P1(unsigned long long *o)
{
  int n = (CPU_FEATURE_PMUV3P1) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_PMUV3P1) | 0);  /* check that CPU_FEATURE_PMUV3P1 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_RDM(unsigned long long *o)
{
  int n = (CPU_FEATURE_RDM) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_RDM) | 0);  /* check that CPU_FEATURE_RDM is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_VHE(unsigned long long *o)
{
  int n = (CPU_FEATURE_VHE) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_VHE) | 0);  /* check that CPU_FEATURE_VHE is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_VMID16(unsigned long long *o)
{
  int n = (CPU_FEATURE_VMID16) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_VMID16) | 0);  /* check that CPU_FEATURE_VMID16 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_AA32HPD(unsigned long long *o)
{
  int n = (CPU_FEATURE_AA32HPD) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_AA32HPD) | 0);  /* check that CPU_FEATURE_AA32HPD is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_AA32I8MM(unsigned long long *o)
{
  int n = (CPU_FEATURE_AA32I8MM) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_AA32I8MM) | 0);  /* check that CPU_FEATURE_AA32I8MM is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_DPB(unsigned long long *o)
{
  int n = (CPU_FEATURE_DPB) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_DPB) | 0);  /* check that CPU_FEATURE_DPB is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_DEBUGV8P2(unsigned long long *o)
{
  int n = (CPU_FEATURE_DEBUGV8P2) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_DEBUGV8P2) | 0);  /* check that CPU_FEATURE_DEBUGV8P2 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_F32MM(unsigned long long *o)
{
  int n = (CPU_FEATURE_F32MM) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_F32MM) | 0);  /* check that CPU_FEATURE_F32MM is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_F64MM(unsigned long long *o)
{
  int n = (CPU_FEATURE_F64MM) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_F64MM) | 0);  /* check that CPU_FEATURE_F64MM is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_FP16(unsigned long long *o)
{
  int n = (CPU_FEATURE_FP16) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_FP16) | 0);  /* check that CPU_FEATURE_FP16 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_HPDS2(unsigned long long *o)
{
  int n = (CPU_FEATURE_HPDS2) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_HPDS2) | 0);  /* check that CPU_FEATURE_HPDS2 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_I8MM(unsigned long long *o)
{
  int n = (CPU_FEATURE_I8MM) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_I8MM) | 0);  /* check that CPU_FEATURE_I8MM is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_IESB(unsigned long long *o)
{
  int n = (CPU_FEATURE_IESB) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_IESB) | 0);  /* check that CPU_FEATURE_IESB is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_LPA(unsigned long long *o)
{
  int n = (CPU_FEATURE_LPA) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_LPA) | 0);  /* check that CPU_FEATURE_LPA is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_LSMAOC(unsigned long long *o)
{
  int n = (CPU_FEATURE_LSMAOC) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_LSMAOC) | 0);  /* check that CPU_FEATURE_LSMAOC is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_LVA(unsigned long long *o)
{
  int n = (CPU_FEATURE_LVA) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_LVA) | 0);  /* check that CPU_FEATURE_LVA is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_PAN2(unsigned long long *o)
{
  int n = (CPU_FEATURE_PAN2) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_PAN2) | 0);  /* check that CPU_FEATURE_PAN2 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_RAS(unsigned long long *o)
{
  int n = (CPU_FEATURE_RAS) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_RAS) | 0);  /* check that CPU_FEATURE_RAS is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SHA3(unsigned long long *o)
{
  int n = (CPU_FEATURE_SHA3) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SHA3) | 0);  /* check that CPU_FEATURE_SHA3 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SHA512(unsigned long long *o)
{
  int n = (CPU_FEATURE_SHA512) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SHA512) | 0);  /* check that CPU_FEATURE_SHA512 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SM3(unsigned long long *o)
{
  int n = (CPU_FEATURE_SM3) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SM3) | 0);  /* check that CPU_FEATURE_SM3 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SM4(unsigned long long *o)
{
  int n = (CPU_FEATURE_SM4) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SM4) | 0);  /* check that CPU_FEATURE_SM4 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SPE(unsigned long long *o)
{
  int n = (CPU_FEATURE_SPE) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SPE) | 0);  /* check that CPU_FEATURE_SPE is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SVE(unsigned long long *o)
{
  int n = (CPU_FEATURE_SVE) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SVE) | 0);  /* check that CPU_FEATURE_SVE is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_TTCNP(unsigned long long *o)
{
  int n = (CPU_FEATURE_TTCNP) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_TTCNP) | 0);  /* check that CPU_FEATURE_TTCNP is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_UAO(unsigned long long *o)
{
  int n = (CPU_FEATURE_UAO) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_UAO) | 0);  /* check that CPU_FEATURE_UAO is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_XNX(unsigned long long *o)
{
  int n = (CPU_FEATURE_XNX) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_XNX) | 0);  /* check that CPU_FEATURE_XNX is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_CCIDX(unsigned long long *o)
{
  int n = (CPU_FEATURE_CCIDX) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_CCIDX) | 0);  /* check that CPU_FEATURE_CCIDX is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_CONSTPACFIELD(unsigned long long *o)
{
  int n = (CPU_FEATURE_CONSTPACFIELD) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_CONSTPACFIELD) | 0);  /* check that CPU_FEATURE_CONSTPACFIELD is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_EPAC(unsigned long long *o)
{
  int n = (CPU_FEATURE_EPAC) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_EPAC) | 0);  /* check that CPU_FEATURE_EPAC is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_FCMA(unsigned long long *o)
{
  int n = (CPU_FEATURE_FCMA) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_FCMA) | 0);  /* check that CPU_FEATURE_FCMA is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_FPAC(unsigned long long *o)
{
  int n = (CPU_FEATURE_FPAC) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_FPAC) | 0);  /* check that CPU_FEATURE_FPAC is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_FPACCOMBINE(unsigned long long *o)
{
  int n = (CPU_FEATURE_FPACCOMBINE) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_FPACCOMBINE) | 0);  /* check that CPU_FEATURE_FPACCOMBINE is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_JSCVT(unsigned long long *o)
{
  int n = (CPU_FEATURE_JSCVT) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_JSCVT) | 0);  /* check that CPU_FEATURE_JSCVT is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_LRCPC(unsigned long long *o)
{
  int n = (CPU_FEATURE_LRCPC) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_LRCPC) | 0);  /* check that CPU_FEATURE_LRCPC is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_PACIMP(unsigned long long *o)
{
  int n = (CPU_FEATURE_PACIMP) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_PACIMP) | 0);  /* check that CPU_FEATURE_PACIMP is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_PACQARMA3(unsigned long long *o)
{
  int n = (CPU_FEATURE_PACQARMA3) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_PACQARMA3) | 0);  /* check that CPU_FEATURE_PACQARMA3 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_PACQARMA5(unsigned long long *o)
{
  int n = (CPU_FEATURE_PACQARMA5) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_PACQARMA5) | 0);  /* check that CPU_FEATURE_PACQARMA5 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_PAUTH(unsigned long long *o)
{
  int n = (CPU_FEATURE_PAUTH) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_PAUTH) | 0);  /* check that CPU_FEATURE_PAUTH is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SPEV1P1(unsigned long long *o)
{
  int n = (CPU_FEATURE_SPEV1P1) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SPEV1P1) | 0);  /* check that CPU_FEATURE_SPEV1P1 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_AMUV1(unsigned long long *o)
{
  int n = (CPU_FEATURE_AMUV1) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_AMUV1) | 0);  /* check that CPU_FEATURE_AMUV1 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_BBM(unsigned long long *o)
{
  int n = (CPU_FEATURE_BBM) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_BBM) | 0);  /* check that CPU_FEATURE_BBM is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_DIT(unsigned long long *o)
{
  int n = (CPU_FEATURE_DIT) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_DIT) | 0);  /* check that CPU_FEATURE_DIT is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_DEBUGV8P4(unsigned long long *o)
{
  int n = (CPU_FEATURE_DEBUGV8P4) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_DEBUGV8P4) | 0);  /* check that CPU_FEATURE_DEBUGV8P4 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_DOTPROD(unsigned long long *o)
{
  int n = (CPU_FEATURE_DOTPROD) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_DOTPROD) | 0);  /* check that CPU_FEATURE_DOTPROD is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_DOUBLEFAULT(unsigned long long *o)
{
  int n = (CPU_FEATURE_DOUBLEFAULT) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_DOUBLEFAULT) | 0);  /* check that CPU_FEATURE_DOUBLEFAULT is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_FHM(unsigned long long *o)
{
  int n = (CPU_FEATURE_FHM) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_FHM) | 0);  /* check that CPU_FEATURE_FHM is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_FLAGM(unsigned long long *o)
{
  int n = (CPU_FEATURE_FLAGM) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_FLAGM) | 0);  /* check that CPU_FEATURE_FLAGM is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_IDST(unsigned long long *o)
{
  int n = (CPU_FEATURE_IDST) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_IDST) | 0);  /* check that CPU_FEATURE_IDST is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_LRCPC2(unsigned long long *o)
{
  int n = (CPU_FEATURE_LRCPC2) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_LRCPC2) | 0);  /* check that CPU_FEATURE_LRCPC2 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_LSE2(unsigned long long *o)
{
  int n = (CPU_FEATURE_LSE2) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_LSE2) | 0);  /* check that CPU_FEATURE_LSE2 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_MPAM(unsigned long long *o)
{
  int n = (CPU_FEATURE_MPAM) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_MPAM) | 0);  /* check that CPU_FEATURE_MPAM is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_PMUV3P4(unsigned long long *o)
{
  int n = (CPU_FEATURE_PMUV3P4) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_PMUV3P4) | 0);  /* check that CPU_FEATURE_PMUV3P4 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_RASV1P1(unsigned long long *o)
{
  int n = (CPU_FEATURE_RASV1P1) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_RASV1P1) | 0);  /* check that CPU_FEATURE_RASV1P1 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_S2FWB(unsigned long long *o)
{
  int n = (CPU_FEATURE_S2FWB) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_S2FWB) | 0);  /* check that CPU_FEATURE_S2FWB is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SEL2(unsigned long long *o)
{
  int n = (CPU_FEATURE_SEL2) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SEL2) | 0);  /* check that CPU_FEATURE_SEL2 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_TLBIOS(unsigned long long *o)
{
  int n = (CPU_FEATURE_TLBIOS) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_TLBIOS) | 0);  /* check that CPU_FEATURE_TLBIOS is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_TLBIRANGE(unsigned long long *o)
{
  int n = (CPU_FEATURE_TLBIRANGE) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_TLBIRANGE) | 0);  /* check that CPU_FEATURE_TLBIRANGE is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_TRF(unsigned long long *o)
{
  int n = (CPU_FEATURE_TRF) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_TRF) | 0);  /* check that CPU_FEATURE_TRF is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_TTL(unsigned long long *o)
{
  int n = (CPU_FEATURE_TTL) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_TTL) | 0);  /* check that CPU_FEATURE_TTL is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_TTST(unsigned long long *o)
{
  int n = (CPU_FEATURE_TTST) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_TTST) | 0);  /* check that CPU_FEATURE_TTST is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_BTI(unsigned long long *o)
{
  int n = (CPU_FEATURE_BTI) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_BTI) | 0);  /* check that CPU_FEATURE_BTI is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_CSV2(unsigned long long *o)
{
  int n = (CPU_FEATURE_CSV2) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_CSV2) | 0);  /* check that CPU_FEATURE_CSV2 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_CSV3(unsigned long long *o)
{
  int n = (CPU_FEATURE_CSV3) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_CSV3) | 0);  /* check that CPU_FEATURE_CSV3 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_DPB2(unsigned long long *o)
{
  int n = (CPU_FEATURE_DPB2) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_DPB2) | 0);  /* check that CPU_FEATURE_DPB2 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_E0PD(unsigned long long *o)
{
  int n = (CPU_FEATURE_E0PD) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_E0PD) | 0);  /* check that CPU_FEATURE_E0PD is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_EVT(unsigned long long *o)
{
  int n = (CPU_FEATURE_EVT) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_EVT) | 0);  /* check that CPU_FEATURE_EVT is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_EXS(unsigned long long *o)
{
  int n = (CPU_FEATURE_EXS) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_EXS) | 0);  /* check that CPU_FEATURE_EXS is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_FRINTTS(unsigned long long *o)
{
  int n = (CPU_FEATURE_FRINTTS) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_FRINTTS) | 0);  /* check that CPU_FEATURE_FRINTTS is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_FLAGM2(unsigned long long *o)
{
  int n = (CPU_FEATURE_FLAGM2) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_FLAGM2) | 0);  /* check that CPU_FEATURE_FLAGM2 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_MTE(unsigned long long *o)
{
  int n = (CPU_FEATURE_MTE) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_MTE) | 0);  /* check that CPU_FEATURE_MTE is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_MTE2(unsigned long long *o)
{
  int n = (CPU_FEATURE_MTE2) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_MTE2) | 0);  /* check that CPU_FEATURE_MTE2 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_PMUV3P5(unsigned long long *o)
{
  int n = (CPU_FEATURE_PMUV3P5) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_PMUV3P5) | 0);  /* check that CPU_FEATURE_PMUV3P5 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_RNG(unsigned long long *o)
{
  int n = (CPU_FEATURE_RNG) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_RNG) | 0);  /* check that CPU_FEATURE_RNG is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_RNG_TRAP(unsigned long long *o)
{
  int n = (CPU_FEATURE_RNG_TRAP) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_RNG_TRAP) | 0);  /* check that CPU_FEATURE_RNG_TRAP is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SB(unsigned long long *o)
{
  int n = (CPU_FEATURE_SB) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SB) | 0);  /* check that CPU_FEATURE_SB is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SPECRES(unsigned long long *o)
{
  int n = (CPU_FEATURE_SPECRES) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SPECRES) | 0);  /* check that CPU_FEATURE_SPECRES is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SSBS(unsigned long long *o)
{
  int n = (CPU_FEATURE_SSBS) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SSBS) | 0);  /* check that CPU_FEATURE_SSBS is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SSBS2(unsigned long long *o)
{
  int n = (CPU_FEATURE_SSBS2) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SSBS2) | 0);  /* check that CPU_FEATURE_SSBS2 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_AA32BF16(unsigned long long *o)
{
  int n = (CPU_FEATURE_AA32BF16) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_AA32BF16) | 0);  /* check that CPU_FEATURE_AA32BF16 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_AMUV1P1(unsigned long long *o)
{
  int n = (CPU_FEATURE_AMUV1P1) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_AMUV1P1) | 0);  /* check that CPU_FEATURE_AMUV1P1 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_BF16(unsigned long long *o)
{
  int n = (CPU_FEATURE_BF16) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_BF16) | 0);  /* check that CPU_FEATURE_BF16 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_DGH(unsigned long long *o)
{
  int n = (CPU_FEATURE_DGH) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_DGH) | 0);  /* check that CPU_FEATURE_DGH is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_ECV(unsigned long long *o)
{
  int n = (CPU_FEATURE_ECV) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_ECV) | 0);  /* check that CPU_FEATURE_ECV is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_FGT(unsigned long long *o)
{
  int n = (CPU_FEATURE_FGT) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_FGT) | 0);  /* check that CPU_FEATURE_FGT is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_HPMN0(unsigned long long *o)
{
  int n = (CPU_FEATURE_HPMN0) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_HPMN0) | 0);  /* check that CPU_FEATURE_HPMN0 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_MPAMV0P1(unsigned long long *o)
{
  int n = (CPU_FEATURE_MPAMV0P1) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_MPAMV0P1) | 0);  /* check that CPU_FEATURE_MPAMV0P1 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_MPAMV1P1(unsigned long long *o)
{
  int n = (CPU_FEATURE_MPAMV1P1) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_MPAMV1P1) | 0);  /* check that CPU_FEATURE_MPAMV1P1 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_MTPMU(unsigned long long *o)
{
  int n = (CPU_FEATURE_MTPMU) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_MTPMU) | 0);  /* check that CPU_FEATURE_MTPMU is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_PAUTH2(unsigned long long *o)
{
  int n = (CPU_FEATURE_PAUTH2) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_PAUTH2) | 0);  /* check that CPU_FEATURE_PAUTH2 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_TWED(unsigned long long *o)
{
  int n = (CPU_FEATURE_TWED) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_TWED) | 0);  /* check that CPU_FEATURE_TWED is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_AFP(unsigned long long *o)
{
  int n = (CPU_FEATURE_AFP) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_AFP) | 0);  /* check that CPU_FEATURE_AFP is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_EBF16(unsigned long long *o)
{
  int n = (CPU_FEATURE_EBF16) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_EBF16) | 0);  /* check that CPU_FEATURE_EBF16 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_HCX(unsigned long long *o)
{
  int n = (CPU_FEATURE_HCX) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_HCX) | 0);  /* check that CPU_FEATURE_HCX is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_LPA2(unsigned long long *o)
{
  int n = (CPU_FEATURE_LPA2) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_LPA2) | 0);  /* check that CPU_FEATURE_LPA2 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_LS64(unsigned long long *o)
{
  int n = (CPU_FEATURE_LS64) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_LS64) | 0);  /* check that CPU_FEATURE_LS64 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_LS64_ACCDATA(unsigned long long *o)
{
  int n = (CPU_FEATURE_LS64_ACCDATA) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_LS64_ACCDATA) | 0);  /* check that CPU_FEATURE_LS64_ACCDATA is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_LS64_V(unsigned long long *o)
{
  int n = (CPU_FEATURE_LS64_V) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_LS64_V) | 0);  /* check that CPU_FEATURE_LS64_V is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_MTE3(unsigned long long *o)
{
  int n = (CPU_FEATURE_MTE3) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_MTE3) | 0);  /* check that CPU_FEATURE_MTE3 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_MTE_ASYM_FAULT(unsigned long long *o)
{
  int n = (CPU_FEATURE_MTE_ASYM_FAULT) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_MTE_ASYM_FAULT) | 0);  /* check that CPU_FEATURE_MTE_ASYM_FAULT is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_PAN3(unsigned long long *o)
{
  int n = (CPU_FEATURE_PAN3) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_PAN3) | 0);  /* check that CPU_FEATURE_PAN3 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_PMUV3P7(unsigned long long *o)
{
  int n = (CPU_FEATURE_PMUV3P7) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_PMUV3P7) | 0);  /* check that CPU_FEATURE_PMUV3P7 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_RPRES(unsigned long long *o)
{
  int n = (CPU_FEATURE_RPRES) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_RPRES) | 0);  /* check that CPU_FEATURE_RPRES is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SPEV1P2(unsigned long long *o)
{
  int n = (CPU_FEATURE_SPEV1P2) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SPEV1P2) | 0);  /* check that CPU_FEATURE_SPEV1P2 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_WFXT(unsigned long long *o)
{
  int n = (CPU_FEATURE_WFXT) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_WFXT) | 0);  /* check that CPU_FEATURE_WFXT is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_XS(unsigned long long *o)
{
  int n = (CPU_FEATURE_XS) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_XS) | 0);  /* check that CPU_FEATURE_XS is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_CMOW(unsigned long long *o)
{
  int n = (CPU_FEATURE_CMOW) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_CMOW) | 0);  /* check that CPU_FEATURE_CMOW is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_DEBUGV8P8(unsigned long long *o)
{
  int n = (CPU_FEATURE_DEBUGV8P8) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_DEBUGV8P8) | 0);  /* check that CPU_FEATURE_DEBUGV8P8 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_HBC(unsigned long long *o)
{
  int n = (CPU_FEATURE_HBC) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_HBC) | 0);  /* check that CPU_FEATURE_HBC is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_MOPS(unsigned long long *o)
{
  int n = (CPU_FEATURE_MOPS) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_MOPS) | 0);  /* check that CPU_FEATURE_MOPS is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_NMI(unsigned long long *o)
{
  int n = (CPU_FEATURE_NMI) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_NMI) | 0);  /* check that CPU_FEATURE_NMI is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_PMUV3P8(unsigned long long *o)
{
  int n = (CPU_FEATURE_PMUV3P8) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_PMUV3P8) | 0);  /* check that CPU_FEATURE_PMUV3P8 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SCTLR2(unsigned long long *o)
{
  int n = (CPU_FEATURE_SCTLR2) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SCTLR2) | 0);  /* check that CPU_FEATURE_SCTLR2 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SPEV1P3(unsigned long long *o)
{
  int n = (CPU_FEATURE_SPEV1P3) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SPEV1P3) | 0);  /* check that CPU_FEATURE_SPEV1P3 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_TCR2(unsigned long long *o)
{
  int n = (CPU_FEATURE_TCR2) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_TCR2) | 0);  /* check that CPU_FEATURE_TCR2 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_TIDCP1(unsigned long long *o)
{
  int n = (CPU_FEATURE_TIDCP1) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_TIDCP1) | 0);  /* check that CPU_FEATURE_TIDCP1 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_ADERR(unsigned long long *o)
{
  int n = (CPU_FEATURE_ADERR) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_ADERR) | 0);  /* check that CPU_FEATURE_ADERR is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_AIE(unsigned long long *o)
{
  int n = (CPU_FEATURE_AIE) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_AIE) | 0);  /* check that CPU_FEATURE_AIE is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_ANERR(unsigned long long *o)
{
  int n = (CPU_FEATURE_ANERR) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_ANERR) | 0);  /* check that CPU_FEATURE_ANERR is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_ATS1A(unsigned long long *o)
{
  int n = (CPU_FEATURE_ATS1A) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_ATS1A) | 0);  /* check that CPU_FEATURE_ATS1A is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_CLRBHB(unsigned long long *o)
{
  int n = (CPU_FEATURE_CLRBHB) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_CLRBHB) | 0);  /* check that CPU_FEATURE_CLRBHB is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_CSSC(unsigned long long *o)
{
  int n = (CPU_FEATURE_CSSC) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_CSSC) | 0);  /* check that CPU_FEATURE_CSSC is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_DEBUGV8P9(unsigned long long *o)
{
  int n = (CPU_FEATURE_DEBUGV8P9) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_DEBUGV8P9) | 0);  /* check that CPU_FEATURE_DEBUGV8P9 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_DOUBLEFAULT2(unsigned long long *o)
{
  int n = (CPU_FEATURE_DOUBLEFAULT2) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_DOUBLEFAULT2) | 0);  /* check that CPU_FEATURE_DOUBLEFAULT2 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_ECBHB(unsigned long long *o)
{
  int n = (CPU_FEATURE_ECBHB) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_ECBHB) | 0);  /* check that CPU_FEATURE_ECBHB is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_FGT2(unsigned long long *o)
{
  int n = (CPU_FEATURE_FGT2) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_FGT2) | 0);  /* check that CPU_FEATURE_FGT2 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_HAFT(unsigned long long *o)
{
  int n = (CPU_FEATURE_HAFT) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_HAFT) | 0);  /* check that CPU_FEATURE_HAFT is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_LRCPC3(unsigned long long *o)
{
  int n = (CPU_FEATURE_LRCPC3) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_LRCPC3) | 0);  /* check that CPU_FEATURE_LRCPC3 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_MTE4(unsigned long long *o)
{
  int n = (CPU_FEATURE_MTE4) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_MTE4) | 0);  /* check that CPU_FEATURE_MTE4 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_MTE_ASYNC(unsigned long long *o)
{
  int n = (CPU_FEATURE_MTE_ASYNC) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_MTE_ASYNC) | 0);  /* check that CPU_FEATURE_MTE_ASYNC is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_MTE_CANONICAL_TAGS(unsigned long long *o)
{
  int n = (CPU_FEATURE_MTE_CANONICAL_TAGS) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_MTE_CANONICAL_TAGS) | 0);  /* check that CPU_FEATURE_MTE_CANONICAL_TAGS is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_MTE_NO_ADDRESS_TAGS(unsigned long long *o)
{
  int n = (CPU_FEATURE_MTE_NO_ADDRESS_TAGS) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_MTE_NO_ADDRESS_TAGS) | 0);  /* check that CPU_FEATURE_MTE_NO_ADDRESS_TAGS is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_MTE_PERM(unsigned long long *o)
{
  int n = (CPU_FEATURE_MTE_PERM) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_MTE_PERM) | 0);  /* check that CPU_FEATURE_MTE_PERM is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_MTE_STORE_ONLY(unsigned long long *o)
{
  int n = (CPU_FEATURE_MTE_STORE_ONLY) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_MTE_STORE_ONLY) | 0);  /* check that CPU_FEATURE_MTE_STORE_ONLY is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_MTE_TAGGED_FAR(unsigned long long *o)
{
  int n = (CPU_FEATURE_MTE_TAGGED_FAR) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_MTE_TAGGED_FAR) | 0);  /* check that CPU_FEATURE_MTE_TAGGED_FAR is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_PFAR(unsigned long long *o)
{
  int n = (CPU_FEATURE_PFAR) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_PFAR) | 0);  /* check that CPU_FEATURE_PFAR is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_PMUV3_ICNTR(unsigned long long *o)
{
  int n = (CPU_FEATURE_PMUV3_ICNTR) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_PMUV3_ICNTR) | 0);  /* check that CPU_FEATURE_PMUV3_ICNTR is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_PMUV3_SS(unsigned long long *o)
{
  int n = (CPU_FEATURE_PMUV3_SS) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_PMUV3_SS) | 0);  /* check that CPU_FEATURE_PMUV3_SS is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_PMUV3P9(unsigned long long *o)
{
  int n = (CPU_FEATURE_PMUV3P9) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_PMUV3P9) | 0);  /* check that CPU_FEATURE_PMUV3P9 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_PRFMSLC(unsigned long long *o)
{
  int n = (CPU_FEATURE_PRFMSLC) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_PRFMSLC) | 0);  /* check that CPU_FEATURE_PRFMSLC is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_RASV2(unsigned long long *o)
{
  int n = (CPU_FEATURE_RASV2) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_RASV2) | 0);  /* check that CPU_FEATURE_RASV2 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_RPRFM(unsigned long long *o)
{
  int n = (CPU_FEATURE_RPRFM) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_RPRFM) | 0);  /* check that CPU_FEATURE_RPRFM is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_S1PIE(unsigned long long *o)
{
  int n = (CPU_FEATURE_S1PIE) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_S1PIE) | 0);  /* check that CPU_FEATURE_S1PIE is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_S1POE(unsigned long long *o)
{
  int n = (CPU_FEATURE_S1POE) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_S1POE) | 0);  /* check that CPU_FEATURE_S1POE is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_S2PIE(unsigned long long *o)
{
  int n = (CPU_FEATURE_S2PIE) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_S2PIE) | 0);  /* check that CPU_FEATURE_S2PIE is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_S2POE(unsigned long long *o)
{
  int n = (CPU_FEATURE_S2POE) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_S2POE) | 0);  /* check that CPU_FEATURE_S2POE is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SPECRES2(unsigned long long *o)
{
  int n = (CPU_FEATURE_SPECRES2) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SPECRES2) | 0);  /* check that CPU_FEATURE_SPECRES2 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SPE_DPFZS(unsigned long long *o)
{
  int n = (CPU_FEATURE_SPE_DPFZS) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SPE_DPFZS) | 0);  /* check that CPU_FEATURE_SPE_DPFZS is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SPEV1P4(unsigned long long *o)
{
  int n = (CPU_FEATURE_SPEV1P4) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SPEV1P4) | 0);  /* check that CPU_FEATURE_SPEV1P4 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SPMU(unsigned long long *o)
{
  int n = (CPU_FEATURE_SPMU) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SPMU) | 0);  /* check that CPU_FEATURE_SPMU is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_THE(unsigned long long *o)
{
  int n = (CPU_FEATURE_THE) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_THE) | 0);  /* check that CPU_FEATURE_THE is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SVE2(unsigned long long *o)
{
  int n = (CPU_FEATURE_SVE2) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SVE2) | 0);  /* check that CPU_FEATURE_SVE2 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SVE_AES(unsigned long long *o)
{
  int n = (CPU_FEATURE_SVE_AES) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SVE_AES) | 0);  /* check that CPU_FEATURE_SVE_AES is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SVE_BITPERM(unsigned long long *o)
{
  int n = (CPU_FEATURE_SVE_BITPERM) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SVE_BITPERM) | 0);  /* check that CPU_FEATURE_SVE_BITPERM is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SVE_PMULL128(unsigned long long *o)
{
  int n = (CPU_FEATURE_SVE_PMULL128) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SVE_PMULL128) | 0);  /* check that CPU_FEATURE_SVE_PMULL128 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SVE_SHA3(unsigned long long *o)
{
  int n = (CPU_FEATURE_SVE_SHA3) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SVE_SHA3) | 0);  /* check that CPU_FEATURE_SVE_SHA3 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SVE_SM4(unsigned long long *o)
{
  int n = (CPU_FEATURE_SVE_SM4) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SVE_SM4) | 0);  /* check that CPU_FEATURE_SVE_SM4 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_TME(unsigned long long *o)
{
  int n = (CPU_FEATURE_TME) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_TME) | 0);  /* check that CPU_FEATURE_TME is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_TRBE(unsigned long long *o)
{
  int n = (CPU_FEATURE_TRBE) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_TRBE) | 0);  /* check that CPU_FEATURE_TRBE is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_BRBE(unsigned long long *o)
{
  int n = (CPU_FEATURE_BRBE) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_BRBE) | 0);  /* check that CPU_FEATURE_BRBE is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_RME(unsigned long long *o)
{
  int n = (CPU_FEATURE_RME) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_RME) | 0);  /* check that CPU_FEATURE_RME is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SME(unsigned long long *o)
{
  int n = (CPU_FEATURE_SME) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SME) | 0);  /* check that CPU_FEATURE_SME is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SME_F64F64(unsigned long long *o)
{
  int n = (CPU_FEATURE_SME_F64F64) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SME_F64F64) | 0);  /* check that CPU_FEATURE_SME_F64F64 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SME_FA64(unsigned long long *o)
{
  int n = (CPU_FEATURE_SME_FA64) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SME_FA64) | 0);  /* check that CPU_FEATURE_SME_FA64 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SME_I16I64(unsigned long long *o)
{
  int n = (CPU_FEATURE_SME_I16I64) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SME_I16I64) | 0);  /* check that CPU_FEATURE_SME_I16I64 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_BRBEV1P1(unsigned long long *o)
{
  int n = (CPU_FEATURE_BRBEV1P1) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_BRBEV1P1) | 0);  /* check that CPU_FEATURE_BRBEV1P1 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_MEC(unsigned long long *o)
{
  int n = (CPU_FEATURE_MEC) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_MEC) | 0);  /* check that CPU_FEATURE_MEC is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SME2(unsigned long long *o)
{
  int n = (CPU_FEATURE_SME2) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SME2) | 0);  /* check that CPU_FEATURE_SME2 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_ABLE(unsigned long long *o)
{
  int n = (CPU_FEATURE_ABLE) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_ABLE) | 0);  /* check that CPU_FEATURE_ABLE is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_BWE(unsigned long long *o)
{
  int n = (CPU_FEATURE_BWE) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_BWE) | 0);  /* check that CPU_FEATURE_BWE is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_D128(unsigned long long *o)
{
  int n = (CPU_FEATURE_D128) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_D128) | 0);  /* check that CPU_FEATURE_D128 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_EBEP(unsigned long long *o)
{
  int n = (CPU_FEATURE_EBEP) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_EBEP) | 0);  /* check that CPU_FEATURE_EBEP is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_GCS(unsigned long long *o)
{
  int n = (CPU_FEATURE_GCS) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_GCS) | 0);  /* check that CPU_FEATURE_GCS is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_ITE(unsigned long long *o)
{
  int n = (CPU_FEATURE_ITE) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_ITE) | 0);  /* check that CPU_FEATURE_ITE is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_LSE128(unsigned long long *o)
{
  int n = (CPU_FEATURE_LSE128) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_LSE128) | 0);  /* check that CPU_FEATURE_LSE128 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_LVA3(unsigned long long *o)
{
  int n = (CPU_FEATURE_LVA3) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_LVA3) | 0);  /* check that CPU_FEATURE_LVA3 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SEBEP(unsigned long long *o)
{
  int n = (CPU_FEATURE_SEBEP) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SEBEP) | 0);  /* check that CPU_FEATURE_SEBEP is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SME2P1(unsigned long long *o)
{
  int n = (CPU_FEATURE_SME2P1) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SME2P1) | 0);  /* check that CPU_FEATURE_SME2P1 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SME_F16F16(unsigned long long *o)
{
  int n = (CPU_FEATURE_SME_F16F16) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SME_F16F16) | 0);  /* check that CPU_FEATURE_SME_F16F16 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SVE2P1(unsigned long long *o)
{
  int n = (CPU_FEATURE_SVE2P1) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SVE2P1) | 0);  /* check that CPU_FEATURE_SVE2P1 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SVE_B16B16(unsigned long long *o)
{
  int n = (CPU_FEATURE_SVE_B16B16) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SVE_B16B16) | 0);  /* check that CPU_FEATURE_SVE_B16B16 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SYSINSTR128(unsigned long long *o)
{
  int n = (CPU_FEATURE_SYSINSTR128) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SYSINSTR128) | 0);  /* check that CPU_FEATURE_SYSINSTR128 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_SYSREG128(unsigned long long *o)
{
  int n = (CPU_FEATURE_SYSREG128) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_SYSREG128) | 0);  /* check that CPU_FEATURE_SYSREG128 is an integer */
  return n;
}

static int _cffi_const_CPU_FEATURE_TRBE_EXT(unsigned long long *o)
{
  int n = (CPU_FEATURE_TRBE_EXT) <= 0;
  *o = (unsigned long long)((CPU_FEATURE_TRBE_EXT) | 0);  /* check that CPU_FEATURE_TRBE_EXT is an integer */
  return n;
}

static int _cffi_const_NUM_CPU_FEATURES(unsigned long long *o)
{
  int n = (NUM_CPU_FEATURES) <= 0;
  *o = (unsigned long long)((NUM_CPU_FEATURES) | 0);  /* check that NUM_CPU_FEATURES is an integer */
  return n;
}

static int _cffi_const_CPU_HINT_SSE_SIZE_AUTH(unsigned long long *o)
{
  int n = (CPU_HINT_SSE_SIZE_AUTH) <= 0;
  *o = (unsigned long long)((CPU_HINT_SSE_SIZE_AUTH) | 0);  /* check that CPU_HINT_SSE_SIZE_AUTH is an integer */
  return n;
}

static int _cffi_const_NUM_CPU_HINTS(unsigned long long *o)
{
  int n = (NUM_CPU_HINTS) <= 0;
  *o = (unsigned long long)((NUM_CPU_HINTS) | 0);  /* check that NUM_CPU_HINTS is an integer */
  return n;
}

static int _cffi_const_INFO_MPERF(unsigned long long *o)
{
  int n = (INFO_MPERF) <= 0;
  *o = (unsigned long long)((INFO_MPERF) | 0);  /* check that INFO_MPERF is an integer */
  return n;
}

static int _cffi_const_INFO_APERF(unsigned long long *o)
{
  int n = (INFO_APERF) <= 0;
  *o = (unsigned long long)((INFO_APERF) | 0);  /* check that INFO_APERF is an integer */
  return n;
}

static int _cffi_const_INFO_MIN_MULTIPLIER(unsigned long long *o)
{
  int n = (INFO_MIN_MULTIPLIER) <= 0;
  *o = (unsigned long long)((INFO_MIN_MULTIPLIER) | 0);  /* check that INFO_MIN_MULTIPLIER is an integer */
  return n;
}

static int _cffi_const_INFO_CUR_MULTIPLIER(unsigned long long *o)
{
  int n = (INFO_CUR_MULTIPLIER) <= 0;
  *o = (unsigned long long)((INFO_CUR_MULTIPLIER) | 0);  /* check that INFO_CUR_MULTIPLIER is an integer */
  return n;
}

static int _cffi_const_INFO_MAX_MULTIPLIER(unsigned long long *o)
{
  int n = (INFO_MAX_MULTIPLIER) <= 0;
  *o = (unsigned long long)((INFO_MAX_MULTIPLIER) | 0);  /* check that INFO_MAX_MULTIPLIER is an integer */
  return n;
}

static int _cffi_const_INFO_TEMPERATURE(unsigned long long *o)
{
  int n = (INFO_TEMPERATURE) <= 0;
  *o = (unsigned long long)((INFO_TEMPERATURE) | 0);  /* check that INFO_TEMPERATURE is an integer */
  return n;
}

static int _cffi_const_INFO_THROTTLING(unsigned long long *o)
{
  int n = (INFO_THROTTLING) <= 0;
  *o = (unsigned long long)((INFO_THROTTLING) | 0);  /* check that INFO_THROTTLING is an integer */
  return n;
}

static int _cffi_const_INFO_VOLTAGE(unsigned long long *o)
{
  int n = (INFO_VOLTAGE) <= 0;
  *o = (unsigned long long)((INFO_VOLTAGE) | 0);  /* check that INFO_VOLTAGE is an integer */
  return n;
}

static int _cffi_const_INFO_BCLK(unsigned long long *o)
{
  int n = (INFO_BCLK) <= 0;
  *o = (unsigned long long)((INFO_BCLK) | 0);  /* check that INFO_BCLK is an integer */
  return n;
}

static int _cffi_const_INFO_BUS_CLOCK(unsigned long long *o)
{
  int n = (INFO_BUS_CLOCK) <= 0;
  *o = (unsigned long long)((INFO_BUS_CLOCK) | 0);  /* check that INFO_BUS_CLOCK is an integer */
  return n;
}

static int _cffi_const_PURPOSE_GENERAL(unsigned long long *o)
{
  int n = (PURPOSE_GENERAL) <= 0;
  *o = (unsigned long long)((PURPOSE_GENERAL) | 0);  /* check that PURPOSE_GENERAL is an integer */
  return n;
}

static int _cffi_const_PURPOSE_PERFORMANCE(unsigned long long *o)
{
  int n = (PURPOSE_PERFORMANCE) <= 0;
  *o = (unsigned long long)((PURPOSE_PERFORMANCE) | 0);  /* check that PURPOSE_PERFORMANCE is an integer */
  return n;
}

static int _cffi_const_PURPOSE_EFFICIENCY(unsigned long long *o)
{
  int n = (PURPOSE_EFFICIENCY) <= 0;
  *o = (unsigned long long)((PURPOSE_EFFICIENCY) | 0);  /* check that PURPOSE_EFFICIENCY is an integer */
  return n;
}

static int _cffi_const_PURPOSE_LP_EFFICIENCY(unsigned long long *o)
{
  int n = (PURPOSE_LP_EFFICIENCY) <= 0;
  *o = (unsigned long long)((PURPOSE_LP_EFFICIENCY) | 0);  /* check that PURPOSE_LP_EFFICIENCY is an integer */
  return n;
}

static int _cffi_const_PURPOSE_U_PERFORMANCE(unsigned long long *o)
{
  int n = (PURPOSE_U_PERFORMANCE) <= 0;
  *o = (unsigned long long)((PURPOSE_U_PERFORMANCE) | 0);  /* check that PURPOSE_U_PERFORMANCE is an integer */
  return n;
}

static int _cffi_const_NUM_CPU_PURPOSES(unsigned long long *o)
{
  int n = (NUM_CPU_PURPOSES) <= 0;
  *o = (unsigned long long)((NUM_CPU_PURPOSES) | 0);  /* check that NUM_CPU_PURPOSES is an integer */
  return n;
}

static int _cffi_const_EAX(unsigned long long *o)
{
  int n = (EAX) <= 0;
  *o = (unsigned long long)((EAX) | 0);  /* check that EAX is an integer */
  return n;
}

static int _cffi_const_EBX(unsigned long long *o)
{
  int n = (EBX) <= 0;
  *o = (unsigned long long)((EBX) | 0);  /* check that EBX is an integer */
  return n;
}

static int _cffi_const_ECX(unsigned long long *o)
{
  int n = (ECX) <= 0;
  *o = (unsigned long long)((ECX) | 0);  /* check that ECX is an integer */
  return n;
}

static int _cffi_const_EDX(unsigned long long *o)
{
  int n = (EDX) <= 0;
  *o = (unsigned long long)((EDX) | 0);  /* check that EDX is an integer */
  return n;
}

static int _cffi_const_NUM_REGS(unsigned long long *o)
{
  int n = (NUM_REGS) <= 0;
  *o = (unsigned long long)((NUM_REGS) | 0);  /* check that NUM_REGS is an integer */
  return n;
}

static int _cffi_const_INTEL_SGX1(unsigned long long *o)
{
  int n = (INTEL_SGX1) <= 0;
  *o = (unsigned long long)((INTEL_SGX1) | 0);  /* check that INTEL_SGX1 is an integer */
  return n;
}

static int _cffi_const_INTEL_SGX2(unsigned long long *o)
{
  int n = (INTEL_SGX2) <= 0;
  *o = (unsigned long long)((INTEL_SGX2) | 0);  /* check that INTEL_SGX2 is an integer */
  return n;
}

static int _cffi_const_NUM_SGX_FEATURES(unsigned long long *o)
{
  int n = (NUM_SGX_FEATURES) <= 0;
  *o = (unsigned long long)((NUM_SGX_FEATURES) | 0);  /* check that NUM_SGX_FEATURES is an integer */
  return n;
}

static int _cffi_const_VENDOR_INTEL(unsigned long long *o)
{
  int n = (VENDOR_INTEL) <= 0;
  *o = (unsigned long long)((VENDOR_INTEL) | 0);  /* check that VENDOR_INTEL is an integer */
  return n;
}

static int _cffi_const_VENDOR_AMD(unsigned long long *o)
{
  int n = (VENDOR_AMD) <= 0;
  *o = (unsigned long long)((VENDOR_AMD) | 0);  /* check that VENDOR_AMD is an integer */
  return n;
}

static int _cffi_const_VENDOR_CYRIX(unsigned long long *o)
{
  int n = (VENDOR_CYRIX) <= 0;
  *o = (unsigned long long)((VENDOR_CYRIX) | 0);  /* check that VENDOR_CYRIX is an integer */
  return n;
}

static int _cffi_const_VENDOR_NEXGEN(unsigned long long *o)
{
  int n = (VENDOR_NEXGEN) <= 0;
  *o = (unsigned long long)((VENDOR_NEXGEN) | 0);  /* check that VENDOR_NEXGEN is an integer */
  return n;
}

static int _cffi_const_VENDOR_TRANSMETA(unsigned long long *o)
{
  int n = (VENDOR_TRANSMETA) <= 0;
  *o = (unsigned long long)((VENDOR_TRANSMETA) | 0);  /* check that VENDOR_TRANSMETA is an integer */
  return n;
}

static int _cffi_const_VENDOR_UMC(unsigned long long *o)
{
  int n = (VENDOR_UMC) <= 0;
  *o = (unsigned long long)((VENDOR_UMC) | 0);  /* check that VENDOR_UMC is an integer */
  return n;
}

static int _cffi_const_VENDOR_CENTAUR(unsigned long long *o)
{
  int n = (VENDOR_CENTAUR) <= 0;
  *o = (unsigned long long)((VENDOR_CENTAUR) | 0);  /* check that VENDOR_CENTAUR is an integer */
  return n;
}

static int _cffi_const_VENDOR_RISE(unsigned long long *o)
{
  int n = (VENDOR_RISE) <= 0;
  *o = (unsigned long long)((VENDOR_RISE) | 0);  /* check that VENDOR_RISE is an integer */
  return n;
}

static int _cffi_const_VENDOR_SIS(unsigned long long *o)
{
  int n = (VENDOR_SIS) <= 0;
  *o = (unsigned long long)((VENDOR_SIS) | 0);  /* check that VENDOR_SIS is an integer */
  return n;
}

static int _cffi_const_VENDOR_NSC(unsigned long long *o)
{
  int n = (VENDOR_NSC) <= 0;
  *o = (unsigned long long)((VENDOR_NSC) | 0);  /* check that VENDOR_NSC is an integer */
  return n;
}

static int _cffi_const_VENDOR_HYGON(unsigned long long *o)
{
  int n = (VENDOR_HYGON) <= 0;
  *o = (unsigned long long)((VENDOR_HYGON) | 0);  /* check that VENDOR_HYGON is an integer */
  return n;
}

static int _cffi_const_VENDOR_ARM(unsigned long long *o)
{
  int n = (VENDOR_ARM) <= 0;
  *o = (unsigned long long)((VENDOR_ARM) | 0);  /* check that VENDOR_ARM is an integer */
  return n;
}

static int _cffi_const_VENDOR_BROADCOM(unsigned long long *o)
{
  int n = (VENDOR_BROADCOM) <= 0;
  *o = (unsigned long long)((VENDOR_BROADCOM) | 0);  /* check that VENDOR_BROADCOM is an integer */
  return n;
}

static int _cffi_const_VENDOR_CAVIUM(unsigned long long *o)
{
  int n = (VENDOR_CAVIUM) <= 0;
  *o = (unsigned long long)((VENDOR_CAVIUM) | 0);  /* check that VENDOR_CAVIUM is an integer */
  return n;
}

static int _cffi_const_VENDOR_DEC(unsigned long long *o)
{
  int n = (VENDOR_DEC) <= 0;
  *o = (unsigned long long)((VENDOR_DEC) | 0);  /* check that VENDOR_DEC is an integer */
  return n;
}

static int _cffi_const_VENDOR_FUJITSU(unsigned long long *o)
{
  int n = (VENDOR_FUJITSU) <= 0;
  *o = (unsigned long long)((VENDOR_FUJITSU) | 0);  /* check that VENDOR_FUJITSU is an integer */
  return n;
}

static int _cffi_const_VENDOR_HISILICON(unsigned long long *o)
{
  int n = (VENDOR_HISILICON) <= 0;
  *o = (unsigned long long)((VENDOR_HISILICON) | 0);  /* check that VENDOR_HISILICON is an integer */
  return n;
}

static int _cffi_const_VENDOR_INFINEON(unsigned long long *o)
{
  int n = (VENDOR_INFINEON) <= 0;
  *o = (unsigned long long)((VENDOR_INFINEON) | 0);  /* check that VENDOR_INFINEON is an integer */
  return n;
}

static int _cffi_const_VENDOR_FREESCALE(unsigned long long *o)
{
  int n = (VENDOR_FREESCALE) <= 0;
  *o = (unsigned long long)((VENDOR_FREESCALE) | 0);  /* check that VENDOR_FREESCALE is an integer */
  return n;
}

static int _cffi_const_VENDOR_NVIDIA(unsigned long long *o)
{
  int n = (VENDOR_NVIDIA) <= 0;
  *o = (unsigned long long)((VENDOR_NVIDIA) | 0);  /* check that VENDOR_NVIDIA is an integer */
  return n;
}

static int _cffi_const_VENDOR_APM(unsigned long long *o)
{
  int n = (VENDOR_APM) <= 0;
  *o = (unsigned long long)((VENDOR_APM) | 0);  /* check that VENDOR_APM is an integer */
  return n;
}

static int _cffi_const_VENDOR_QUALCOMM(unsigned long long *o)
{
  int n = (VENDOR_QUALCOMM) <= 0;
  *o = (unsigned long long)((VENDOR_QUALCOMM) | 0);  /* check that VENDOR_QUALCOMM is an integer */
  return n;
}

static int _cffi_const_VENDOR_SAMSUNG(unsigned long long *o)
{
  int n = (VENDOR_SAMSUNG) <= 0;
  *o = (unsigned long long)((VENDOR_SAMSUNG) | 0);  /* check that VENDOR_SAMSUNG is an integer */
  return n;
}

static int _cffi_const_VENDOR_MARVELL(unsigned long long *o)
{
  int n = (VENDOR_MARVELL) <= 0;
  *o = (unsigned long long)((VENDOR_MARVELL) | 0);  /* check that VENDOR_MARVELL is an integer */
  return n;
}

static int _cffi_const_VENDOR_APPLE(unsigned long long *o)
{
  int n = (VENDOR_APPLE) <= 0;
  *o = (unsigned long long)((VENDOR_APPLE) | 0);  /* check that VENDOR_APPLE is an integer */
  return n;
}

static int _cffi_const_VENDOR_FARADAY(unsigned long long *o)
{
  int n = (VENDOR_FARADAY) <= 0;
  *o = (unsigned long long)((VENDOR_FARADAY) | 0);  /* check that VENDOR_FARADAY is an integer */
  return n;
}

static int _cffi_const_VENDOR_MICROSOFT(unsigned long long *o)
{
  int n = (VENDOR_MICROSOFT) <= 0;
  *o = (unsigned long long)((VENDOR_MICROSOFT) | 0);  /* check that VENDOR_MICROSOFT is an integer */
  return n;
}

static int _cffi_const_VENDOR_PHYTIUM(unsigned long long *o)
{
  int n = (VENDOR_PHYTIUM) <= 0;
  *o = (unsigned long long)((VENDOR_PHYTIUM) | 0);  /* check that VENDOR_PHYTIUM is an integer */
  return n;
}

static int _cffi_const_VENDOR_AMPERE(unsigned long long *o)
{
  int n = (VENDOR_AMPERE) <= 0;
  *o = (unsigned long long)((VENDOR_AMPERE) | 0);  /* check that VENDOR_AMPERE is an integer */
  return n;
}

static int _cffi_const_NUM_CPU_VENDORS(unsigned long long *o)
{
  int n = (NUM_CPU_VENDORS) <= 0;
  *o = (unsigned long long)((NUM_CPU_VENDORS) | 0);  /* check that NUM_CPU_VENDORS is an integer */
  return n;
}

static int _cffi_const_VENDOR_UNKNOWN(unsigned long long *o)
{
  int n = (VENDOR_UNKNOWN) <= 0;
  *o = (unsigned long long)((VENDOR_UNKNOWN) | 0);  /* check that VENDOR_UNKNOWN is an integer */
  return n;
}

static int _cffi_const_HYPERVISOR_NONE(unsigned long long *o)
{
  int n = (HYPERVISOR_NONE) <= 0;
  *o = (unsigned long long)((HYPERVISOR_NONE) | 0);  /* check that HYPERVISOR_NONE is an integer */
  return n;
}

static int _cffi_const_HYPERVISOR_BHYVE(unsigned long long *o)
{
  int n = (HYPERVISOR_BHYVE) <= 0;
  *o = (unsigned long long)((HYPERVISOR_BHYVE) | 0);  /* check that HYPERVISOR_BHYVE is an integer */
  return n;
}

static int _cffi_const_HYPERVISOR_HYPERV(unsigned long long *o)
{
  int n = (HYPERVISOR_HYPERV) <= 0;
  *o = (unsigned long long)((HYPERVISOR_HYPERV) | 0);  /* check that HYPERVISOR_HYPERV is an integer */
  return n;
}

static int _cffi_const_HYPERVISOR_KVM(unsigned long long *o)
{
  int n = (HYPERVISOR_KVM) <= 0;
  *o = (unsigned long long)((HYPERVISOR_KVM) | 0);  /* check that HYPERVISOR_KVM is an integer */
  return n;
}

static int _cffi_const_HYPERVISOR_PARALLELS(unsigned long long *o)
{
  int n = (HYPERVISOR_PARALLELS) <= 0;
  *o = (unsigned long long)((HYPERVISOR_PARALLELS) | 0);  /* check that HYPERVISOR_PARALLELS is an integer */
  return n;
}

static int _cffi_const_HYPERVISOR_QEMU(unsigned long long *o)
{
  int n = (HYPERVISOR_QEMU) <= 0;
  *o = (unsigned long long)((HYPERVISOR_QEMU) | 0);  /* check that HYPERVISOR_QEMU is an integer */
  return n;
}

static int _cffi_const_HYPERVISOR_VIRTUALBOX(unsigned long long *o)
{
  int n = (HYPERVISOR_VIRTUALBOX) <= 0;
  *o = (unsigned long long)((HYPERVISOR_VIRTUALBOX) | 0);  /* check that HYPERVISOR_VIRTUALBOX is an integer */
  return n;
}

static int _cffi_const_HYPERVISOR_VMWARE(unsigned long long *o)
{
  int n = (HYPERVISOR_VMWARE) <= 0;
  *o = (unsigned long long)((HYPERVISOR_VMWARE) | 0);  /* check that HYPERVISOR_VMWARE is an integer */
  return n;
}

static int _cffi_const_HYPERVISOR_XEN(unsigned long long *o)
{
  int n = (HYPERVISOR_XEN) <= 0;
  *o = (unsigned long long)((HYPERVISOR_XEN) | 0);  /* check that HYPERVISOR_XEN is an integer */
  return n;
}

static int _cffi_const_NUM_HYPERVISOR_VENDORS(unsigned long long *o)
{
  int n = (NUM_HYPERVISOR_VENDORS) <= 0;
  *o = (unsigned long long)((NUM_HYPERVISOR_VENDORS) | 0);  /* check that NUM_HYPERVISOR_VENDORS is an integer */
  return n;
}

static int _cffi_const_HYPERVISOR_UNKNOWN(unsigned long long *o)
{
  int n = (HYPERVISOR_UNKNOWN) <= 0;
  *o = (unsigned long long)((HYPERVISOR_UNKNOWN) | 0);  /* check that HYPERVISOR_UNKNOWN is an integer */
  return n;
}

static char * _cffi_d_affinity_mask_str(cpu_affinity_mask_t * x0)
{
  return affinity_mask_str(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_affinity_mask_str(PyObject *self, PyObject *arg0)
{
  cpu_affinity_mask_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  char * result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpu_affinity_mask_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = affinity_mask_str(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(5));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_affinity_mask_str _cffi_d_affinity_mask_str
#endif

static char * _cffi_d_affinity_mask_str_r(cpu_affinity_mask_t * x0, char * x1, unsigned int x2)
{
  return affinity_mask_str_r(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_affinity_mask_str_r(PyObject *self, PyObject *args)
{
  cpu_affinity_mask_t * x0;
  char * x1;
  unsigned int x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  char * result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "affinity_mask_str_r", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(1), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (cpu_affinity_mask_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(1), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(5), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(5), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x2 = _cffi_to_c_int(arg2, unsigned int);
  if (x2 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = affinity_mask_str_r(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(5));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_affinity_mask_str_r _cffi_d_affinity_mask_str_r
#endif

static char const * _cffi_d_cpu_architecture_str(cpu_architecture_t x0)
{
  return cpu_architecture_str(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpu_architecture_str(PyObject *self, PyObject *arg0)
{
  cpu_architecture_t x0;
  char const * result;
  PyObject *pyresult;

  if (_cffi_to_c((char *)&x0, _cffi_type(9), arg0) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpu_architecture_str(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(45));
  return pyresult;
}
#else
#  define _cffi_f_cpu_architecture_str _cffi_d_cpu_architecture_str
#endif

static int _cffi_d_cpu_clock(void)
{
  return cpu_clock();
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpu_clock(PyObject *self, PyObject *noarg)
{
  int result;
  PyObject *pyresult;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpu_clock(); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  (void)noarg; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  return pyresult;
}
#else
#  define _cffi_f_cpu_clock _cffi_d_cpu_clock
#endif

static int _cffi_d_cpu_clock_by_ic(int x0, int x1)
{
  return cpu_clock_by_ic(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpu_clock_by_ic(PyObject *self, PyObject *args)
{
  int x0;
  int x1;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpu_clock_by_ic", 2, 2, &arg0, &arg1))
    return NULL;

  x0 = _cffi_to_c_int(arg0, int);
  if (x0 == (int)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpu_clock_by_ic(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  return pyresult;
}
#else
#  define _cffi_f_cpu_clock_by_ic _cffi_d_cpu_clock_by_ic
#endif

static int _cffi_d_cpu_clock_by_mark(struct cpu_mark_t * x0)
{
  return cpu_clock_by_mark(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpu_clock_by_mark(PyObject *self, PyObject *arg0)
{
  struct cpu_mark_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(38), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct cpu_mark_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(38), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpu_clock_by_mark(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpu_clock_by_mark _cffi_d_cpu_clock_by_mark
#endif

static int _cffi_d_cpu_clock_by_os(void)
{
  return cpu_clock_by_os();
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpu_clock_by_os(PyObject *self, PyObject *noarg)
{
  int result;
  PyObject *pyresult;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpu_clock_by_os(); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  (void)noarg; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  return pyresult;
}
#else
#  define _cffi_f_cpu_clock_by_os _cffi_d_cpu_clock_by_os
#endif

static int _cffi_d_cpu_clock_by_tsc(struct cpu_raw_data_t * x0)
{
  return cpu_clock_by_tsc(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpu_clock_by_tsc(PyObject *self, PyObject *arg0)
{
  struct cpu_raw_data_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(25), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct cpu_raw_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(25), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpu_clock_by_tsc(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpu_clock_by_tsc _cffi_d_cpu_clock_by_tsc
#endif

static int _cffi_d_cpu_clock_measure(int x0, int x1)
{
  return cpu_clock_measure(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpu_clock_measure(PyObject *self, PyObject *args)
{
  int x0;
  int x1;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpu_clock_measure", 2, 2, &arg0, &arg1))
    return NULL;

  x0 = _cffi_to_c_int(arg0, int);
  if (x0 == (int)-1 && PyErr_Occurred())
    return NULL;

  x1 = _cffi_to_c_int(arg1, int);
  if (x1 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpu_clock_measure(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  return pyresult;
}
#else
#  define _cffi_f_cpu_clock_measure _cffi_d_cpu_clock_measure
#endif

static void _cffi_d_cpu_exec_cpuid(unsigned int x0, unsigned int * x1)
{
  cpu_exec_cpuid(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpu_exec_cpuid(PyObject *self, PyObject *args)
{
  unsigned int x0;
  unsigned int * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpu_exec_cpuid", 2, 2, &arg0, &arg1))
    return NULL;

  x0 = _cffi_to_c_int(arg0, unsigned int);
  if (x0 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(123), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (unsigned int *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(123), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpu_exec_cpuid(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpu_exec_cpuid _cffi_d_cpu_exec_cpuid
#endif

static void _cffi_d_cpu_exec_cpuid_ext(unsigned int * x0)
{
  cpu_exec_cpuid_ext(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpu_exec_cpuid_ext(PyObject *self, PyObject *arg0)
{
  unsigned int * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(123), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (unsigned int *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(123), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpu_exec_cpuid_ext(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpu_exec_cpuid_ext _cffi_d_cpu_exec_cpuid_ext
#endif

static char const * _cffi_d_cpu_feature_level_str(cpu_feature_level_t x0)
{
  return cpu_feature_level_str(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpu_feature_level_str(PyObject *self, PyObject *arg0)
{
  cpu_feature_level_t x0;
  char const * result;
  PyObject *pyresult;

  if (_cffi_to_c((char *)&x0, _cffi_type(12), arg0) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpu_feature_level_str(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(45));
  return pyresult;
}
#else
#  define _cffi_f_cpu_feature_level_str _cffi_d_cpu_feature_level_str
#endif

static char const * _cffi_d_cpu_feature_str(cpu_feature_t x0)
{
  return cpu_feature_str(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpu_feature_str(PyObject *self, PyObject *arg0)
{
  cpu_feature_t x0;
  char const * result;
  PyObject *pyresult;

  if (_cffi_to_c((char *)&x0, _cffi_type(15), arg0) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpu_feature_str(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(45));
  return pyresult;
}
#else
#  define _cffi_f_cpu_feature_str _cffi_d_cpu_feature_str
#endif

static int _cffi_d_cpu_identify(struct cpu_raw_data_t * x0, struct cpu_id_t * x1)
{
  return cpu_identify(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpu_identify(PyObject *self, PyObject *args)
{
  struct cpu_raw_data_t * x0;
  struct cpu_id_t * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpu_identify", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(25), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct cpu_raw_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(25), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(26), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (struct cpu_id_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(26), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpu_identify(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpu_identify _cffi_d_cpu_identify
#endif

static int _cffi_d_cpu_identify_all(struct cpu_raw_data_array_t * x0, struct system_id_t * x1)
{
  return cpu_identify_all(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpu_identify_all(PyObject *self, PyObject *args)
{
  struct cpu_raw_data_array_t * x0;
  struct system_id_t * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpu_identify_all", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(30), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct cpu_raw_data_array_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(30), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(49), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (struct system_id_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(49), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpu_identify_all(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpu_identify_all _cffi_d_cpu_identify_all
#endif

static int _cffi_d_cpu_msr_driver_close(struct msr_driver_t * x0)
{
  return cpu_msr_driver_close(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpu_msr_driver_close(PyObject *self, PyObject *arg0)
{
  struct msr_driver_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(67), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct msr_driver_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(67), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpu_msr_driver_close(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpu_msr_driver_close _cffi_d_cpu_msr_driver_close
#endif

static struct msr_driver_t * _cffi_d_cpu_msr_driver_open(void)
{
  return cpu_msr_driver_open();
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpu_msr_driver_open(PyObject *self, PyObject *noarg)
{
  struct msr_driver_t * result;
  PyObject *pyresult;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpu_msr_driver_open(); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  (void)noarg; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(67));
  return pyresult;
}
#else
#  define _cffi_f_cpu_msr_driver_open _cffi_d_cpu_msr_driver_open
#endif

static struct msr_driver_t * _cffi_d_cpu_msr_driver_open_core(unsigned int x0)
{
  return cpu_msr_driver_open_core(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpu_msr_driver_open_core(PyObject *self, PyObject *arg0)
{
  unsigned int x0;
  struct msr_driver_t * result;
  PyObject *pyresult;

  x0 = _cffi_to_c_int(arg0, unsigned int);
  if (x0 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpu_msr_driver_open_core(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(67));
  return pyresult;
}
#else
#  define _cffi_f_cpu_msr_driver_open_core _cffi_d_cpu_msr_driver_open_core
#endif

static int _cffi_d_cpu_msrinfo(struct msr_driver_t * x0, cpu_msrinfo_request_t x1)
{
  return cpu_msrinfo(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpu_msrinfo(PyObject *self, PyObject *args)
{
  struct msr_driver_t * x0;
  cpu_msrinfo_request_t x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpu_msrinfo", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(67), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct msr_driver_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(67), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  if (_cffi_to_c((char *)&x1, _cffi_type(75), arg1) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpu_msrinfo(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpu_msrinfo _cffi_d_cpu_msrinfo
#endif

static char const * _cffi_d_cpu_purpose_str(cpu_purpose_t x0)
{
  return cpu_purpose_str(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpu_purpose_str(PyObject *self, PyObject *arg0)
{
  cpu_purpose_t x0;
  char const * result;
  PyObject *pyresult;

  if (_cffi_to_c((char *)&x0, _cffi_type(18), arg0) < 0)
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpu_purpose_str(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(45));
  return pyresult;
}
#else
#  define _cffi_f_cpu_purpose_str _cffi_d_cpu_purpose_str
#endif

static int _cffi_d_cpu_rdmsr(struct msr_driver_t * x0, unsigned int x1, unsigned long * x2)
{
  return cpu_rdmsr(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpu_rdmsr(PyObject *self, PyObject *args)
{
  struct msr_driver_t * x0;
  unsigned int x1;
  unsigned long * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "cpu_rdmsr", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(67), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct msr_driver_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(67), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned int);
  if (x1 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(82), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (unsigned long *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(82), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpu_rdmsr(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpu_rdmsr _cffi_d_cpu_rdmsr
#endif

static int _cffi_d_cpu_rdmsr_range(struct msr_driver_t * x0, unsigned int x1, unsigned char x2, unsigned char x3, unsigned long * x4)
{
  return cpu_rdmsr_range(x0, x1, x2, x3, x4);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpu_rdmsr_range(PyObject *self, PyObject *args)
{
  struct msr_driver_t * x0;
  unsigned int x1;
  unsigned char x2;
  unsigned char x3;
  unsigned long * x4;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;

  if (!PyArg_UnpackTuple(args, "cpu_rdmsr_range", 5, 5, &arg0, &arg1, &arg2, &arg3, &arg4))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(67), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct msr_driver_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(67), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned int);
  if (x1 == (unsigned int)-1 && PyErr_Occurred())
    return NULL;

  x2 = _cffi_to_c_int(arg2, unsigned char);
  if (x2 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  x3 = _cffi_to_c_int(arg3, unsigned char);
  if (x3 == (unsigned char)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(82), arg4, (char **)&x4);
  if (datasize != 0) {
    x4 = ((size_t)datasize) <= 640 ? (unsigned long *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(82), arg4, (char **)&x4,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpu_rdmsr_range(x0, x1, x2, x3, x4); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpu_rdmsr_range _cffi_d_cpu_rdmsr_range
#endif

static void _cffi_d_cpu_rdtsc(unsigned long * x0)
{
  cpu_rdtsc(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpu_rdtsc(PyObject *self, PyObject *arg0)
{
  unsigned long * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(82), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (unsigned long *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(82), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpu_rdtsc(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpu_rdtsc _cffi_d_cpu_rdtsc
#endif

static int _cffi_d_cpu_request_core_type(cpu_purpose_t x0, struct cpu_raw_data_array_t * x1, struct cpu_id_t * x2)
{
  return cpu_request_core_type(x0, x1, x2);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpu_request_core_type(PyObject *self, PyObject *args)
{
  cpu_purpose_t x0;
  struct cpu_raw_data_array_t * x1;
  struct cpu_id_t * x2;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;
  PyObject *arg2;

  if (!PyArg_UnpackTuple(args, "cpu_request_core_type", 3, 3, &arg0, &arg1, &arg2))
    return NULL;

  if (_cffi_to_c((char *)&x0, _cffi_type(18), arg0) < 0)
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(30), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (struct cpu_raw_data_array_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(30), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(26), arg2, (char **)&x2);
  if (datasize != 0) {
    x2 = ((size_t)datasize) <= 640 ? (struct cpu_id_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(26), arg2, (char **)&x2,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpu_request_core_type(x0, x1, x2); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpu_request_core_type _cffi_d_cpu_request_core_type
#endif

static void _cffi_d_cpu_tsc_mark(struct cpu_mark_t * x0)
{
  cpu_tsc_mark(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpu_tsc_mark(PyObject *self, PyObject *arg0)
{
  struct cpu_mark_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(38), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct cpu_mark_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(38), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpu_tsc_mark(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpu_tsc_mark _cffi_d_cpu_tsc_mark
#endif

static void _cffi_d_cpu_tsc_unmark(struct cpu_mark_t * x0)
{
  cpu_tsc_unmark(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpu_tsc_unmark(PyObject *self, PyObject *arg0)
{
  struct cpu_mark_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(38), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct cpu_mark_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(38), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpu_tsc_unmark(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpu_tsc_unmark _cffi_d_cpu_tsc_unmark
#endif

static int _cffi_d_cpuid_deserialize_all_raw_data(struct cpu_raw_data_array_t * x0, char const * x1)
{
  return cpuid_deserialize_all_raw_data(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpuid_deserialize_all_raw_data(PyObject *self, PyObject *args)
{
  struct cpu_raw_data_array_t * x0;
  char const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpuid_deserialize_all_raw_data", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(30), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct cpu_raw_data_array_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(30), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpuid_deserialize_all_raw_data(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpuid_deserialize_all_raw_data _cffi_d_cpuid_deserialize_all_raw_data
#endif

static int _cffi_d_cpuid_deserialize_raw_data(struct cpu_raw_data_t * x0, char const * x1)
{
  return cpuid_deserialize_raw_data(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpuid_deserialize_raw_data(PyObject *self, PyObject *args)
{
  struct cpu_raw_data_t * x0;
  char const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpuid_deserialize_raw_data", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(25), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct cpu_raw_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(25), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpuid_deserialize_raw_data(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpuid_deserialize_raw_data _cffi_d_cpuid_deserialize_raw_data
#endif

static char const * _cffi_d_cpuid_error(void)
{
  return cpuid_error();
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpuid_error(PyObject *self, PyObject *noarg)
{
  char const * result;
  PyObject *pyresult;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpuid_error(); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  (void)noarg; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(45));
  return pyresult;
}
#else
#  define _cffi_f_cpuid_error _cffi_d_cpuid_error
#endif

static void _cffi_d_cpuid_free_cpu_list(struct cpu_list_t * x0)
{
  cpuid_free_cpu_list(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpuid_free_cpu_list(PyObject *self, PyObject *arg0)
{
  struct cpu_list_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(105), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct cpu_list_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(105), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpuid_free_cpu_list(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpuid_free_cpu_list _cffi_d_cpuid_free_cpu_list
#endif

static void _cffi_d_cpuid_free_raw_data_array(struct cpu_raw_data_array_t * x0)
{
  cpuid_free_raw_data_array(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpuid_free_raw_data_array(PyObject *self, PyObject *arg0)
{
  struct cpu_raw_data_array_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(30), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct cpu_raw_data_array_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(30), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpuid_free_raw_data_array(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpuid_free_raw_data_array _cffi_d_cpuid_free_raw_data_array
#endif

static void _cffi_d_cpuid_free_system_id(struct system_id_t * x0)
{
  cpuid_free_system_id(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpuid_free_system_id(PyObject *self, PyObject *arg0)
{
  struct system_id_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(49), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct system_id_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(49), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpuid_free_system_id(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpuid_free_system_id _cffi_d_cpuid_free_system_id
#endif

static int _cffi_d_cpuid_get_all_raw_data(struct cpu_raw_data_array_t * x0)
{
  return cpuid_get_all_raw_data(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpuid_get_all_raw_data(PyObject *self, PyObject *arg0)
{
  struct cpu_raw_data_array_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(30), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct cpu_raw_data_array_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(30), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpuid_get_all_raw_data(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpuid_get_all_raw_data _cffi_d_cpuid_get_all_raw_data
#endif

static void _cffi_d_cpuid_get_cpu_list(cpu_vendor_t x0, struct cpu_list_t * x1)
{
  cpuid_get_cpu_list(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpuid_get_cpu_list(PyObject *self, PyObject *args)
{
  cpu_vendor_t x0;
  struct cpu_list_t * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpuid_get_cpu_list", 2, 2, &arg0, &arg1))
    return NULL;

  if (_cffi_to_c((char *)&x0, _cffi_type(104), arg0) < 0)
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(105), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (struct cpu_list_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(105), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpuid_get_cpu_list(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpuid_get_cpu_list _cffi_d_cpuid_get_cpu_list
#endif

static struct cpu_epc_t _cffi_d_cpuid_get_epc(int x0, struct cpu_raw_data_t const * x1)
{
  return cpuid_get_epc(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpuid_get_epc(PyObject *self, PyObject *args)
{
  int x0;
  struct cpu_raw_data_t const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  struct cpu_epc_t result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpuid_get_epc", 2, 2, &arg0, &arg1))
    return NULL;

  x0 = _cffi_to_c_int(arg0, int);
  if (x0 == (int)-1 && PyErr_Occurred())
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(93), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (struct cpu_raw_data_t const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(93), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpuid_get_epc(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_struct((char *)&result, _cffi_type(155));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
static void _cffi_f_cpuid_get_epc(struct cpu_epc_t *result, int x0, struct cpu_raw_data_t const * x1)
{
  { *result = cpuid_get_epc(x0, x1); }
}
#endif

static hypervisor_vendor_t _cffi_d_cpuid_get_hypervisor(struct cpu_raw_data_t * x0, struct cpu_id_t * x1)
{
  return cpuid_get_hypervisor(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpuid_get_hypervisor(PyObject *self, PyObject *args)
{
  struct cpu_raw_data_t * x0;
  struct cpu_id_t * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  hypervisor_vendor_t result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpuid_get_hypervisor", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(25), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct cpu_raw_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(25), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(26), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (struct cpu_id_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(26), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpuid_get_hypervisor(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(148));
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpuid_get_hypervisor _cffi_d_cpuid_get_hypervisor
#endif

static int _cffi_d_cpuid_get_raw_data(struct cpu_raw_data_t * x0)
{
  return cpuid_get_raw_data(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpuid_get_raw_data(PyObject *self, PyObject *arg0)
{
  struct cpu_raw_data_t * x0;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(25), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct cpu_raw_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(25), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpuid_get_raw_data(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpuid_get_raw_data _cffi_d_cpuid_get_raw_data
#endif

static int _cffi_d_cpuid_get_raw_data_core(struct cpu_raw_data_t * x0, unsigned short x1)
{
  return cpuid_get_raw_data_core(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpuid_get_raw_data_core(PyObject *self, PyObject *args)
{
  struct cpu_raw_data_t * x0;
  unsigned short x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpuid_get_raw_data_core", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(25), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct cpu_raw_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(25), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  x1 = _cffi_to_c_int(arg1, unsigned short);
  if (x1 == (unsigned short)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpuid_get_raw_data_core(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpuid_get_raw_data_core _cffi_d_cpuid_get_raw_data_core
#endif

static int _cffi_d_cpuid_get_total_cpus(void)
{
  return cpuid_get_total_cpus();
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpuid_get_total_cpus(PyObject *self, PyObject *noarg)
{
  int result;
  PyObject *pyresult;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpuid_get_total_cpus(); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  (void)noarg; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  return pyresult;
}
#else
#  define _cffi_f_cpuid_get_total_cpus _cffi_d_cpuid_get_total_cpus
#endif

static cpu_vendor_t _cffi_d_cpuid_get_vendor(void)
{
  return cpuid_get_vendor();
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpuid_get_vendor(PyObject *self, PyObject *noarg)
{
  cpu_vendor_t result;
  PyObject *pyresult;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpuid_get_vendor(); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  (void)noarg; /* unused */
  pyresult = _cffi_from_c_deref((char *)&result, _cffi_type(104));
  return pyresult;
}
#else
#  define _cffi_f_cpuid_get_vendor _cffi_d_cpuid_get_vendor
#endif

static char const * _cffi_d_cpuid_lib_version(void)
{
  return cpuid_lib_version();
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpuid_lib_version(PyObject *self, PyObject *noarg)
{
  char const * result;
  PyObject *pyresult;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpuid_lib_version(); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  (void)noarg; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(45));
  return pyresult;
}
#else
#  define _cffi_f_cpuid_lib_version _cffi_d_cpuid_lib_version
#endif

static int _cffi_d_cpuid_present(void)
{
  return cpuid_present();
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpuid_present(PyObject *self, PyObject *noarg)
{
  int result;
  PyObject *pyresult;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpuid_present(); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  (void)noarg; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  return pyresult;
}
#else
#  define _cffi_f_cpuid_present _cffi_d_cpuid_present
#endif

static int _cffi_d_cpuid_serialize_all_raw_data(struct cpu_raw_data_array_t * x0, char const * x1)
{
  return cpuid_serialize_all_raw_data(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpuid_serialize_all_raw_data(PyObject *self, PyObject *args)
{
  struct cpu_raw_data_array_t * x0;
  char const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpuid_serialize_all_raw_data", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(30), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct cpu_raw_data_array_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(30), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpuid_serialize_all_raw_data(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpuid_serialize_all_raw_data _cffi_d_cpuid_serialize_all_raw_data
#endif

static int _cffi_d_cpuid_serialize_raw_data(struct cpu_raw_data_t * x0, char const * x1)
{
  return cpuid_serialize_raw_data(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpuid_serialize_raw_data(PyObject *self, PyObject *args)
{
  struct cpu_raw_data_t * x0;
  char const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "cpuid_serialize_raw_data", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(25), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct cpu_raw_data_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(25), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpuid_serialize_raw_data(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_cpuid_serialize_raw_data _cffi_d_cpuid_serialize_raw_data
#endif

static void _cffi_d_cpuid_set_verbosiness_level(int x0)
{
  cpuid_set_verbosiness_level(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpuid_set_verbosiness_level(PyObject *self, PyObject *arg0)
{
  int x0;

  x0 = _cffi_to_c_int(arg0, int);
  if (x0 == (int)-1 && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { cpuid_set_verbosiness_level(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  Py_INCREF(Py_None);
  return Py_None;
}
#else
#  define _cffi_f_cpuid_set_verbosiness_level _cffi_d_cpuid_set_verbosiness_level
#endif

static void(* _cffi_d_cpuid_set_warn_function(void(* x0)(char const *)))(char const *)
{
  return cpuid_set_warn_function(x0);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_cpuid_set_warn_function(PyObject *self, PyObject *arg0)
{
  void(* x0)(char const *);
  void(* result)(char const *);
  PyObject *pyresult;

  x0 = (void(*)(char const *))_cffi_to_c_pointer(arg0, _cffi_type(133));
  if (x0 == (void(*)(char const *))NULL && PyErr_Occurred())
    return NULL;

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = cpuid_set_warn_function(x0); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_pointer((char *)result, _cffi_type(133));
  return pyresult;
}
#else
#  define _cffi_f_cpuid_set_warn_function _cffi_d_cpuid_set_warn_function
#endif

static int _cffi_d_msr_serialize_raw_data(struct msr_driver_t * x0, char const * x1)
{
  return msr_serialize_raw_data(x0, x1);
}
#ifndef PYPY_VERSION
static PyObject *
_cffi_f_msr_serialize_raw_data(PyObject *self, PyObject *args)
{
  struct msr_driver_t * x0;
  char const * x1;
  Py_ssize_t datasize;
  struct _cffi_freeme_s *large_args_free = NULL;
  int result;
  PyObject *pyresult;
  PyObject *arg0;
  PyObject *arg1;

  if (!PyArg_UnpackTuple(args, "msr_serialize_raw_data", 2, 2, &arg0, &arg1))
    return NULL;

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(67), arg0, (char **)&x0);
  if (datasize != 0) {
    x0 = ((size_t)datasize) <= 640 ? (struct msr_driver_t *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(67), arg0, (char **)&x0,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  datasize = _cffi_prepare_pointer_call_argument(
      _cffi_type(45), arg1, (char **)&x1);
  if (datasize != 0) {
    x1 = ((size_t)datasize) <= 640 ? (char const *)alloca((size_t)datasize) : NULL;
    if (_cffi_convert_array_argument(_cffi_type(45), arg1, (char **)&x1,
            datasize, &large_args_free) < 0)
      return NULL;
  }

  Py_BEGIN_ALLOW_THREADS
  _cffi_restore_errno();
  { result = msr_serialize_raw_data(x0, x1); }
  _cffi_save_errno();
  Py_END_ALLOW_THREADS

  (void)self; /* unused */
  pyresult = _cffi_from_c_int(result, int);
  if (large_args_free != NULL) _cffi_free_array_arguments(large_args_free);
  return pyresult;
}
#else
#  define _cffi_f_msr_serialize_raw_data _cffi_d_msr_serialize_raw_data
#endif

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_arm_id_t(struct arm_id_t *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->implementer) | 0);  /* check that 'struct arm_id_t.implementer' is an integer */
  (void)((p->variant) | 0);  /* check that 'struct arm_id_t.variant' is an integer */
  (void)((p->part_num) | 0);  /* check that 'struct arm_id_t.part_num' is an integer */
  (void)((p->revision) | 0);  /* check that 'struct arm_id_t.revision' is an integer */
}
struct _cffi_align_struct_arm_id_t { char x; struct arm_id_t y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_cpu_epc_t(struct cpu_epc_t *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->start_addr) | 0);  /* check that 'struct cpu_epc_t.start_addr' is an integer */
  (void)((p->length) | 0);  /* check that 'struct cpu_epc_t.length' is an integer */
}
struct _cffi_align_struct_cpu_epc_t { char x; struct cpu_epc_t y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_cpu_id_t(struct cpu_id_t *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { cpu_architecture_t *tmp = &p->architecture; (void)tmp; }
  { cpu_feature_level_t *tmp = &p->feature_level; (void)tmp; }
  { char(*tmp)[16] = &p->vendor_str; (void)tmp; }
  { char(*tmp)[64] = &p->brand_str; (void)tmp; }
  { cpu_vendor_t *tmp = &p->vendor; (void)tmp; }
  { unsigned char(*tmp)[384] = &p->flags; (void)tmp; }
  (void)((p->family) | 0);  /* check that 'struct cpu_id_t.family' is an integer */
  (void)((p->model) | 0);  /* check that 'struct cpu_id_t.model' is an integer */
  (void)((p->stepping) | 0);  /* check that 'struct cpu_id_t.stepping' is an integer */
  (void)((p->ext_family) | 0);  /* check that 'struct cpu_id_t.ext_family' is an integer */
  (void)((p->ext_model) | 0);  /* check that 'struct cpu_id_t.ext_model' is an integer */
  { struct x86_id_t *tmp = &p->x86; (void)tmp; }
  { struct arm_id_t *tmp = &p->arm; (void)tmp; }
  (void)((p->num_cores) | 0);  /* check that 'struct cpu_id_t.num_cores' is an integer */
  (void)((p->num_logical_cpus) | 0);  /* check that 'struct cpu_id_t.num_logical_cpus' is an integer */
  (void)((p->total_logical_cpus) | 0);  /* check that 'struct cpu_id_t.total_logical_cpus' is an integer */
  (void)((p->l1_data_cache) | 0);  /* check that 'struct cpu_id_t.l1_data_cache' is an integer */
  (void)((p->l1_instruction_cache) | 0);  /* check that 'struct cpu_id_t.l1_instruction_cache' is an integer */
  (void)((p->l2_cache) | 0);  /* check that 'struct cpu_id_t.l2_cache' is an integer */
  (void)((p->l3_cache) | 0);  /* check that 'struct cpu_id_t.l3_cache' is an integer */
  (void)((p->l4_cache) | 0);  /* check that 'struct cpu_id_t.l4_cache' is an integer */
  (void)((p->l1_assoc) | 0);  /* check that 'struct cpu_id_t.l1_assoc' is an integer */
  (void)((p->l1_data_assoc) | 0);  /* check that 'struct cpu_id_t.l1_data_assoc' is an integer */
  (void)((p->l1_instruction_assoc) | 0);  /* check that 'struct cpu_id_t.l1_instruction_assoc' is an integer */
  (void)((p->l2_assoc) | 0);  /* check that 'struct cpu_id_t.l2_assoc' is an integer */
  (void)((p->l3_assoc) | 0);  /* check that 'struct cpu_id_t.l3_assoc' is an integer */
  (void)((p->l4_assoc) | 0);  /* check that 'struct cpu_id_t.l4_assoc' is an integer */
  (void)((p->l1_cacheline) | 0);  /* check that 'struct cpu_id_t.l1_cacheline' is an integer */
  (void)((p->l1_data_cacheline) | 0);  /* check that 'struct cpu_id_t.l1_data_cacheline' is an integer */
  (void)((p->l1_instruction_cacheline) | 0);  /* check that 'struct cpu_id_t.l1_instruction_cacheline' is an integer */
  (void)((p->l2_cacheline) | 0);  /* check that 'struct cpu_id_t.l2_cacheline' is an integer */
  (void)((p->l3_cacheline) | 0);  /* check that 'struct cpu_id_t.l3_cacheline' is an integer */
  (void)((p->l4_cacheline) | 0);  /* check that 'struct cpu_id_t.l4_cacheline' is an integer */
  (void)((p->l1_data_instances) | 0);  /* check that 'struct cpu_id_t.l1_data_instances' is an integer */
  (void)((p->l1_instruction_instances) | 0);  /* check that 'struct cpu_id_t.l1_instruction_instances' is an integer */
  (void)((p->l2_instances) | 0);  /* check that 'struct cpu_id_t.l2_instances' is an integer */
  (void)((p->l3_instances) | 0);  /* check that 'struct cpu_id_t.l3_instances' is an integer */
  (void)((p->l4_instances) | 0);  /* check that 'struct cpu_id_t.l4_instances' is an integer */
  { char(*tmp)[64] = &p->cpu_codename; (void)tmp; }
  (void)((p->sse_size) | 0);  /* check that 'struct cpu_id_t.sse_size' is an integer */
  { unsigned char(*tmp)[16] = &p->detection_hints; (void)tmp; }
  { struct cpu_sgx_t *tmp = &p->sgx; (void)tmp; }
  { cpu_affinity_mask_t *tmp = &p->affinity_mask; (void)tmp; }
  { cpu_purpose_t *tmp = &p->purpose; (void)tmp; }
}
struct _cffi_align_struct_cpu_id_t { char x; struct cpu_id_t y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_cpu_list_t(struct cpu_list_t *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->num_entries) | 0);  /* check that 'struct cpu_list_t.num_entries' is an integer */
  { char * * *tmp = &p->names; (void)tmp; }
}
struct _cffi_align_struct_cpu_list_t { char x; struct cpu_list_t y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_cpu_mark_t(struct cpu_mark_t *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->tsc) | 0);  /* check that 'struct cpu_mark_t.tsc' is an integer */
  (void)((p->sys_clock) | 0);  /* check that 'struct cpu_mark_t.sys_clock' is an integer */
}
struct _cffi_align_struct_cpu_mark_t { char x; struct cpu_mark_t y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_cpu_raw_data_array_t(struct cpu_raw_data_array_t *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->with_affinity) | 0);  /* check that 'struct cpu_raw_data_array_t.with_affinity' is an integer */
  (void)((p->num_raw) | 0);  /* check that 'struct cpu_raw_data_array_t.num_raw' is an integer */
  { struct cpu_raw_data_t * *tmp = &p->raw; (void)tmp; }
}
struct _cffi_align_struct_cpu_raw_data_array_t { char x; struct cpu_raw_data_array_t y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_cpu_raw_data_t(struct cpu_raw_data_t *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  { unsigned int(*tmp)[32][4] = &p->basic_cpuid; (void)tmp; }
  { unsigned int(*tmp)[32][4] = &p->ext_cpuid; (void)tmp; }
  { unsigned int(*tmp)[8][4] = &p->intel_fn4; (void)tmp; }
  { unsigned int(*tmp)[4][4] = &p->intel_fn11; (void)tmp; }
  { unsigned int(*tmp)[4][4] = &p->intel_fn12h; (void)tmp; }
  { unsigned int(*tmp)[4][4] = &p->intel_fn14h; (void)tmp; }
  { unsigned int(*tmp)[4][4] = &p->amd_fn8000001dh; (void)tmp; }
  { unsigned int(*tmp)[4][4] = &p->amd_fn80000026h; (void)tmp; }
  (void)((p->arm_midr) | 0);  /* check that 'struct cpu_raw_data_t.arm_midr' is an integer */
  (void)((p->arm_mpidr) | 0);  /* check that 'struct cpu_raw_data_t.arm_mpidr' is an integer */
  (void)((p->arm_revidr) | 0);  /* check that 'struct cpu_raw_data_t.arm_revidr' is an integer */
  { unsigned int(*tmp)[1] = &p->arm_id_afr; (void)tmp; }
  { unsigned int(*tmp)[2] = &p->arm_id_dfr; (void)tmp; }
  { unsigned int(*tmp)[7] = &p->arm_id_isar; (void)tmp; }
  { unsigned int(*tmp)[6] = &p->arm_id_mmfr; (void)tmp; }
  { unsigned int(*tmp)[3] = &p->arm_id_pfr; (void)tmp; }
  { unsigned long(*tmp)[2] = &p->arm_id_aa64afr; (void)tmp; }
  { unsigned long(*tmp)[2] = &p->arm_id_aa64dfr; (void)tmp; }
  { unsigned long(*tmp)[3] = &p->arm_id_aa64isar; (void)tmp; }
  { unsigned long(*tmp)[5] = &p->arm_id_aa64mmfr; (void)tmp; }
  { unsigned long(*tmp)[3] = &p->arm_id_aa64pfr; (void)tmp; }
  { unsigned long(*tmp)[1] = &p->arm_id_aa64smfr; (void)tmp; }
  { unsigned long(*tmp)[1] = &p->arm_id_aa64zfr; (void)tmp; }
}
struct _cffi_align_struct_cpu_raw_data_t { char x; struct cpu_raw_data_t y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_cpu_sgx_t(struct cpu_sgx_t *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->present) | 0);  /* check that 'struct cpu_sgx_t.present' is an integer */
  (void)((p->max_enclave_32bit) | 0);  /* check that 'struct cpu_sgx_t.max_enclave_32bit' is an integer */
  (void)((p->max_enclave_64bit) | 0);  /* check that 'struct cpu_sgx_t.max_enclave_64bit' is an integer */
  { unsigned char(*tmp)[14] = &p->flags; (void)tmp; }
  (void)((p->num_epc_sections) | 0);  /* check that 'struct cpu_sgx_t.num_epc_sections' is an integer */
  (void)((p->misc_select) | 0);  /* check that 'struct cpu_sgx_t.misc_select' is an integer */
  (void)((p->secs_attributes) | 0);  /* check that 'struct cpu_sgx_t.secs_attributes' is an integer */
  (void)((p->secs_xfrm) | 0);  /* check that 'struct cpu_sgx_t.secs_xfrm' is an integer */
}
struct _cffi_align_struct_cpu_sgx_t { char x; struct cpu_sgx_t y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_system_id_t(struct system_id_t *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->num_cpu_types) | 0);  /* check that 'struct system_id_t.num_cpu_types' is an integer */
  { struct cpu_id_t * *tmp = &p->cpu_types; (void)tmp; }
  (void)((p->l1_data_total_instances) | 0);  /* check that 'struct system_id_t.l1_data_total_instances' is an integer */
  (void)((p->l1_instruction_total_instances) | 0);  /* check that 'struct system_id_t.l1_instruction_total_instances' is an integer */
  (void)((p->l2_total_instances) | 0);  /* check that 'struct system_id_t.l2_total_instances' is an integer */
  (void)((p->l3_total_instances) | 0);  /* check that 'struct system_id_t.l3_total_instances' is an integer */
  (void)((p->l4_total_instances) | 0);  /* check that 'struct system_id_t.l4_total_instances' is an integer */
}
struct _cffi_align_struct_system_id_t { char x; struct system_id_t y; };

_CFFI_UNUSED_FN
static void _cffi_checkfld_struct_x86_id_t(struct x86_id_t *p)
{
  /* only to generate compile-time warnings or errors */
  (void)p;
  (void)((p->family) | 0);  /* check that 'struct x86_id_t.family' is an integer */
  (void)((p->model) | 0);  /* check that 'struct x86_id_t.model' is an integer */
  (void)((p->stepping) | 0);  /* check that 'struct x86_id_t.stepping' is an integer */
  (void)((p->ext_family) | 0);  /* check that 'struct x86_id_t.ext_family' is an integer */
  (void)((p->ext_model) | 0);  /* check that 'struct x86_id_t.ext_model' is an integer */
  (void)((p->sse_size) | 0);  /* check that 'struct x86_id_t.sse_size' is an integer */
  { struct cpu_sgx_t *tmp = &p->sgx; (void)tmp; }
}
struct _cffi_align_struct_x86_id_t { char x; struct x86_id_t y; };

static const struct _cffi_global_s _cffi_globals[] = {
  { "ARCHITECTURE_ARM", (void *)_cffi_const_ARCHITECTURE_ARM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ARCHITECTURE_UNKNOWN", (void *)_cffi_const_ARCHITECTURE_UNKNOWN, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ARCHITECTURE_X86", (void *)_cffi_const_ARCHITECTURE_X86, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_100MHZSTEPS", (void *)_cffi_const_CPU_FEATURE_100MHZSTEPS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_3DNOW", (void *)_cffi_const_CPU_FEATURE_3DNOW, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_3DNOWEXT", (void *)_cffi_const_CPU_FEATURE_3DNOWEXT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_3DNOWPREFETCH", (void *)_cffi_const_CPU_FEATURE_3DNOWPREFETCH, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_AA32BF16", (void *)_cffi_const_CPU_FEATURE_AA32BF16, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_AA32HPD", (void *)_cffi_const_CPU_FEATURE_AA32HPD, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_AA32I8MM", (void *)_cffi_const_CPU_FEATURE_AA32I8MM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_ABLE", (void *)_cffi_const_CPU_FEATURE_ABLE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_ABM", (void *)_cffi_const_CPU_FEATURE_ABM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_ACPI", (void *)_cffi_const_CPU_FEATURE_ACPI, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_ADERR", (void *)_cffi_const_CPU_FEATURE_ADERR, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_ADVMULTS", (void *)_cffi_const_CPU_FEATURE_ADVMULTS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_ADVMULTU", (void *)_cffi_const_CPU_FEATURE_ADVMULTU, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_ADVSIMD", (void *)_cffi_const_CPU_FEATURE_ADVSIMD, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_ADX", (void *)_cffi_const_CPU_FEATURE_ADX, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_AES", (void *)_cffi_const_CPU_FEATURE_AES, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_AFP", (void *)_cffi_const_CPU_FEATURE_AFP, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_AIE", (void *)_cffi_const_CPU_FEATURE_AIE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_AMUV1", (void *)_cffi_const_CPU_FEATURE_AMUV1, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_AMUV1P1", (void *)_cffi_const_CPU_FEATURE_AMUV1P1, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_ANERR", (void *)_cffi_const_CPU_FEATURE_ANERR, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_APERFMPERF", (void *)_cffi_const_CPU_FEATURE_APERFMPERF, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_APIC", (void *)_cffi_const_CPU_FEATURE_APIC, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_ASID16", (void *)_cffi_const_CPU_FEATURE_ASID16, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_ATS1A", (void *)_cffi_const_CPU_FEATURE_ATS1A, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_AVX", (void *)_cffi_const_CPU_FEATURE_AVX, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_AVX2", (void *)_cffi_const_CPU_FEATURE_AVX2, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_AVX512BW", (void *)_cffi_const_CPU_FEATURE_AVX512BW, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_AVX512CD", (void *)_cffi_const_CPU_FEATURE_AVX512CD, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_AVX512DQ", (void *)_cffi_const_CPU_FEATURE_AVX512DQ, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_AVX512ER", (void *)_cffi_const_CPU_FEATURE_AVX512ER, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_AVX512F", (void *)_cffi_const_CPU_FEATURE_AVX512F, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_AVX512PF", (void *)_cffi_const_CPU_FEATURE_AVX512PF, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_AVX512VBMI", (void *)_cffi_const_CPU_FEATURE_AVX512VBMI, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_AVX512VBMI2", (void *)_cffi_const_CPU_FEATURE_AVX512VBMI2, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_AVX512VL", (void *)_cffi_const_CPU_FEATURE_AVX512VL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_AVX512VNNI", (void *)_cffi_const_CPU_FEATURE_AVX512VNNI, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_BBM", (void *)_cffi_const_CPU_FEATURE_BBM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_BF16", (void *)_cffi_const_CPU_FEATURE_BF16, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_BMI1", (void *)_cffi_const_CPU_FEATURE_BMI1, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_BMI2", (void *)_cffi_const_CPU_FEATURE_BMI2, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_BRBE", (void *)_cffi_const_CPU_FEATURE_BRBE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_BRBEV1P1", (void *)_cffi_const_CPU_FEATURE_BRBEV1P1, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_BTI", (void *)_cffi_const_CPU_FEATURE_BTI, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_BWE", (void *)_cffi_const_CPU_FEATURE_BWE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_CCIDX", (void *)_cffi_const_CPU_FEATURE_CCIDX, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_CID", (void *)_cffi_const_CPU_FEATURE_CID, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_CLFLUSH", (void *)_cffi_const_CPU_FEATURE_CLFLUSH, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_CLRBHB", (void *)_cffi_const_CPU_FEATURE_CLRBHB, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_CMOV", (void *)_cffi_const_CPU_FEATURE_CMOV, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_CMOW", (void *)_cffi_const_CPU_FEATURE_CMOW, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_CMP_LEGACY", (void *)_cffi_const_CPU_FEATURE_CMP_LEGACY, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_CONSTANT_TSC", (void *)_cffi_const_CPU_FEATURE_CONSTANT_TSC, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_CONSTPACFIELD", (void *)_cffi_const_CPU_FEATURE_CONSTPACFIELD, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_CPB", (void *)_cffi_const_CPU_FEATURE_CPB, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_CRC32", (void *)_cffi_const_CPU_FEATURE_CRC32, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_CSSC", (void *)_cffi_const_CPU_FEATURE_CSSC, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_CSV2", (void *)_cffi_const_CPU_FEATURE_CSV2, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_CSV2_1P1", (void *)_cffi_const_CPU_FEATURE_CSV2_1P1, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_CSV2_1P2", (void *)_cffi_const_CPU_FEATURE_CSV2_1P2, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_CSV2_2", (void *)_cffi_const_CPU_FEATURE_CSV2_2, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_CSV2_3", (void *)_cffi_const_CPU_FEATURE_CSV2_3, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_CSV3", (void *)_cffi_const_CPU_FEATURE_CSV3, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_CX16", (void *)_cffi_const_CPU_FEATURE_CX16, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_CX8", (void *)_cffi_const_CPU_FEATURE_CX8, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_D128", (void *)_cffi_const_CPU_FEATURE_D128, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_DCA", (void *)_cffi_const_CPU_FEATURE_DCA, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_DE", (void *)_cffi_const_CPU_FEATURE_DE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_DEBUGV6", (void *)_cffi_const_CPU_FEATURE_DEBUGV6, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_DEBUGV6P1", (void *)_cffi_const_CPU_FEATURE_DEBUGV6P1, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_DEBUGV7", (void *)_cffi_const_CPU_FEATURE_DEBUGV7, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_DEBUGV7P1", (void *)_cffi_const_CPU_FEATURE_DEBUGV7P1, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_DEBUGV8P2", (void *)_cffi_const_CPU_FEATURE_DEBUGV8P2, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_DEBUGV8P4", (void *)_cffi_const_CPU_FEATURE_DEBUGV8P4, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_DEBUGV8P8", (void *)_cffi_const_CPU_FEATURE_DEBUGV8P8, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_DEBUGV8P9", (void *)_cffi_const_CPU_FEATURE_DEBUGV8P9, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_DGH", (void *)_cffi_const_CPU_FEATURE_DGH, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_DIT", (void *)_cffi_const_CPU_FEATURE_DIT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_DIVIDE", (void *)_cffi_const_CPU_FEATURE_DIVIDE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_DOTPROD", (void *)_cffi_const_CPU_FEATURE_DOTPROD, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_DOUBLEFAULT", (void *)_cffi_const_CPU_FEATURE_DOUBLEFAULT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_DOUBLEFAULT2", (void *)_cffi_const_CPU_FEATURE_DOUBLEFAULT2, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_DOUBLELOCK", (void *)_cffi_const_CPU_FEATURE_DOUBLELOCK, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_DPB", (void *)_cffi_const_CPU_FEATURE_DPB, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_DPB2", (void *)_cffi_const_CPU_FEATURE_DPB2, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_DS_CPL", (void *)_cffi_const_CPU_FEATURE_DS_CPL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_DTS", (void *)_cffi_const_CPU_FEATURE_DTS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_DTS64", (void *)_cffi_const_CPU_FEATURE_DTS64, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_E0PD", (void *)_cffi_const_CPU_FEATURE_E0PD, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_EBEP", (void *)_cffi_const_CPU_FEATURE_EBEP, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_EBF16", (void *)_cffi_const_CPU_FEATURE_EBF16, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_ECBHB", (void *)_cffi_const_CPU_FEATURE_ECBHB, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_ECV", (void *)_cffi_const_CPU_FEATURE_ECV, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_EPAC", (void *)_cffi_const_CPU_FEATURE_EPAC, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_EST", (void *)_cffi_const_CPU_FEATURE_EST, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_ETS2", (void *)_cffi_const_CPU_FEATURE_ETS2, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_EVT", (void *)_cffi_const_CPU_FEATURE_EVT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_EXS", (void *)_cffi_const_CPU_FEATURE_EXS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_F16C", (void *)_cffi_const_CPU_FEATURE_F16C, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_F32MM", (void *)_cffi_const_CPU_FEATURE_F32MM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_F64MM", (void *)_cffi_const_CPU_FEATURE_F64MM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_FCMA", (void *)_cffi_const_CPU_FEATURE_FCMA, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_FGT", (void *)_cffi_const_CPU_FEATURE_FGT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_FGT2", (void *)_cffi_const_CPU_FEATURE_FGT2, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_FHM", (void *)_cffi_const_CPU_FEATURE_FHM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_FID", (void *)_cffi_const_CPU_FEATURE_FID, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_FLAGM", (void *)_cffi_const_CPU_FEATURE_FLAGM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_FLAGM2", (void *)_cffi_const_CPU_FEATURE_FLAGM2, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_FMA3", (void *)_cffi_const_CPU_FEATURE_FMA3, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_FMA4", (void *)_cffi_const_CPU_FEATURE_FMA4, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_FP", (void *)_cffi_const_CPU_FEATURE_FP, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_FP16", (void *)_cffi_const_CPU_FEATURE_FP16, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_FPAC", (void *)_cffi_const_CPU_FEATURE_FPAC, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_FPACCOMBINE", (void *)_cffi_const_CPU_FEATURE_FPACCOMBINE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_FPU", (void *)_cffi_const_CPU_FEATURE_FPU, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_FRINTTS", (void *)_cffi_const_CPU_FEATURE_FRINTTS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_FXSR", (void *)_cffi_const_CPU_FEATURE_FXSR, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_FXSR_OPT", (void *)_cffi_const_CPU_FEATURE_FXSR_OPT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_GCS", (void *)_cffi_const_CPU_FEATURE_GCS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_HAFDBS", (void *)_cffi_const_CPU_FEATURE_HAFDBS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_HAFT", (void *)_cffi_const_CPU_FEATURE_HAFT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_HBC", (void *)_cffi_const_CPU_FEATURE_HBC, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_HCX", (void *)_cffi_const_CPU_FEATURE_HCX, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_HLE", (void *)_cffi_const_CPU_FEATURE_HLE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_HPDS", (void *)_cffi_const_CPU_FEATURE_HPDS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_HPDS2", (void *)_cffi_const_CPU_FEATURE_HPDS2, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_HPMN0", (void *)_cffi_const_CPU_FEATURE_HPMN0, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_HT", (void *)_cffi_const_CPU_FEATURE_HT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_HWPSTATE", (void *)_cffi_const_CPU_FEATURE_HWPSTATE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_HYPERVISOR", (void *)_cffi_const_CPU_FEATURE_HYPERVISOR, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_I8MM", (void *)_cffi_const_CPU_FEATURE_I8MM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_IA64", (void *)_cffi_const_CPU_FEATURE_IA64, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_IBS", (void *)_cffi_const_CPU_FEATURE_IBS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_IDST", (void *)_cffi_const_CPU_FEATURE_IDST, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_IESB", (void *)_cffi_const_CPU_FEATURE_IESB, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_ITE", (void *)_cffi_const_CPU_FEATURE_ITE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_JAZELLE", (void *)_cffi_const_CPU_FEATURE_JAZELLE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_JSCVT", (void *)_cffi_const_CPU_FEATURE_JSCVT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_LAHF_LM", (void *)_cffi_const_CPU_FEATURE_LAHF_LM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_LM", (void *)_cffi_const_CPU_FEATURE_LM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_LOR", (void *)_cffi_const_CPU_FEATURE_LOR, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_LPA", (void *)_cffi_const_CPU_FEATURE_LPA, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_LPA2", (void *)_cffi_const_CPU_FEATURE_LPA2, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_LPAE", (void *)_cffi_const_CPU_FEATURE_LPAE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_LRCPC", (void *)_cffi_const_CPU_FEATURE_LRCPC, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_LRCPC2", (void *)_cffi_const_CPU_FEATURE_LRCPC2, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_LRCPC3", (void *)_cffi_const_CPU_FEATURE_LRCPC3, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_LS64", (void *)_cffi_const_CPU_FEATURE_LS64, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_LS64_ACCDATA", (void *)_cffi_const_CPU_FEATURE_LS64_ACCDATA, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_LS64_V", (void *)_cffi_const_CPU_FEATURE_LS64_V, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_LSE", (void *)_cffi_const_CPU_FEATURE_LSE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_LSE128", (void *)_cffi_const_CPU_FEATURE_LSE128, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_LSE2", (void *)_cffi_const_CPU_FEATURE_LSE2, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_LSMAOC", (void *)_cffi_const_CPU_FEATURE_LSMAOC, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_LVA", (void *)_cffi_const_CPU_FEATURE_LVA, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_LVA3", (void *)_cffi_const_CPU_FEATURE_LVA3, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_MCA", (void *)_cffi_const_CPU_FEATURE_MCA, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_MCE", (void *)_cffi_const_CPU_FEATURE_MCE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_MEC", (void *)_cffi_const_CPU_FEATURE_MEC, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_MISALIGNSSE", (void *)_cffi_const_CPU_FEATURE_MISALIGNSSE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_MIXEDEND", (void *)_cffi_const_CPU_FEATURE_MIXEDEND, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_MIXEDENDEL0", (void *)_cffi_const_CPU_FEATURE_MIXEDENDEL0, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_MMX", (void *)_cffi_const_CPU_FEATURE_MMX, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_MMXEXT", (void *)_cffi_const_CPU_FEATURE_MMXEXT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_MONITOR", (void *)_cffi_const_CPU_FEATURE_MONITOR, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_MOPS", (void *)_cffi_const_CPU_FEATURE_MOPS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_MOVBE", (void *)_cffi_const_CPU_FEATURE_MOVBE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_MPAM", (void *)_cffi_const_CPU_FEATURE_MPAM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_MPAMV0P1", (void *)_cffi_const_CPU_FEATURE_MPAMV0P1, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_MPAMV1P1", (void *)_cffi_const_CPU_FEATURE_MPAMV1P1, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_MSR", (void *)_cffi_const_CPU_FEATURE_MSR, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_MTE", (void *)_cffi_const_CPU_FEATURE_MTE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_MTE2", (void *)_cffi_const_CPU_FEATURE_MTE2, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_MTE3", (void *)_cffi_const_CPU_FEATURE_MTE3, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_MTE4", (void *)_cffi_const_CPU_FEATURE_MTE4, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_MTE_ASYM_FAULT", (void *)_cffi_const_CPU_FEATURE_MTE_ASYM_FAULT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_MTE_ASYNC", (void *)_cffi_const_CPU_FEATURE_MTE_ASYNC, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_MTE_CANONICAL_TAGS", (void *)_cffi_const_CPU_FEATURE_MTE_CANONICAL_TAGS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_MTE_NO_ADDRESS_TAGS", (void *)_cffi_const_CPU_FEATURE_MTE_NO_ADDRESS_TAGS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_MTE_PERM", (void *)_cffi_const_CPU_FEATURE_MTE_PERM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_MTE_STORE_ONLY", (void *)_cffi_const_CPU_FEATURE_MTE_STORE_ONLY, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_MTE_TAGGED_FAR", (void *)_cffi_const_CPU_FEATURE_MTE_TAGGED_FAR, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_MTPMU", (void *)_cffi_const_CPU_FEATURE_MTPMU, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_MTRR", (void *)_cffi_const_CPU_FEATURE_MTRR, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_NMI", (void *)_cffi_const_CPU_FEATURE_NMI, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_NTLBPA", (void *)_cffi_const_CPU_FEATURE_NTLBPA, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_NX", (void *)_cffi_const_CPU_FEATURE_NX, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_OSVW", (void *)_cffi_const_CPU_FEATURE_OSVW, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_OSXSAVE", (void *)_cffi_const_CPU_FEATURE_OSXSAVE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_PA", (void *)_cffi_const_CPU_FEATURE_PA, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_PACIMP", (void *)_cffi_const_CPU_FEATURE_PACIMP, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_PACQARMA3", (void *)_cffi_const_CPU_FEATURE_PACQARMA3, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_PACQARMA5", (void *)_cffi_const_CPU_FEATURE_PACQARMA5, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_PAE", (void *)_cffi_const_CPU_FEATURE_PAE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_PAN", (void *)_cffi_const_CPU_FEATURE_PAN, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_PAN2", (void *)_cffi_const_CPU_FEATURE_PAN2, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_PAN3", (void *)_cffi_const_CPU_FEATURE_PAN3, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_PAT", (void *)_cffi_const_CPU_FEATURE_PAT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_PAUTH", (void *)_cffi_const_CPU_FEATURE_PAUTH, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_PAUTH2", (void *)_cffi_const_CPU_FEATURE_PAUTH2, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_PBE", (void *)_cffi_const_CPU_FEATURE_PBE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_PCLMUL", (void *)_cffi_const_CPU_FEATURE_PCLMUL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_PDCM", (void *)_cffi_const_CPU_FEATURE_PDCM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_PFAR", (void *)_cffi_const_CPU_FEATURE_PFAR, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_PFI", (void *)_cffi_const_CPU_FEATURE_PFI, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_PGE", (void *)_cffi_const_CPU_FEATURE_PGE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_PMULL", (void *)_cffi_const_CPU_FEATURE_PMULL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_PMUV1", (void *)_cffi_const_CPU_FEATURE_PMUV1, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_PMUV2", (void *)_cffi_const_CPU_FEATURE_PMUV2, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_PMUV3", (void *)_cffi_const_CPU_FEATURE_PMUV3, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_PMUV3P1", (void *)_cffi_const_CPU_FEATURE_PMUV3P1, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_PMUV3P4", (void *)_cffi_const_CPU_FEATURE_PMUV3P4, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_PMUV3P5", (void *)_cffi_const_CPU_FEATURE_PMUV3P5, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_PMUV3P7", (void *)_cffi_const_CPU_FEATURE_PMUV3P7, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_PMUV3P8", (void *)_cffi_const_CPU_FEATURE_PMUV3P8, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_PMUV3P9", (void *)_cffi_const_CPU_FEATURE_PMUV3P9, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_PMUV3_ICNTR", (void *)_cffi_const_CPU_FEATURE_PMUV3_ICNTR, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_PMUV3_SS", (void *)_cffi_const_CPU_FEATURE_PMUV3_SS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_PN", (void *)_cffi_const_CPU_FEATURE_PN, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_PNI", (void *)_cffi_const_CPU_FEATURE_PNI, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_POPCNT", (void *)_cffi_const_CPU_FEATURE_POPCNT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_PRFMSLC", (void *)_cffi_const_CPU_FEATURE_PRFMSLC, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_PSE", (void *)_cffi_const_CPU_FEATURE_PSE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_PSE36", (void *)_cffi_const_CPU_FEATURE_PSE36, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_RAS", (void *)_cffi_const_CPU_FEATURE_RAS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_RASV1P1", (void *)_cffi_const_CPU_FEATURE_RASV1P1, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_RASV2", (void *)_cffi_const_CPU_FEATURE_RASV2, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_RDM", (void *)_cffi_const_CPU_FEATURE_RDM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_RDRAND", (void *)_cffi_const_CPU_FEATURE_RDRAND, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_RDSEED", (void *)_cffi_const_CPU_FEATURE_RDSEED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_RDTSCP", (void *)_cffi_const_CPU_FEATURE_RDTSCP, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_RME", (void *)_cffi_const_CPU_FEATURE_RME, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_RNG", (void *)_cffi_const_CPU_FEATURE_RNG, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_RNG_TRAP", (void *)_cffi_const_CPU_FEATURE_RNG_TRAP, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_RPRES", (void *)_cffi_const_CPU_FEATURE_RPRES, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_RPRFM", (void *)_cffi_const_CPU_FEATURE_RPRFM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_RTM", (void *)_cffi_const_CPU_FEATURE_RTM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_S1PIE", (void *)_cffi_const_CPU_FEATURE_S1PIE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_S1POE", (void *)_cffi_const_CPU_FEATURE_S1POE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_S2FWB", (void *)_cffi_const_CPU_FEATURE_S2FWB, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_S2PIE", (void *)_cffi_const_CPU_FEATURE_S2PIE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_S2POE", (void *)_cffi_const_CPU_FEATURE_S2POE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SB", (void *)_cffi_const_CPU_FEATURE_SB, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SCTLR2", (void *)_cffi_const_CPU_FEATURE_SCTLR2, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SEBEP", (void *)_cffi_const_CPU_FEATURE_SEBEP, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SEL2", (void *)_cffi_const_CPU_FEATURE_SEL2, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SEP", (void *)_cffi_const_CPU_FEATURE_SEP, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SGX", (void *)_cffi_const_CPU_FEATURE_SGX, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SHA1", (void *)_cffi_const_CPU_FEATURE_SHA1, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SHA256", (void *)_cffi_const_CPU_FEATURE_SHA256, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SHA3", (void *)_cffi_const_CPU_FEATURE_SHA3, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SHA512", (void *)_cffi_const_CPU_FEATURE_SHA512, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SHA_NI", (void *)_cffi_const_CPU_FEATURE_SHA_NI, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SKINIT", (void *)_cffi_const_CPU_FEATURE_SKINIT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SM3", (void *)_cffi_const_CPU_FEATURE_SM3, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SM4", (void *)_cffi_const_CPU_FEATURE_SM4, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SME", (void *)_cffi_const_CPU_FEATURE_SME, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SME2", (void *)_cffi_const_CPU_FEATURE_SME2, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SME2P1", (void *)_cffi_const_CPU_FEATURE_SME2P1, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SME_F16F16", (void *)_cffi_const_CPU_FEATURE_SME_F16F16, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SME_F64F64", (void *)_cffi_const_CPU_FEATURE_SME_F64F64, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SME_FA64", (void *)_cffi_const_CPU_FEATURE_SME_FA64, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SME_I16I64", (void *)_cffi_const_CPU_FEATURE_SME_I16I64, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SMX", (void *)_cffi_const_CPU_FEATURE_SMX, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SPE", (void *)_cffi_const_CPU_FEATURE_SPE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SPECRES", (void *)_cffi_const_CPU_FEATURE_SPECRES, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SPECRES2", (void *)_cffi_const_CPU_FEATURE_SPECRES2, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SPEV1P1", (void *)_cffi_const_CPU_FEATURE_SPEV1P1, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SPEV1P2", (void *)_cffi_const_CPU_FEATURE_SPEV1P2, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SPEV1P3", (void *)_cffi_const_CPU_FEATURE_SPEV1P3, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SPEV1P4", (void *)_cffi_const_CPU_FEATURE_SPEV1P4, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SPE_DPFZS", (void *)_cffi_const_CPU_FEATURE_SPE_DPFZS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SPMU", (void *)_cffi_const_CPU_FEATURE_SPMU, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SS", (void *)_cffi_const_CPU_FEATURE_SS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SSBS", (void *)_cffi_const_CPU_FEATURE_SSBS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SSBS2", (void *)_cffi_const_CPU_FEATURE_SSBS2, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SSE", (void *)_cffi_const_CPU_FEATURE_SSE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SSE2", (void *)_cffi_const_CPU_FEATURE_SSE2, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SSE4A", (void *)_cffi_const_CPU_FEATURE_SSE4A, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SSE4_1", (void *)_cffi_const_CPU_FEATURE_SSE4_1, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SSE4_2", (void *)_cffi_const_CPU_FEATURE_SSE4_2, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SSE5", (void *)_cffi_const_CPU_FEATURE_SSE5, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SSSE3", (void *)_cffi_const_CPU_FEATURE_SSSE3, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_STC", (void *)_cffi_const_CPU_FEATURE_STC, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SVE", (void *)_cffi_const_CPU_FEATURE_SVE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SVE2", (void *)_cffi_const_CPU_FEATURE_SVE2, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SVE2P1", (void *)_cffi_const_CPU_FEATURE_SVE2P1, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SVE_AES", (void *)_cffi_const_CPU_FEATURE_SVE_AES, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SVE_B16B16", (void *)_cffi_const_CPU_FEATURE_SVE_B16B16, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SVE_BITPERM", (void *)_cffi_const_CPU_FEATURE_SVE_BITPERM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SVE_PMULL128", (void *)_cffi_const_CPU_FEATURE_SVE_PMULL128, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SVE_SHA3", (void *)_cffi_const_CPU_FEATURE_SVE_SHA3, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SVE_SM4", (void *)_cffi_const_CPU_FEATURE_SVE_SM4, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SVM", (void *)_cffi_const_CPU_FEATURE_SVM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SWAP", (void *)_cffi_const_CPU_FEATURE_SWAP, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SYSCALL", (void *)_cffi_const_CPU_FEATURE_SYSCALL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SYSINSTR128", (void *)_cffi_const_CPU_FEATURE_SYSINSTR128, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_SYSREG128", (void *)_cffi_const_CPU_FEATURE_SYSREG128, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_TBM", (void *)_cffi_const_CPU_FEATURE_TBM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_TCR2", (void *)_cffi_const_CPU_FEATURE_TCR2, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_THE", (void *)_cffi_const_CPU_FEATURE_THE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_THUMB", (void *)_cffi_const_CPU_FEATURE_THUMB, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_THUMB2", (void *)_cffi_const_CPU_FEATURE_THUMB2, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_THUMBEE", (void *)_cffi_const_CPU_FEATURE_THUMBEE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_TIDCP1", (void *)_cffi_const_CPU_FEATURE_TIDCP1, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_TLBIOS", (void *)_cffi_const_CPU_FEATURE_TLBIOS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_TLBIRANGE", (void *)_cffi_const_CPU_FEATURE_TLBIRANGE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_TM", (void *)_cffi_const_CPU_FEATURE_TM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_TM2", (void *)_cffi_const_CPU_FEATURE_TM2, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_TME", (void *)_cffi_const_CPU_FEATURE_TME, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_TM_AMD", (void *)_cffi_const_CPU_FEATURE_TM_AMD, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_TRBE", (void *)_cffi_const_CPU_FEATURE_TRBE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_TRBE_EXT", (void *)_cffi_const_CPU_FEATURE_TRBE_EXT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_TRF", (void *)_cffi_const_CPU_FEATURE_TRF, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_TS", (void *)_cffi_const_CPU_FEATURE_TS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_TSC", (void *)_cffi_const_CPU_FEATURE_TSC, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_TTCNP", (void *)_cffi_const_CPU_FEATURE_TTCNP, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_TTL", (void *)_cffi_const_CPU_FEATURE_TTL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_TTP", (void *)_cffi_const_CPU_FEATURE_TTP, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_TTST", (void *)_cffi_const_CPU_FEATURE_TTST, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_TWED", (void *)_cffi_const_CPU_FEATURE_TWED, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_UAO", (void *)_cffi_const_CPU_FEATURE_UAO, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_VHE", (void *)_cffi_const_CPU_FEATURE_VHE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_VID", (void *)_cffi_const_CPU_FEATURE_VID, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_VME", (void *)_cffi_const_CPU_FEATURE_VME, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_VMID16", (void *)_cffi_const_CPU_FEATURE_VMID16, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_VMX", (void *)_cffi_const_CPU_FEATURE_VMX, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_WDT", (void *)_cffi_const_CPU_FEATURE_WDT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_WFXT", (void *)_cffi_const_CPU_FEATURE_WFXT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_X2APIC", (void *)_cffi_const_CPU_FEATURE_X2APIC, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_XD", (void *)_cffi_const_CPU_FEATURE_XD, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_XNX", (void *)_cffi_const_CPU_FEATURE_XNX, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_XOP", (void *)_cffi_const_CPU_FEATURE_XOP, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_XS", (void *)_cffi_const_CPU_FEATURE_XS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_XSAVE", (void *)_cffi_const_CPU_FEATURE_XSAVE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_FEATURE_XTPR", (void *)_cffi_const_CPU_FEATURE_XTPR, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "CPU_HINT_SSE_SIZE_AUTH", (void *)_cffi_const_CPU_HINT_SSE_SIZE_AUTH, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "EAX", (void *)_cffi_const_EAX, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "EBX", (void *)_cffi_const_EBX, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ECX", (void *)_cffi_const_ECX, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "EDX", (void *)_cffi_const_EDX, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ERR_BADFMT", (void *)_cffi_const_ERR_BADFMT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ERR_CPU_UNKN", (void *)_cffi_const_ERR_CPU_UNKN, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ERR_EXTRACT", (void *)_cffi_const_ERR_EXTRACT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ERR_HANDLE", (void *)_cffi_const_ERR_HANDLE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ERR_HANDLE_R", (void *)_cffi_const_ERR_HANDLE_R, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ERR_INVCNB", (void *)_cffi_const_ERR_INVCNB, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ERR_INVMSR", (void *)_cffi_const_ERR_INVMSR, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ERR_INVRANGE", (void *)_cffi_const_ERR_INVRANGE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ERR_IOCTL", (void *)_cffi_const_ERR_IOCTL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ERR_NOT_FOUND", (void *)_cffi_const_ERR_NOT_FOUND, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ERR_NOT_IMP", (void *)_cffi_const_ERR_NOT_IMP, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ERR_NO_CPUID", (void *)_cffi_const_ERR_NO_CPUID, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ERR_NO_DRIVER", (void *)_cffi_const_ERR_NO_DRIVER, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ERR_NO_MEM", (void *)_cffi_const_ERR_NO_MEM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ERR_NO_PERMS", (void *)_cffi_const_ERR_NO_PERMS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ERR_NO_RDMSR", (void *)_cffi_const_ERR_NO_RDMSR, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ERR_NO_RDTSC", (void *)_cffi_const_ERR_NO_RDTSC, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ERR_OK", (void *)_cffi_const_ERR_OK, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ERR_OPEN", (void *)_cffi_const_ERR_OPEN, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "ERR_REQUEST", (void *)_cffi_const_ERR_REQUEST, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "FEATURE_LEVEL_ARM_V1", (void *)_cffi_const_FEATURE_LEVEL_ARM_V1, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "FEATURE_LEVEL_ARM_V2", (void *)_cffi_const_FEATURE_LEVEL_ARM_V2, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "FEATURE_LEVEL_ARM_V3", (void *)_cffi_const_FEATURE_LEVEL_ARM_V3, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "FEATURE_LEVEL_ARM_V4", (void *)_cffi_const_FEATURE_LEVEL_ARM_V4, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "FEATURE_LEVEL_ARM_V4T", (void *)_cffi_const_FEATURE_LEVEL_ARM_V4T, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "FEATURE_LEVEL_ARM_V5", (void *)_cffi_const_FEATURE_LEVEL_ARM_V5, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "FEATURE_LEVEL_ARM_V5T", (void *)_cffi_const_FEATURE_LEVEL_ARM_V5T, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "FEATURE_LEVEL_ARM_V5TE", (void *)_cffi_const_FEATURE_LEVEL_ARM_V5TE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "FEATURE_LEVEL_ARM_V5TEJ", (void *)_cffi_const_FEATURE_LEVEL_ARM_V5TEJ, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "FEATURE_LEVEL_ARM_V6", (void *)_cffi_const_FEATURE_LEVEL_ARM_V6, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "FEATURE_LEVEL_ARM_V6_M", (void *)_cffi_const_FEATURE_LEVEL_ARM_V6_M, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "FEATURE_LEVEL_ARM_V7E_M", (void *)_cffi_const_FEATURE_LEVEL_ARM_V7E_M, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "FEATURE_LEVEL_ARM_V7_A", (void *)_cffi_const_FEATURE_LEVEL_ARM_V7_A, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "FEATURE_LEVEL_ARM_V7_M", (void *)_cffi_const_FEATURE_LEVEL_ARM_V7_M, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "FEATURE_LEVEL_ARM_V7_R", (void *)_cffi_const_FEATURE_LEVEL_ARM_V7_R, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "FEATURE_LEVEL_ARM_V8_0_A", (void *)_cffi_const_FEATURE_LEVEL_ARM_V8_0_A, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "FEATURE_LEVEL_ARM_V8_0_M", (void *)_cffi_const_FEATURE_LEVEL_ARM_V8_0_M, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "FEATURE_LEVEL_ARM_V8_0_R", (void *)_cffi_const_FEATURE_LEVEL_ARM_V8_0_R, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "FEATURE_LEVEL_ARM_V8_1_A", (void *)_cffi_const_FEATURE_LEVEL_ARM_V8_1_A, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "FEATURE_LEVEL_ARM_V8_1_M", (void *)_cffi_const_FEATURE_LEVEL_ARM_V8_1_M, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "FEATURE_LEVEL_ARM_V8_2_A", (void *)_cffi_const_FEATURE_LEVEL_ARM_V8_2_A, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "FEATURE_LEVEL_ARM_V8_3_A", (void *)_cffi_const_FEATURE_LEVEL_ARM_V8_3_A, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "FEATURE_LEVEL_ARM_V8_4_A", (void *)_cffi_const_FEATURE_LEVEL_ARM_V8_4_A, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "FEATURE_LEVEL_ARM_V8_5_A", (void *)_cffi_const_FEATURE_LEVEL_ARM_V8_5_A, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "FEATURE_LEVEL_ARM_V8_6_A", (void *)_cffi_const_FEATURE_LEVEL_ARM_V8_6_A, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "FEATURE_LEVEL_ARM_V8_7_A", (void *)_cffi_const_FEATURE_LEVEL_ARM_V8_7_A, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "FEATURE_LEVEL_ARM_V8_8_A", (void *)_cffi_const_FEATURE_LEVEL_ARM_V8_8_A, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "FEATURE_LEVEL_ARM_V8_9_A", (void *)_cffi_const_FEATURE_LEVEL_ARM_V8_9_A, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "FEATURE_LEVEL_ARM_V9_0_A", (void *)_cffi_const_FEATURE_LEVEL_ARM_V9_0_A, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "FEATURE_LEVEL_ARM_V9_1_A", (void *)_cffi_const_FEATURE_LEVEL_ARM_V9_1_A, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "FEATURE_LEVEL_ARM_V9_2_A", (void *)_cffi_const_FEATURE_LEVEL_ARM_V9_2_A, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "FEATURE_LEVEL_ARM_V9_3_A", (void *)_cffi_const_FEATURE_LEVEL_ARM_V9_3_A, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "FEATURE_LEVEL_ARM_V9_4_A", (void *)_cffi_const_FEATURE_LEVEL_ARM_V9_4_A, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "FEATURE_LEVEL_I386", (void *)_cffi_const_FEATURE_LEVEL_I386, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "FEATURE_LEVEL_I486", (void *)_cffi_const_FEATURE_LEVEL_I486, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "FEATURE_LEVEL_I586", (void *)_cffi_const_FEATURE_LEVEL_I586, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "FEATURE_LEVEL_I686", (void *)_cffi_const_FEATURE_LEVEL_I686, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "FEATURE_LEVEL_UNKNOWN", (void *)_cffi_const_FEATURE_LEVEL_UNKNOWN, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "FEATURE_LEVEL_X86_64_V1", (void *)_cffi_const_FEATURE_LEVEL_X86_64_V1, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "FEATURE_LEVEL_X86_64_V2", (void *)_cffi_const_FEATURE_LEVEL_X86_64_V2, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "FEATURE_LEVEL_X86_64_V3", (void *)_cffi_const_FEATURE_LEVEL_X86_64_V3, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "FEATURE_LEVEL_X86_64_V4", (void *)_cffi_const_FEATURE_LEVEL_X86_64_V4, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "HYPERVISOR_BHYVE", (void *)_cffi_const_HYPERVISOR_BHYVE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "HYPERVISOR_HYPERV", (void *)_cffi_const_HYPERVISOR_HYPERV, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "HYPERVISOR_KVM", (void *)_cffi_const_HYPERVISOR_KVM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "HYPERVISOR_NONE", (void *)_cffi_const_HYPERVISOR_NONE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "HYPERVISOR_PARALLELS", (void *)_cffi_const_HYPERVISOR_PARALLELS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "HYPERVISOR_QEMU", (void *)_cffi_const_HYPERVISOR_QEMU, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "HYPERVISOR_UNKNOWN", (void *)_cffi_const_HYPERVISOR_UNKNOWN, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "HYPERVISOR_VIRTUALBOX", (void *)_cffi_const_HYPERVISOR_VIRTUALBOX, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "HYPERVISOR_VMWARE", (void *)_cffi_const_HYPERVISOR_VMWARE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "HYPERVISOR_XEN", (void *)_cffi_const_HYPERVISOR_XEN, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "INFO_APERF", (void *)_cffi_const_INFO_APERF, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "INFO_BCLK", (void *)_cffi_const_INFO_BCLK, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "INFO_BUS_CLOCK", (void *)_cffi_const_INFO_BUS_CLOCK, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "INFO_CUR_MULTIPLIER", (void *)_cffi_const_INFO_CUR_MULTIPLIER, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "INFO_MAX_MULTIPLIER", (void *)_cffi_const_INFO_MAX_MULTIPLIER, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "INFO_MIN_MULTIPLIER", (void *)_cffi_const_INFO_MIN_MULTIPLIER, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "INFO_MPERF", (void *)_cffi_const_INFO_MPERF, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "INFO_TEMPERATURE", (void *)_cffi_const_INFO_TEMPERATURE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "INFO_THROTTLING", (void *)_cffi_const_INFO_THROTTLING, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "INFO_VOLTAGE", (void *)_cffi_const_INFO_VOLTAGE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "INTEL_SGX1", (void *)_cffi_const_INTEL_SGX1, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "INTEL_SGX2", (void *)_cffi_const_INTEL_SGX2, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "NUM_CPU_ARCHITECTURES", (void *)_cffi_const_NUM_CPU_ARCHITECTURES, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "NUM_CPU_FEATURES", (void *)_cffi_const_NUM_CPU_FEATURES, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "NUM_CPU_HINTS", (void *)_cffi_const_NUM_CPU_HINTS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "NUM_CPU_PURPOSES", (void *)_cffi_const_NUM_CPU_PURPOSES, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "NUM_CPU_VENDORS", (void *)_cffi_const_NUM_CPU_VENDORS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "NUM_FEATURE_LEVELS", (void *)_cffi_const_NUM_FEATURE_LEVELS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "NUM_HYPERVISOR_VENDORS", (void *)_cffi_const_NUM_HYPERVISOR_VENDORS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "NUM_REGS", (void *)_cffi_const_NUM_REGS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "NUM_SGX_FEATURES", (void *)_cffi_const_NUM_SGX_FEATURES, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PURPOSE_EFFICIENCY", (void *)_cffi_const_PURPOSE_EFFICIENCY, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PURPOSE_GENERAL", (void *)_cffi_const_PURPOSE_GENERAL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PURPOSE_LP_EFFICIENCY", (void *)_cffi_const_PURPOSE_LP_EFFICIENCY, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PURPOSE_PERFORMANCE", (void *)_cffi_const_PURPOSE_PERFORMANCE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "PURPOSE_U_PERFORMANCE", (void *)_cffi_const_PURPOSE_U_PERFORMANCE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "VENDOR_AMD", (void *)_cffi_const_VENDOR_AMD, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "VENDOR_AMPERE", (void *)_cffi_const_VENDOR_AMPERE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "VENDOR_APM", (void *)_cffi_const_VENDOR_APM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "VENDOR_APPLE", (void *)_cffi_const_VENDOR_APPLE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "VENDOR_ARM", (void *)_cffi_const_VENDOR_ARM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "VENDOR_BROADCOM", (void *)_cffi_const_VENDOR_BROADCOM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "VENDOR_CAVIUM", (void *)_cffi_const_VENDOR_CAVIUM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "VENDOR_CENTAUR", (void *)_cffi_const_VENDOR_CENTAUR, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "VENDOR_CYRIX", (void *)_cffi_const_VENDOR_CYRIX, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "VENDOR_DEC", (void *)_cffi_const_VENDOR_DEC, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "VENDOR_FARADAY", (void *)_cffi_const_VENDOR_FARADAY, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "VENDOR_FREESCALE", (void *)_cffi_const_VENDOR_FREESCALE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "VENDOR_FUJITSU", (void *)_cffi_const_VENDOR_FUJITSU, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "VENDOR_HISILICON", (void *)_cffi_const_VENDOR_HISILICON, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "VENDOR_HYGON", (void *)_cffi_const_VENDOR_HYGON, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "VENDOR_INFINEON", (void *)_cffi_const_VENDOR_INFINEON, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "VENDOR_INTEL", (void *)_cffi_const_VENDOR_INTEL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "VENDOR_MARVELL", (void *)_cffi_const_VENDOR_MARVELL, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "VENDOR_MICROSOFT", (void *)_cffi_const_VENDOR_MICROSOFT, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "VENDOR_NEXGEN", (void *)_cffi_const_VENDOR_NEXGEN, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "VENDOR_NSC", (void *)_cffi_const_VENDOR_NSC, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "VENDOR_NVIDIA", (void *)_cffi_const_VENDOR_NVIDIA, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "VENDOR_PHYTIUM", (void *)_cffi_const_VENDOR_PHYTIUM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "VENDOR_QUALCOMM", (void *)_cffi_const_VENDOR_QUALCOMM, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "VENDOR_RISE", (void *)_cffi_const_VENDOR_RISE, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "VENDOR_SAMSUNG", (void *)_cffi_const_VENDOR_SAMSUNG, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "VENDOR_SIS", (void *)_cffi_const_VENDOR_SIS, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "VENDOR_TRANSMETA", (void *)_cffi_const_VENDOR_TRANSMETA, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "VENDOR_UMC", (void *)_cffi_const_VENDOR_UMC, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "VENDOR_UNKNOWN", (void *)_cffi_const_VENDOR_UNKNOWN, _CFFI_OP(_CFFI_OP_ENUM, -1), (void *)0 },
  { "affinity_mask_str", (void *)_cffi_f_affinity_mask_str, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 0), (void *)_cffi_d_affinity_mask_str },
  { "affinity_mask_str_r", (void *)_cffi_f_affinity_mask_str_r, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 3), (void *)_cffi_d_affinity_mask_str_r },
  { "cpu_architecture_str", (void *)_cffi_f_cpu_architecture_str, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 8), (void *)_cffi_d_cpu_architecture_str },
  { "cpu_clock", (void *)_cffi_f_cpu_clock, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_N, 89), (void *)_cffi_d_cpu_clock },
  { "cpu_clock_by_ic", (void *)_cffi_f_cpu_clock_by_ic, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 33), (void *)_cffi_d_cpu_clock_by_ic },
  { "cpu_clock_by_mark", (void *)_cffi_f_cpu_clock_by_mark, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 37), (void *)_cffi_d_cpu_clock_by_mark },
  { "cpu_clock_by_os", (void *)_cffi_f_cpu_clock_by_os, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_N, 89), (void *)_cffi_d_cpu_clock_by_os },
  { "cpu_clock_by_tsc", (void *)_cffi_f_cpu_clock_by_tsc, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 51), (void *)_cffi_d_cpu_clock_by_tsc },
  { "cpu_clock_measure", (void *)_cffi_f_cpu_clock_measure, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 33), (void *)_cffi_d_cpu_clock_measure },
  { "cpu_exec_cpuid", (void *)_cffi_f_cpu_exec_cpuid, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 125), (void *)_cffi_d_cpu_exec_cpuid },
  { "cpu_exec_cpuid_ext", (void *)_cffi_f_cpu_exec_cpuid_ext, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 122), (void *)_cffi_d_cpu_exec_cpuid_ext },
  { "cpu_feature_level_str", (void *)_cffi_f_cpu_feature_level_str, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 11), (void *)_cffi_d_cpu_feature_level_str },
  { "cpu_feature_str", (void *)_cffi_f_cpu_feature_str, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 14), (void *)_cffi_d_cpu_feature_str },
  { "cpu_identify", (void *)_cffi_f_cpu_identify, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 58), (void *)_cffi_d_cpu_identify },
  { "cpu_identify_all", (void *)_cffi_f_cpu_identify_all, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 47), (void *)_cffi_d_cpu_identify_all },
  { "cpu_msr_driver_close", (void *)_cffi_f_cpu_msr_driver_close, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 66), (void *)_cffi_d_cpu_msr_driver_close },
  { "cpu_msr_driver_open", (void *)_cffi_f_cpu_msr_driver_open, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_N, 98), (void *)_cffi_d_cpu_msr_driver_open },
  { "cpu_msr_driver_open_core", (void *)_cffi_f_cpu_msr_driver_open_core, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 95), (void *)_cffi_d_cpu_msr_driver_open_core },
  { "cpu_msrinfo", (void *)_cffi_f_cpu_msrinfo, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 73), (void *)_cffi_d_cpu_msrinfo },
  { "cpu_purpose_str", (void *)_cffi_f_cpu_purpose_str, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 17), (void *)_cffi_d_cpu_purpose_str },
  { "cpu_rdmsr", (void *)_cffi_f_cpu_rdmsr, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 84), (void *)_cffi_d_cpu_rdmsr },
  { "cpu_rdmsr_range", (void *)_cffi_f_cpu_rdmsr_range, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 77), (void *)_cffi_d_cpu_rdmsr_range },
  { "cpu_rdtsc", (void *)_cffi_f_cpu_rdtsc, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 129), (void *)_cffi_d_cpu_rdtsc },
  { "cpu_request_core_type", (void *)_cffi_f_cpu_request_core_type, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 28), (void *)_cffi_d_cpu_request_core_type },
  { "cpu_tsc_mark", (void *)_cffi_f_cpu_tsc_mark, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 113), (void *)_cffi_d_cpu_tsc_mark },
  { "cpu_tsc_unmark", (void *)_cffi_f_cpu_tsc_unmark, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 113), (void *)_cffi_d_cpu_tsc_unmark },
  { "cpuid_deserialize_all_raw_data", (void *)_cffi_f_cpuid_deserialize_all_raw_data, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 43), (void *)_cffi_d_cpuid_deserialize_all_raw_data },
  { "cpuid_deserialize_raw_data", (void *)_cffi_f_cpuid_deserialize_raw_data, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 54), (void *)_cffi_d_cpuid_deserialize_raw_data },
  { "cpuid_error", (void *)_cffi_f_cpuid_error, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_N, 20), (void *)_cffi_d_cpuid_error },
  { "cpuid_free_cpu_list", (void *)_cffi_f_cpuid_free_cpu_list, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 110), (void *)_cffi_d_cpuid_free_cpu_list },
  { "cpuid_free_raw_data_array", (void *)_cffi_f_cpuid_free_raw_data_array, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 116), (void *)_cffi_d_cpuid_free_raw_data_array },
  { "cpuid_free_system_id", (void *)_cffi_f_cpuid_free_system_id, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 119), (void *)_cffi_d_cpuid_free_system_id },
  { "cpuid_get_all_raw_data", (void *)_cffi_f_cpuid_get_all_raw_data, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 40), (void *)_cffi_d_cpuid_get_all_raw_data },
  { "cpuid_get_cpu_list", (void *)_cffi_f_cpuid_get_cpu_list, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 103), (void *)_cffi_d_cpuid_get_cpu_list },
  { "cpuid_get_epc", (void *)_cffi_f_cpuid_get_epc, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 91), (void *)_cffi_d_cpuid_get_epc },
  { "cpuid_get_hypervisor", (void *)_cffi_f_cpuid_get_hypervisor, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 24), (void *)_cffi_d_cpuid_get_hypervisor },
  { "cpuid_get_raw_data", (void *)_cffi_f_cpuid_get_raw_data, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 51), (void *)_cffi_d_cpuid_get_raw_data },
  { "cpuid_get_raw_data_core", (void *)_cffi_f_cpuid_get_raw_data_core, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 62), (void *)_cffi_d_cpuid_get_raw_data_core },
  { "cpuid_get_total_cpus", (void *)_cffi_f_cpuid_get_total_cpus, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_N, 89), (void *)_cffi_d_cpuid_get_total_cpus },
  { "cpuid_get_vendor", (void *)_cffi_f_cpuid_get_vendor, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_N, 22), (void *)_cffi_d_cpuid_get_vendor },
  { "cpuid_lib_version", (void *)_cffi_f_cpuid_lib_version, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_N, 20), (void *)_cffi_d_cpuid_lib_version },
  { "cpuid_present", (void *)_cffi_f_cpuid_present, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_N, 89), (void *)_cffi_d_cpuid_present },
  { "cpuid_serialize_all_raw_data", (void *)_cffi_f_cpuid_serialize_all_raw_data, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 43), (void *)_cffi_d_cpuid_serialize_all_raw_data },
  { "cpuid_serialize_raw_data", (void *)_cffi_f_cpuid_serialize_raw_data, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 54), (void *)_cffi_d_cpuid_serialize_raw_data },
  { "cpuid_set_verbosiness_level", (void *)_cffi_f_cpuid_set_verbosiness_level, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 107), (void *)_cffi_d_cpuid_set_verbosiness_level },
  { "cpuid_set_warn_function", (void *)_cffi_f_cpuid_set_warn_function, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_O, 132), (void *)_cffi_d_cpuid_set_warn_function },
  { "msr_serialize_raw_data", (void *)_cffi_f_msr_serialize_raw_data, _CFFI_OP(_CFFI_OP_CPYTHON_BLTN_V, 69), (void *)_cffi_d_msr_serialize_raw_data },
};

static const struct _cffi_field_s _cffi_fields[] = {
  { "__val", offsetof(__fsid_t, __val),
             sizeof(((__fsid_t *)0)->__val),
             _CFFI_OP(_CFFI_OP_NOOP, 149) },
  { "__bits", offsetof(cpu_affinity_mask_t, __bits),
              sizeof(((cpu_affinity_mask_t *)0)->__bits),
              _CFFI_OP(_CFFI_OP_NOOP, 171) },
  { "implementer", offsetof(struct arm_id_t, implementer),
                   sizeof(((struct arm_id_t *)0)->implementer),
                   _CFFI_OP(_CFFI_OP_NOOP, 80) },
  { "variant", offsetof(struct arm_id_t, variant),
               sizeof(((struct arm_id_t *)0)->variant),
               _CFFI_OP(_CFFI_OP_NOOP, 80) },
  { "part_num", offsetof(struct arm_id_t, part_num),
                sizeof(((struct arm_id_t *)0)->part_num),
                _CFFI_OP(_CFFI_OP_NOOP, 64) },
  { "revision", offsetof(struct arm_id_t, revision),
                sizeof(((struct arm_id_t *)0)->revision),
                _CFFI_OP(_CFFI_OP_NOOP, 80) },
  { "start_addr", offsetof(struct cpu_epc_t, start_addr),
                  sizeof(((struct cpu_epc_t *)0)->start_addr),
                  _CFFI_OP(_CFFI_OP_NOOP, 191) },
  { "length", offsetof(struct cpu_epc_t, length),
              sizeof(((struct cpu_epc_t *)0)->length),
              _CFFI_OP(_CFFI_OP_NOOP, 191) },
  { "architecture", offsetof(struct cpu_id_t, architecture),
                    sizeof(((struct cpu_id_t *)0)->architecture),
                    _CFFI_OP(_CFFI_OP_NOOP, 9) },
  { "feature_level", offsetof(struct cpu_id_t, feature_level),
                     sizeof(((struct cpu_id_t *)0)->feature_level),
                     _CFFI_OP(_CFFI_OP_NOOP, 12) },
  { "vendor_str", offsetof(struct cpu_id_t, vendor_str),
                  sizeof(((struct cpu_id_t *)0)->vendor_str),
                  _CFFI_OP(_CFFI_OP_NOOP, 139) },
  { "brand_str", offsetof(struct cpu_id_t, brand_str),
                 sizeof(((struct cpu_id_t *)0)->brand_str),
                 _CFFI_OP(_CFFI_OP_NOOP, 141) },
  { "vendor", offsetof(struct cpu_id_t, vendor),
              sizeof(((struct cpu_id_t *)0)->vendor),
              _CFFI_OP(_CFFI_OP_NOOP, 104) },
  { "flags", offsetof(struct cpu_id_t, flags),
             sizeof(((struct cpu_id_t *)0)->flags),
             _CFFI_OP(_CFFI_OP_NOOP, 169) },
  { "family", offsetof(struct cpu_id_t, family),
              sizeof(((struct cpu_id_t *)0)->family),
              _CFFI_OP(_CFFI_OP_NOOP, 34) },
  { "model", offsetof(struct cpu_id_t, model),
             sizeof(((struct cpu_id_t *)0)->model),
             _CFFI_OP(_CFFI_OP_NOOP, 34) },
  { "stepping", offsetof(struct cpu_id_t, stepping),
                sizeof(((struct cpu_id_t *)0)->stepping),
                _CFFI_OP(_CFFI_OP_NOOP, 34) },
  { "ext_family", offsetof(struct cpu_id_t, ext_family),
                  sizeof(((struct cpu_id_t *)0)->ext_family),
                  _CFFI_OP(_CFFI_OP_NOOP, 34) },
  { "ext_model", offsetof(struct cpu_id_t, ext_model),
                 sizeof(((struct cpu_id_t *)0)->ext_model),
                 _CFFI_OP(_CFFI_OP_NOOP, 34) },
  { "x86", offsetof(struct cpu_id_t, x86),
           sizeof(((struct cpu_id_t *)0)->x86),
           _CFFI_OP(_CFFI_OP_NOOP, 164) },
  { "arm", offsetof(struct cpu_id_t, arm),
           sizeof(((struct cpu_id_t *)0)->arm),
           _CFFI_OP(_CFFI_OP_NOOP, 154) },
  { "num_cores", offsetof(struct cpu_id_t, num_cores),
                 sizeof(((struct cpu_id_t *)0)->num_cores),
                 _CFFI_OP(_CFFI_OP_NOOP, 34) },
  { "num_logical_cpus", offsetof(struct cpu_id_t, num_logical_cpus),
                        sizeof(((struct cpu_id_t *)0)->num_logical_cpus),
                        _CFFI_OP(_CFFI_OP_NOOP, 34) },
  { "total_logical_cpus", offsetof(struct cpu_id_t, total_logical_cpus),
                          sizeof(((struct cpu_id_t *)0)->total_logical_cpus),
                          _CFFI_OP(_CFFI_OP_NOOP, 34) },
  { "l1_data_cache", offsetof(struct cpu_id_t, l1_data_cache),
                     sizeof(((struct cpu_id_t *)0)->l1_data_cache),
                     _CFFI_OP(_CFFI_OP_NOOP, 34) },
  { "l1_instruction_cache", offsetof(struct cpu_id_t, l1_instruction_cache),
                            sizeof(((struct cpu_id_t *)0)->l1_instruction_cache),
                            _CFFI_OP(_CFFI_OP_NOOP, 34) },
  { "l2_cache", offsetof(struct cpu_id_t, l2_cache),
                sizeof(((struct cpu_id_t *)0)->l2_cache),
                _CFFI_OP(_CFFI_OP_NOOP, 34) },
  { "l3_cache", offsetof(struct cpu_id_t, l3_cache),
                sizeof(((struct cpu_id_t *)0)->l3_cache),
                _CFFI_OP(_CFFI_OP_NOOP, 34) },
  { "l4_cache", offsetof(struct cpu_id_t, l4_cache),
                sizeof(((struct cpu_id_t *)0)->l4_cache),
                _CFFI_OP(_CFFI_OP_NOOP, 34) },
  { "l1_assoc", offsetof(struct cpu_id_t, l1_assoc),
                sizeof(((struct cpu_id_t *)0)->l1_assoc),
                _CFFI_OP(_CFFI_OP_NOOP, 34) },
  { "l1_data_assoc", offsetof(struct cpu_id_t, l1_data_assoc),
                     sizeof(((struct cpu_id_t *)0)->l1_data_assoc),
                     _CFFI_OP(_CFFI_OP_NOOP, 34) },
  { "l1_instruction_assoc", offsetof(struct cpu_id_t, l1_instruction_assoc),
                            sizeof(((struct cpu_id_t *)0)->l1_instruction_assoc),
                            _CFFI_OP(_CFFI_OP_NOOP, 34) },
  { "l2_assoc", offsetof(struct cpu_id_t, l2_assoc),
                sizeof(((struct cpu_id_t *)0)->l2_assoc),
                _CFFI_OP(_CFFI_OP_NOOP, 34) },
  { "l3_assoc", offsetof(struct cpu_id_t, l3_assoc),
                sizeof(((struct cpu_id_t *)0)->l3_assoc),
                _CFFI_OP(_CFFI_OP_NOOP, 34) },
  { "l4_assoc", offsetof(struct cpu_id_t, l4_assoc),
                sizeof(((struct cpu_id_t *)0)->l4_assoc),
                _CFFI_OP(_CFFI_OP_NOOP, 34) },
  { "l1_cacheline", offsetof(struct cpu_id_t, l1_cacheline),
                    sizeof(((struct cpu_id_t *)0)->l1_cacheline),
                    _CFFI_OP(_CFFI_OP_NOOP, 34) },
  { "l1_data_cacheline", offsetof(struct cpu_id_t, l1_data_cacheline),
                         sizeof(((struct cpu_id_t *)0)->l1_data_cacheline),
                         _CFFI_OP(_CFFI_OP_NOOP, 34) },
  { "l1_instruction_cacheline", offsetof(struct cpu_id_t, l1_instruction_cacheline),
                                sizeof(((struct cpu_id_t *)0)->l1_instruction_cacheline),
                                _CFFI_OP(_CFFI_OP_NOOP, 34) },
  { "l2_cacheline", offsetof(struct cpu_id_t, l2_cacheline),
                    sizeof(((struct cpu_id_t *)0)->l2_cacheline),
                    _CFFI_OP(_CFFI_OP_NOOP, 34) },
  { "l3_cacheline", offsetof(struct cpu_id_t, l3_cacheline),
                    sizeof(((struct cpu_id_t *)0)->l3_cacheline),
                    _CFFI_OP(_CFFI_OP_NOOP, 34) },
  { "l4_cacheline", offsetof(struct cpu_id_t, l4_cacheline),
                    sizeof(((struct cpu_id_t *)0)->l4_cacheline),
                    _CFFI_OP(_CFFI_OP_NOOP, 34) },
  { "l1_data_instances", offsetof(struct cpu_id_t, l1_data_instances),
                         sizeof(((struct cpu_id_t *)0)->l1_data_instances),
                         _CFFI_OP(_CFFI_OP_NOOP, 34) },
  { "l1_instruction_instances", offsetof(struct cpu_id_t, l1_instruction_instances),
                                sizeof(((struct cpu_id_t *)0)->l1_instruction_instances),
                                _CFFI_OP(_CFFI_OP_NOOP, 34) },
  { "l2_instances", offsetof(struct cpu_id_t, l2_instances),
                    sizeof(((struct cpu_id_t *)0)->l2_instances),
                    _CFFI_OP(_CFFI_OP_NOOP, 34) },
  { "l3_instances", offsetof(struct cpu_id_t, l3_instances),
                    sizeof(((struct cpu_id_t *)0)->l3_instances),
                    _CFFI_OP(_CFFI_OP_NOOP, 34) },
  { "l4_instances", offsetof(struct cpu_id_t, l4_instances),
                    sizeof(((struct cpu_id_t *)0)->l4_instances),
                    _CFFI_OP(_CFFI_OP_NOOP, 34) },
  { "cpu_codename", offsetof(struct cpu_id_t, cpu_codename),
                    sizeof(((struct cpu_id_t *)0)->cpu_codename),
                    _CFFI_OP(_CFFI_OP_NOOP, 141) },
  { "sse_size", offsetof(struct cpu_id_t, sse_size),
                sizeof(((struct cpu_id_t *)0)->sse_size),
                _CFFI_OP(_CFFI_OP_NOOP, 34) },
  { "detection_hints", offsetof(struct cpu_id_t, detection_hints),
                       sizeof(((struct cpu_id_t *)0)->detection_hints),
                       _CFFI_OP(_CFFI_OP_NOOP, 167) },
  { "sgx", offsetof(struct cpu_id_t, sgx),
           sizeof(((struct cpu_id_t *)0)->sgx),
           _CFFI_OP(_CFFI_OP_NOOP, 161) },
  { "affinity_mask", offsetof(struct cpu_id_t, affinity_mask),
                     sizeof(((struct cpu_id_t *)0)->affinity_mask),
                     _CFFI_OP(_CFFI_OP_NOOP, 143) },
  { "purpose", offsetof(struct cpu_id_t, purpose),
               sizeof(((struct cpu_id_t *)0)->purpose),
               _CFFI_OP(_CFFI_OP_NOOP, 18) },
  { "num_entries", offsetof(struct cpu_list_t, num_entries),
                   sizeof(((struct cpu_list_t *)0)->num_entries),
                   _CFFI_OP(_CFFI_OP_NOOP, 34) },
  { "names", offsetof(struct cpu_list_t, names),
             sizeof(((struct cpu_list_t *)0)->names),
             _CFFI_OP(_CFFI_OP_NOOP, 137) },
  { "tsc", offsetof(struct cpu_mark_t, tsc),
           sizeof(((struct cpu_mark_t *)0)->tsc),
           _CFFI_OP(_CFFI_OP_NOOP, 191) },
  { "sys_clock", offsetof(struct cpu_mark_t, sys_clock),
                 sizeof(((struct cpu_mark_t *)0)->sys_clock),
                 _CFFI_OP(_CFFI_OP_NOOP, 191) },
  { "with_affinity", offsetof(struct cpu_raw_data_array_t, with_affinity),
                     sizeof(((struct cpu_raw_data_array_t *)0)->with_affinity),
                     _CFFI_OP(_CFFI_OP_NOOP, 135) },
  { "num_raw", offsetof(struct cpu_raw_data_array_t, num_raw),
               sizeof(((struct cpu_raw_data_array_t *)0)->num_raw),
               _CFFI_OP(_CFFI_OP_NOOP, 64) },
  { "raw", offsetof(struct cpu_raw_data_array_t, raw),
           sizeof(((struct cpu_raw_data_array_t *)0)->raw),
           _CFFI_OP(_CFFI_OP_NOOP, 25) },
  { "basic_cpuid", offsetof(struct cpu_raw_data_t, basic_cpuid),
                   sizeof(((struct cpu_raw_data_t *)0)->basic_cpuid),
                   _CFFI_OP(_CFFI_OP_NOOP, 177) },
  { "ext_cpuid", offsetof(struct cpu_raw_data_t, ext_cpuid),
                 sizeof(((struct cpu_raw_data_t *)0)->ext_cpuid),
                 _CFFI_OP(_CFFI_OP_NOOP, 177) },
  { "intel_fn4", offsetof(struct cpu_raw_data_t, intel_fn4),
                 sizeof(((struct cpu_raw_data_t *)0)->intel_fn4),
                 _CFFI_OP(_CFFI_OP_NOOP, 189) },
  { "intel_fn11", offsetof(struct cpu_raw_data_t, intel_fn11),
                  sizeof(((struct cpu_raw_data_t *)0)->intel_fn11),
                  _CFFI_OP(_CFFI_OP_NOOP, 183) },
  { "intel_fn12h", offsetof(struct cpu_raw_data_t, intel_fn12h),
                   sizeof(((struct cpu_raw_data_t *)0)->intel_fn12h),
                   _CFFI_OP(_CFFI_OP_NOOP, 183) },
  { "intel_fn14h", offsetof(struct cpu_raw_data_t, intel_fn14h),
                   sizeof(((struct cpu_raw_data_t *)0)->intel_fn14h),
                   _CFFI_OP(_CFFI_OP_NOOP, 183) },
  { "amd_fn8000001dh", offsetof(struct cpu_raw_data_t, amd_fn8000001dh),
                       sizeof(((struct cpu_raw_data_t *)0)->amd_fn8000001dh),
                       _CFFI_OP(_CFFI_OP_NOOP, 183) },
  { "amd_fn80000026h", offsetof(struct cpu_raw_data_t, amd_fn80000026h),
                       sizeof(((struct cpu_raw_data_t *)0)->amd_fn80000026h),
                       _CFFI_OP(_CFFI_OP_NOOP, 183) },
  { "arm_midr", offsetof(struct cpu_raw_data_t, arm_midr),
                sizeof(((struct cpu_raw_data_t *)0)->arm_midr),
                _CFFI_OP(_CFFI_OP_NOOP, 191) },
  { "arm_mpidr", offsetof(struct cpu_raw_data_t, arm_mpidr),
                 sizeof(((struct cpu_raw_data_t *)0)->arm_mpidr),
                 _CFFI_OP(_CFFI_OP_NOOP, 191) },
  { "arm_revidr", offsetof(struct cpu_raw_data_t, arm_revidr),
                  sizeof(((struct cpu_raw_data_t *)0)->arm_revidr),
                  _CFFI_OP(_CFFI_OP_NOOP, 191) },
  { "arm_id_afr", offsetof(struct cpu_raw_data_t, arm_id_afr),
                  sizeof(((struct cpu_raw_data_t *)0)->arm_id_afr),
                  _CFFI_OP(_CFFI_OP_NOOP, 173) },
  { "arm_id_dfr", offsetof(struct cpu_raw_data_t, arm_id_dfr),
                  sizeof(((struct cpu_raw_data_t *)0)->arm_id_dfr),
                  _CFFI_OP(_CFFI_OP_NOOP, 175) },
  { "arm_id_isar", offsetof(struct cpu_raw_data_t, arm_id_isar),
                   sizeof(((struct cpu_raw_data_t *)0)->arm_id_isar),
                   _CFFI_OP(_CFFI_OP_NOOP, 187) },
  { "arm_id_mmfr", offsetof(struct cpu_raw_data_t, arm_id_mmfr),
                   sizeof(((struct cpu_raw_data_t *)0)->arm_id_mmfr),
                   _CFFI_OP(_CFFI_OP_NOOP, 185) },
  { "arm_id_pfr", offsetof(struct cpu_raw_data_t, arm_id_pfr),
                  sizeof(((struct cpu_raw_data_t *)0)->arm_id_pfr),
                  _CFFI_OP(_CFFI_OP_NOOP, 179) },
  { "arm_id_aa64afr", offsetof(struct cpu_raw_data_t, arm_id_aa64afr),
                      sizeof(((struct cpu_raw_data_t *)0)->arm_id_aa64afr),
                      _CFFI_OP(_CFFI_OP_NOOP, 194) },
  { "arm_id_aa64dfr", offsetof(struct cpu_raw_data_t, arm_id_aa64dfr),
                      sizeof(((struct cpu_raw_data_t *)0)->arm_id_aa64dfr),
                      _CFFI_OP(_CFFI_OP_NOOP, 194) },
  { "arm_id_aa64isar", offsetof(struct cpu_raw_data_t, arm_id_aa64isar),
                       sizeof(((struct cpu_raw_data_t *)0)->arm_id_aa64isar),
                       _CFFI_OP(_CFFI_OP_NOOP, 196) },
  { "arm_id_aa64mmfr", offsetof(struct cpu_raw_data_t, arm_id_aa64mmfr),
                       sizeof(((struct cpu_raw_data_t *)0)->arm_id_aa64mmfr),
                       _CFFI_OP(_CFFI_OP_NOOP, 198) },
  { "arm_id_aa64pfr", offsetof(struct cpu_raw_data_t, arm_id_aa64pfr),
                      sizeof(((struct cpu_raw_data_t *)0)->arm_id_aa64pfr),
                      _CFFI_OP(_CFFI_OP_NOOP, 196) },
  { "arm_id_aa64smfr", offsetof(struct cpu_raw_data_t, arm_id_aa64smfr),
                       sizeof(((struct cpu_raw_data_t *)0)->arm_id_aa64smfr),
                       _CFFI_OP(_CFFI_OP_NOOP, 192) },
  { "arm_id_aa64zfr", offsetof(struct cpu_raw_data_t, arm_id_aa64zfr),
                      sizeof(((struct cpu_raw_data_t *)0)->arm_id_aa64zfr),
                      _CFFI_OP(_CFFI_OP_NOOP, 192) },
  { "present", offsetof(struct cpu_sgx_t, present),
               sizeof(((struct cpu_sgx_t *)0)->present),
               _CFFI_OP(_CFFI_OP_NOOP, 6) },
  { "max_enclave_32bit", offsetof(struct cpu_sgx_t, max_enclave_32bit),
                         sizeof(((struct cpu_sgx_t *)0)->max_enclave_32bit),
                         _CFFI_OP(_CFFI_OP_NOOP, 80) },
  { "max_enclave_64bit", offsetof(struct cpu_sgx_t, max_enclave_64bit),
                         sizeof(((struct cpu_sgx_t *)0)->max_enclave_64bit),
                         _CFFI_OP(_CFFI_OP_NOOP, 80) },
  { "flags", offsetof(struct cpu_sgx_t, flags),
             sizeof(((struct cpu_sgx_t *)0)->flags),
             _CFFI_OP(_CFFI_OP_NOOP, 165) },
  { "num_epc_sections", offsetof(struct cpu_sgx_t, num_epc_sections),
                        sizeof(((struct cpu_sgx_t *)0)->num_epc_sections),
                        _CFFI_OP(_CFFI_OP_NOOP, 34) },
  { "misc_select", offsetof(struct cpu_sgx_t, misc_select),
                   sizeof(((struct cpu_sgx_t *)0)->misc_select),
                   _CFFI_OP(_CFFI_OP_NOOP, 6) },
  { "secs_attributes", offsetof(struct cpu_sgx_t, secs_attributes),
                       sizeof(((struct cpu_sgx_t *)0)->secs_attributes),
                       _CFFI_OP(_CFFI_OP_NOOP, 191) },
  { "secs_xfrm", offsetof(struct cpu_sgx_t, secs_xfrm),
                 sizeof(((struct cpu_sgx_t *)0)->secs_xfrm),
                 _CFFI_OP(_CFFI_OP_NOOP, 191) },
  { "num_cpu_types", offsetof(struct system_id_t, num_cpu_types),
                     sizeof(((struct system_id_t *)0)->num_cpu_types),
                     _CFFI_OP(_CFFI_OP_NOOP, 80) },
  { "cpu_types", offsetof(struct system_id_t, cpu_types),
                 sizeof(((struct system_id_t *)0)->cpu_types),
                 _CFFI_OP(_CFFI_OP_NOOP, 26) },
  { "l1_data_total_instances", offsetof(struct system_id_t, l1_data_total_instances),
                               sizeof(((struct system_id_t *)0)->l1_data_total_instances),
                               _CFFI_OP(_CFFI_OP_NOOP, 34) },
  { "l1_instruction_total_instances", offsetof(struct system_id_t, l1_instruction_total_instances),
                                      sizeof(((struct system_id_t *)0)->l1_instruction_total_instances),
                                      _CFFI_OP(_CFFI_OP_NOOP, 34) },
  { "l2_total_instances", offsetof(struct system_id_t, l2_total_instances),
                          sizeof(((struct system_id_t *)0)->l2_total_instances),
                          _CFFI_OP(_CFFI_OP_NOOP, 34) },
  { "l3_total_instances", offsetof(struct system_id_t, l3_total_instances),
                          sizeof(((struct system_id_t *)0)->l3_total_instances),
                          _CFFI_OP(_CFFI_OP_NOOP, 34) },
  { "l4_total_instances", offsetof(struct system_id_t, l4_total_instances),
                          sizeof(((struct system_id_t *)0)->l4_total_instances),
                          _CFFI_OP(_CFFI_OP_NOOP, 34) },
  { "family", offsetof(struct x86_id_t, family),
              sizeof(((struct x86_id_t *)0)->family),
              _CFFI_OP(_CFFI_OP_NOOP, 34) },
  { "model", offsetof(struct x86_id_t, model),
             sizeof(((struct x86_id_t *)0)->model),
             _CFFI_OP(_CFFI_OP_NOOP, 34) },
  { "stepping", offsetof(struct x86_id_t, stepping),
                sizeof(((struct x86_id_t *)0)->stepping),
                _CFFI_OP(_CFFI_OP_NOOP, 34) },
  { "ext_family", offsetof(struct x86_id_t, ext_family),
                  sizeof(((struct x86_id_t *)0)->ext_family),
                  _CFFI_OP(_CFFI_OP_NOOP, 34) },
  { "ext_model", offsetof(struct x86_id_t, ext_model),
                 sizeof(((struct x86_id_t *)0)->ext_model),
                 _CFFI_OP(_CFFI_OP_NOOP, 34) },
  { "sse_size", offsetof(struct x86_id_t, sse_size),
                sizeof(((struct x86_id_t *)0)->sse_size),
                _CFFI_OP(_CFFI_OP_NOOP, 34) },
  { "sgx", offsetof(struct x86_id_t, sgx),
           sizeof(((struct x86_id_t *)0)->sgx),
           _CFFI_OP(_CFFI_OP_NOOP, 161) },
};

static const struct _cffi_struct_union_s _cffi_struct_unions[] = {
  { "$__fsid_t", 136, _CFFI_F_CHECK_FIELDS,
    sizeof(__fsid_t), offsetof(struct _cffi_align_typedef___fsid_t, y), 0, 1 },
  { "$cpu_affinity_mask_t", 143, _CFFI_F_CHECK_FIELDS,
    sizeof(cpu_affinity_mask_t), offsetof(struct _cffi_align_typedef_cpu_affinity_mask_t, y), 1, 1 },
  { "arm_id_t", 154, _CFFI_F_CHECK_FIELDS,
    sizeof(struct arm_id_t), offsetof(struct _cffi_align_struct_arm_id_t, y), 2, 4 },
  { "cpu_epc_t", 155, _CFFI_F_CHECK_FIELDS,
    sizeof(struct cpu_epc_t), offsetof(struct _cffi_align_struct_cpu_epc_t, y), 6, 2 },
  { "cpu_id_t", 156, 0,
    sizeof(struct cpu_id_t), offsetof(struct _cffi_align_struct_cpu_id_t, y), 8, 44 },
  { "cpu_list_t", 157, _CFFI_F_CHECK_FIELDS,
    sizeof(struct cpu_list_t), offsetof(struct _cffi_align_struct_cpu_list_t, y), 52, 2 },
  { "cpu_mark_t", 158, _CFFI_F_CHECK_FIELDS,
    sizeof(struct cpu_mark_t), offsetof(struct _cffi_align_struct_cpu_mark_t, y), 54, 2 },
  { "cpu_raw_data_array_t", 159, _CFFI_F_CHECK_FIELDS,
    sizeof(struct cpu_raw_data_array_t), offsetof(struct _cffi_align_struct_cpu_raw_data_array_t, y), 56, 3 },
  { "cpu_raw_data_t", 160, _CFFI_F_CHECK_FIELDS,
    sizeof(struct cpu_raw_data_t), offsetof(struct _cffi_align_struct_cpu_raw_data_t, y), 59, 23 },
  { "cpu_sgx_t", 161, _CFFI_F_CHECK_FIELDS,
    sizeof(struct cpu_sgx_t), offsetof(struct _cffi_align_struct_cpu_sgx_t, y), 82, 8 },
  { "msr_driver_t", 162, _CFFI_F_OPAQUE,
    (size_t)-1, -1, -1, 0 /* opaque */ },
  { "system_id_t", 163, _CFFI_F_CHECK_FIELDS,
    sizeof(struct system_id_t), offsetof(struct _cffi_align_struct_system_id_t, y), 90, 7 },
  { "x86_id_t", 164, _CFFI_F_CHECK_FIELDS,
    sizeof(struct x86_id_t), offsetof(struct _cffi_align_struct_x86_id_t, y), 97, 7 },
};

static const struct _cffi_enum_s _cffi_enums[] = {
  { "$cpu_architecture_t", 9, _cffi_prim_int(sizeof(cpu_architecture_t), ((cpu_architecture_t)-1) <= 0),
    "ARCHITECTURE_X86,ARCHITECTURE_ARM,NUM_CPU_ARCHITECTURES,ARCHITECTURE_UNKNOWN" },
  { "$cpu_error_t", 144, _cffi_prim_int(sizeof(cpu_error_t), ((cpu_error_t)-1) <= 0),
    "ERR_OK,ERR_NO_CPUID,ERR_NO_RDTSC,ERR_NO_MEM,ERR_OPEN,ERR_BADFMT,ERR_NOT_IMP,ERR_CPU_UNKN,ERR_NO_RDMSR,ERR_NO_DRIVER,ERR_NO_PERMS,ERR_EXTRACT,ERR_HANDLE,ERR_INVMSR,ERR_INVCNB,ERR_HANDLE_R,ERR_INVRANGE,ERR_NOT_FOUND,ERR_IOCTL,ERR_REQUEST" },
  { "$cpu_feature_level_t", 12, _cffi_prim_int(sizeof(cpu_feature_level_t), ((cpu_feature_level_t)-1) <= 0),
    "FEATURE_LEVEL_I386,FEATURE_LEVEL_I486,FEATURE_LEVEL_I586,FEATURE_LEVEL_I686,FEATURE_LEVEL_X86_64_V1,FEATURE_LEVEL_X86_64_V2,FEATURE_LEVEL_X86_64_V3,FEATURE_LEVEL_X86_64_V4,FEATURE_LEVEL_ARM_V1,FEATURE_LEVEL_ARM_V2,FEATURE_LEVEL_ARM_V3,FEATURE_LEVEL_ARM_V4,FEATURE_LEVEL_ARM_V4T,FEATURE_LEVEL_ARM_V5,FEATURE_LEVEL_ARM_V5T,FEATURE_LEVEL_ARM_V5TE,FEATURE_LEVEL_ARM_V5TEJ,FEATURE_LEVEL_ARM_V6,FEATURE_LEVEL_ARM_V6_M,FEATURE_LEVEL_ARM_V7_A,FEATURE_LEVEL_ARM_V7_M,FEATURE_LEVEL_ARM_V7_R,FEATURE_LEVEL_ARM_V7E_M,FEATURE_LEVEL_ARM_V8_0_A,FEATURE_LEVEL_ARM_V8_0_M,FEATURE_LEVEL_ARM_V8_0_R,FEATURE_LEVEL_ARM_V8_1_A,FEATURE_LEVEL_ARM_V8_1_M,FEATURE_LEVEL_ARM_V8_2_A,FEATURE_LEVEL_ARM_V8_3_A,FEATURE_LEVEL_ARM_V8_4_A,FEATURE_LEVEL_ARM_V8_5_A,FEATURE_LEVEL_ARM_V8_6_A,FEATURE_LEVEL_ARM_V8_7_A,FEATURE_LEVEL_ARM_V8_8_A,FEATURE_LEVEL_ARM_V8_9_A,FEATURE_LEVEL_ARM_V9_0_A,FEATURE_LEVEL_ARM_V9_1_A,FEATURE_LEVEL_ARM_V9_2_A,FEATURE_LEVEL_ARM_V9_3_A,FEATURE_LEVEL_ARM_V9_4_A,NUM_FEATURE_LEVELS,FEATURE_LEVEL_UNKNOWN" },
  { "$cpu_feature_t", 15, _cffi_prim_int(sizeof(cpu_feature_t), ((cpu_feature_t)-1) <= 0),
    "CPU_FEATURE_FPU,CPU_FEATURE_VME,CPU_FEATURE_DE,CPU_FEATURE_PSE,CPU_FEATURE_TSC,CPU_FEATURE_MSR,CPU_FEATURE_PAE,CPU_FEATURE_MCE,CPU_FEATURE_CX8,CPU_FEATURE_APIC,CPU_FEATURE_MTRR,CPU_FEATURE_SEP,CPU_FEATURE_PGE,CPU_FEATURE_MCA,CPU_FEATURE_CMOV,CPU_FEATURE_PAT,CPU_FEATURE_PSE36,CPU_FEATURE_PN,CPU_FEATURE_CLFLUSH,CPU_FEATURE_DTS,CPU_FEATURE_ACPI,CPU_FEATURE_MMX,CPU_FEATURE_FXSR,CPU_FEATURE_SSE,CPU_FEATURE_SSE2,CPU_FEATURE_SS,CPU_FEATURE_HT,CPU_FEATURE_TM,CPU_FEATURE_IA64,CPU_FEATURE_PBE,CPU_FEATURE_PNI,CPU_FEATURE_PCLMUL,CPU_FEATURE_DTS64,CPU_FEATURE_MONITOR,CPU_FEATURE_DS_CPL,CPU_FEATURE_VMX,CPU_FEATURE_SMX,CPU_FEATURE_EST,CPU_FEATURE_TM2,CPU_FEATURE_SSSE3,CPU_FEATURE_CID,CPU_FEATURE_CX16,CPU_FEATURE_XTPR,CPU_FEATURE_PDCM,CPU_FEATURE_DCA,CPU_FEATURE_SSE4_1,CPU_FEATURE_SSE4_2,CPU_FEATURE_SYSCALL,CPU_FEATURE_XD,CPU_FEATURE_MOVBE,CPU_FEATURE_POPCNT,CPU_FEATURE_AES,CPU_FEATURE_XSAVE,CPU_FEATURE_OSXSAVE,CPU_FEATURE_AVX,CPU_FEATURE_MMXEXT,CPU_FEATURE_3DNOW,CPU_FEATURE_3DNOWEXT,CPU_FEATURE_NX,CPU_FEATURE_FXSR_OPT,CPU_FEATURE_RDTSCP,CPU_FEATURE_LM,CPU_FEATURE_LAHF_LM,CPU_FEATURE_CMP_LEGACY,CPU_FEATURE_SVM,CPU_FEATURE_ABM,CPU_FEATURE_MISALIGNSSE,CPU_FEATURE_SSE4A,CPU_FEATURE_3DNOWPREFETCH,CPU_FEATURE_OSVW,CPU_FEATURE_IBS,CPU_FEATURE_SSE5,CPU_FEATURE_SKINIT,CPU_FEATURE_WDT,CPU_FEATURE_TS,CPU_FEATURE_FID,CPU_FEATURE_VID,CPU_FEATURE_TTP,CPU_FEATURE_TM_AMD,CPU_FEATURE_STC,CPU_FEATURE_100MHZSTEPS,CPU_FEATURE_HWPSTATE,CPU_FEATURE_CONSTANT_TSC,CPU_FEATURE_XOP,CPU_FEATURE_FMA3,CPU_FEATURE_FMA4,CPU_FEATURE_TBM,CPU_FEATURE_F16C,CPU_FEATURE_RDRAND,CPU_FEATURE_X2APIC,CPU_FEATURE_CPB,CPU_FEATURE_APERFMPERF,CPU_FEATURE_PFI,CPU_FEATURE_PA,CPU_FEATURE_AVX2,CPU_FEATURE_BMI1,CPU_FEATURE_BMI2,CPU_FEATURE_HLE,CPU_FEATURE_RTM,CPU_FEATURE_AVX512F,CPU_FEATURE_AVX512DQ,CPU_FEATURE_AVX512PF,CPU_FEATURE_AVX512ER,CPU_FEATURE_AVX512CD,CPU_FEATURE_SHA_NI,CPU_FEATURE_AVX512BW,CPU_FEATURE_AVX512VL,CPU_FEATURE_SGX,CPU_FEATURE_RDSEED,CPU_FEATURE_ADX,CPU_FEATURE_AVX512VNNI,CPU_FEATURE_AVX512VBMI,CPU_FEATURE_AVX512VBMI2,CPU_FEATURE_HYPERVISOR,CPU_FEATURE_SWAP,CPU_FEATURE_THUMB,CPU_FEATURE_ADVMULTU,CPU_FEATURE_ADVMULTS,CPU_FEATURE_JAZELLE,CPU_FEATURE_DEBUGV6,CPU_FEATURE_DEBUGV6P1,CPU_FEATURE_THUMB2,CPU_FEATURE_DEBUGV7,CPU_FEATURE_DEBUGV7P1,CPU_FEATURE_THUMBEE,CPU_FEATURE_DIVIDE,CPU_FEATURE_LPAE,CPU_FEATURE_PMUV1,CPU_FEATURE_PMUV2,CPU_FEATURE_ASID16,CPU_FEATURE_ADVSIMD,CPU_FEATURE_CRC32,CPU_FEATURE_CSV2_1P1,CPU_FEATURE_CSV2_1P2,CPU_FEATURE_CSV2_2,CPU_FEATURE_CSV2_3,CPU_FEATURE_DOUBLELOCK,CPU_FEATURE_ETS2,CPU_FEATURE_FP,CPU_FEATURE_MIXEDEND,CPU_FEATURE_MIXEDENDEL0,CPU_FEATURE_PMULL,CPU_FEATURE_PMUV3,CPU_FEATURE_SHA1,CPU_FEATURE_SHA256,CPU_FEATURE_NTLBPA,CPU_FEATURE_HAFDBS,CPU_FEATURE_HPDS,CPU_FEATURE_LOR,CPU_FEATURE_LSE,CPU_FEATURE_PAN,CPU_FEATURE_PMUV3P1,CPU_FEATURE_RDM,CPU_FEATURE_VHE,CPU_FEATURE_VMID16,CPU_FEATURE_AA32HPD,CPU_FEATURE_AA32I8MM,CPU_FEATURE_DPB,CPU_FEATURE_DEBUGV8P2,CPU_FEATURE_F32MM,CPU_FEATURE_F64MM,CPU_FEATURE_FP16,CPU_FEATURE_HPDS2,CPU_FEATURE_I8MM,CPU_FEATURE_IESB,CPU_FEATURE_LPA,CPU_FEATURE_LSMAOC,CPU_FEATURE_LVA,CPU_FEATURE_PAN2,CPU_FEATURE_RAS,CPU_FEATURE_SHA3,CPU_FEATURE_SHA512,CPU_FEATURE_SM3,CPU_FEATURE_SM4,CPU_FEATURE_SPE,CPU_FEATURE_SVE,CPU_FEATURE_TTCNP,CPU_FEATURE_UAO,CPU_FEATURE_XNX,CPU_FEATURE_CCIDX,CPU_FEATURE_CONSTPACFIELD,CPU_FEATURE_EPAC,CPU_FEATURE_FCMA,CPU_FEATURE_FPAC,CPU_FEATURE_FPACCOMBINE,CPU_FEATURE_JSCVT,CPU_FEATURE_LRCPC,CPU_FEATURE_PACIMP,CPU_FEATURE_PACQARMA3,CPU_FEATURE_PACQARMA5,CPU_FEATURE_PAUTH,CPU_FEATURE_SPEV1P1,CPU_FEATURE_AMUV1,CPU_FEATURE_BBM,CPU_FEATURE_DIT,CPU_FEATURE_DEBUGV8P4,CPU_FEATURE_DOTPROD,CPU_FEATURE_DOUBLEFAULT,CPU_FEATURE_FHM,CPU_FEATURE_FLAGM,CPU_FEATURE_IDST,CPU_FEATURE_LRCPC2,CPU_FEATURE_LSE2,CPU_FEATURE_MPAM,CPU_FEATURE_PMUV3P4,CPU_FEATURE_RASV1P1,CPU_FEATURE_S2FWB,CPU_FEATURE_SEL2,CPU_FEATURE_TLBIOS,CPU_FEATURE_TLBIRANGE,CPU_FEATURE_TRF,CPU_FEATURE_TTL,CPU_FEATURE_TTST,CPU_FEATURE_BTI,CPU_FEATURE_CSV2,CPU_FEATURE_CSV3,CPU_FEATURE_DPB2,CPU_FEATURE_E0PD,CPU_FEATURE_EVT,CPU_FEATURE_EXS,CPU_FEATURE_FRINTTS,CPU_FEATURE_FLAGM2,CPU_FEATURE_MTE,CPU_FEATURE_MTE2,CPU_FEATURE_PMUV3P5,CPU_FEATURE_RNG,CPU_FEATURE_RNG_TRAP,CPU_FEATURE_SB,CPU_FEATURE_SPECRES,CPU_FEATURE_SSBS,CPU_FEATURE_SSBS2,CPU_FEATURE_AA32BF16,CPU_FEATURE_AMUV1P1,CPU_FEATURE_BF16,CPU_FEATURE_DGH,CPU_FEATURE_ECV,CPU_FEATURE_FGT,CPU_FEATURE_HPMN0,CPU_FEATURE_MPAMV0P1,CPU_FEATURE_MPAMV1P1,CPU_FEATURE_MTPMU,CPU_FEATURE_PAUTH2,CPU_FEATURE_TWED,CPU_FEATURE_AFP,CPU_FEATURE_EBF16,CPU_FEATURE_HCX,CPU_FEATURE_LPA2,CPU_FEATURE_LS64,CPU_FEATURE_LS64_ACCDATA,CPU_FEATURE_LS64_V,CPU_FEATURE_MTE3,CPU_FEATURE_MTE_ASYM_FAULT,CPU_FEATURE_PAN3,CPU_FEATURE_PMUV3P7,CPU_FEATURE_RPRES,CPU_FEATURE_SPEV1P2,CPU_FEATURE_WFXT,CPU_FEATURE_XS,CPU_FEATURE_CMOW,CPU_FEATURE_DEBUGV8P8,CPU_FEATURE_HBC,CPU_FEATURE_MOPS,CPU_FEATURE_NMI,CPU_FEATURE_PMUV3P8,CPU_FEATURE_SCTLR2,CPU_FEATURE_SPEV1P3,CPU_FEATURE_TCR2,CPU_FEATURE_TIDCP1,CPU_FEATURE_ADERR,CPU_FEATURE_AIE,CPU_FEATURE_ANERR,CPU_FEATURE_ATS1A,CPU_FEATURE_CLRBHB,CPU_FEATURE_CSSC,CPU_FEATURE_DEBUGV8P9,CPU_FEATURE_DOUBLEFAULT2,CPU_FEATURE_ECBHB,CPU_FEATURE_FGT2,CPU_FEATURE_HAFT,CPU_FEATURE_LRCPC3,CPU_FEATURE_MTE4,CPU_FEATURE_MTE_ASYNC,CPU_FEATURE_MTE_CANONICAL_TAGS,CPU_FEATURE_MTE_NO_ADDRESS_TAGS,CPU_FEATURE_MTE_PERM,CPU_FEATURE_MTE_STORE_ONLY,CPU_FEATURE_MTE_TAGGED_FAR,CPU_FEATURE_PFAR,CPU_FEATURE_PMUV3_ICNTR,CPU_FEATURE_PMUV3_SS,CPU_FEATURE_PMUV3P9,CPU_FEATURE_PRFMSLC,CPU_FEATURE_RASV2,CPU_FEATURE_RPRFM,CPU_FEATURE_S1PIE,CPU_FEATURE_S1POE,CPU_FEATURE_S2PIE,CPU_FEATURE_S2POE,CPU_FEATURE_SPECRES2,CPU_FEATURE_SPE_DPFZS,CPU_FEATURE_SPEV1P4,CPU_FEATURE_SPMU,CPU_FEATURE_THE,CPU_FEATURE_SVE2,CPU_FEATURE_SVE_AES,CPU_FEATURE_SVE_BITPERM,CPU_FEATURE_SVE_PMULL128,CPU_FEATURE_SVE_SHA3,CPU_FEATURE_SVE_SM4,CPU_FEATURE_TME,CPU_FEATURE_TRBE,CPU_FEATURE_BRBE,CPU_FEATURE_RME,CPU_FEATURE_SME,CPU_FEATURE_SME_F64F64,CPU_FEATURE_SME_FA64,CPU_FEATURE_SME_I16I64,CPU_FEATURE_BRBEV1P1,CPU_FEATURE_MEC,CPU_FEATURE_SME2,CPU_FEATURE_ABLE,CPU_FEATURE_BWE,CPU_FEATURE_D128,CPU_FEATURE_EBEP,CPU_FEATURE_GCS,CPU_FEATURE_ITE,CPU_FEATURE_LSE128,CPU_FEATURE_LVA3,CPU_FEATURE_SEBEP,CPU_FEATURE_SME2P1,CPU_FEATURE_SME_F16F16,CPU_FEATURE_SVE2P1,CPU_FEATURE_SVE_B16B16,CPU_FEATURE_SYSINSTR128,CPU_FEATURE_SYSREG128,CPU_FEATURE_TRBE_EXT,NUM_CPU_FEATURES" },
  { "$cpu_hint_t", 145, _cffi_prim_int(sizeof(cpu_hint_t), ((cpu_hint_t)-1) <= 0),
    "CPU_HINT_SSE_SIZE_AUTH,NUM_CPU_HINTS" },
  { "$cpu_msrinfo_request_t", 75, _cffi_prim_int(sizeof(cpu_msrinfo_request_t), ((cpu_msrinfo_request_t)-1) <= 0),
    "INFO_MPERF,INFO_APERF,INFO_MIN_MULTIPLIER,INFO_CUR_MULTIPLIER,INFO_MAX_MULTIPLIER,INFO_TEMPERATURE,INFO_THROTTLING,INFO_VOLTAGE,INFO_BCLK,INFO_BUS_CLOCK" },
  { "$cpu_purpose_t", 18, _cffi_prim_int(sizeof(cpu_purpose_t), ((cpu_purpose_t)-1) <= 0),
    "PURPOSE_GENERAL,PURPOSE_PERFORMANCE,PURPOSE_EFFICIENCY,PURPOSE_LP_EFFICIENCY,PURPOSE_U_PERFORMANCE,NUM_CPU_PURPOSES" },
  { "$cpu_registers_t", 146, _cffi_prim_int(sizeof(cpu_registers_t), ((cpu_registers_t)-1) <= 0),
    "EAX,EBX,ECX,EDX,NUM_REGS" },
  { "$cpu_sgx_feature_t", 147, _cffi_prim_int(sizeof(cpu_sgx_feature_t), ((cpu_sgx_feature_t)-1) <= 0),
    "INTEL_SGX1,INTEL_SGX2,NUM_SGX_FEATURES" },
  { "$cpu_vendor_t", 104, _cffi_prim_int(sizeof(cpu_vendor_t), ((cpu_vendor_t)-1) <= 0),
    "VENDOR_INTEL,VENDOR_AMD,VENDOR_CYRIX,VENDOR_NEXGEN,VENDOR_TRANSMETA,VENDOR_UMC,VENDOR_CENTAUR,VENDOR_RISE,VENDOR_SIS,VENDOR_NSC,VENDOR_HYGON,VENDOR_ARM,VENDOR_BROADCOM,VENDOR_CAVIUM,VENDOR_DEC,VENDOR_FUJITSU,VENDOR_HISILICON,VENDOR_INFINEON,VENDOR_FREESCALE,VENDOR_NVIDIA,VENDOR_APM,VENDOR_QUALCOMM,VENDOR_SAMSUNG,VENDOR_MARVELL,VENDOR_APPLE,VENDOR_FARADAY,VENDOR_MICROSOFT,VENDOR_PHYTIUM,VENDOR_AMPERE,NUM_CPU_VENDORS,VENDOR_UNKNOWN" },
  { "$hypervisor_vendor_t", 148, _cffi_prim_int(sizeof(hypervisor_vendor_t), ((hypervisor_vendor_t)-1) <= 0),
    "HYPERVISOR_NONE,HYPERVISOR_BHYVE,HYPERVISOR_HYPERV,HYPERVISOR_KVM,HYPERVISOR_PARALLELS,HYPERVISOR_QEMU,HYPERVISOR_VIRTUALBOX,HYPERVISOR_VMWARE,HYPERVISOR_XEN,NUM_HYPERVISOR_VENDORS,HYPERVISOR_UNKNOWN" },
};

static const struct _cffi_typename_s _cffi_typenames[] = {
  { "__blkcnt64_t", 151 },
  { "__blkcnt_t", 151 },
  { "__blksize_t", 151 },
  { "__caddr_t", 5 },
  { "__clock_t", 151 },
  { "__clockid_t", 34 },
  { "__daddr_t", 34 },
  { "__dev_t", 191 },
  { "__fsblkcnt64_t", 191 },
  { "__fsblkcnt_t", 191 },
  { "__fsfilcnt64_t", 191 },
  { "__fsfilcnt_t", 191 },
  { "__fsid_t", 136 },
  { "__fsword_t", 151 },
  { "__gid_t", 6 },
  { "__id_t", 6 },
  { "__ino64_t", 191 },
  { "__ino_t", 191 },
  { "__int16_t", 152 },
  { "__int32_t", 34 },
  { "__int64_t", 151 },
  { "__int8_t", 153 },
  { "__int_least16_t", 152 },
  { "__int_least32_t", 34 },
  { "__int_least64_t", 151 },
  { "__int_least8_t", 153 },
  { "__intmax_t", 151 },
  { "__intptr_t", 151 },
  { "__key_t", 34 },
  { "__loff_t", 151 },
  { "__mode_t", 6 },
  { "__nlink_t", 191 },
  { "__off64_t", 151 },
  { "__off_t", 151 },
  { "__pid_t", 34 },
  { "__quad_t", 151 },
  { "__rlim64_t", 191 },
  { "__rlim_t", 191 },
  { "__sig_atomic_t", 34 },
  { "__socklen_t", 6 },
  { "__ssize_t", 151 },
  { "__suseconds64_t", 151 },
  { "__suseconds_t", 151 },
  { "__syscall_slong_t", 151 },
  { "__syscall_ulong_t", 191 },
  { "__time_t", 151 },
  { "__timer_t", 200 },
  { "__u_char", 80 },
  { "__u_int", 6 },
  { "__u_long", 191 },
  { "__u_quad_t", 191 },
  { "__u_short", 64 },
  { "__uid_t", 6 },
  { "__uint16_t", 64 },
  { "__uint32_t", 6 },
  { "__uint64_t", 191 },
  { "__uint8_t", 80 },
  { "__uint_least16_t", 64 },
  { "__uint_least32_t", 6 },
  { "__uint_least64_t", 191 },
  { "__uint_least8_t", 80 },
  { "__uintmax_t", 191 },
  { "__useconds_t", 6 },
  { "cpu_affinity_mask_t", 143 },
  { "cpu_architecture_t", 9 },
  { "cpu_error_t", 144 },
  { "cpu_feature_level_t", 12 },
  { "cpu_feature_t", 15 },
  { "cpu_hint_t", 145 },
  { "cpu_msrinfo_request_t", 75 },
  { "cpu_purpose_t", 18 },
  { "cpu_registers_t", 146 },
  { "cpu_sgx_feature_t", 147 },
  { "cpu_vendor_t", 104 },
  { "hypervisor_vendor_t", 148 },
  { "int16_t", 152 },
  { "int32_t", 34 },
  { "int64_t", 151 },
  { "int8_t", 153 },
  { "int_fast16_t", 151 },
  { "int_fast32_t", 151 },
  { "int_fast64_t", 151 },
  { "int_fast8_t", 153 },
  { "int_least16_t", 152 },
  { "int_least32_t", 34 },
  { "int_least64_t", 151 },
  { "int_least8_t", 153 },
  { "intmax_t", 151 },
  { "intptr_t", 151 },
  { "libcpuid_warn_fn_t", 133 },
  { "logical_cpu_t", 64 },
  { "uint16_t", 64 },
  { "uint32_t", 6 },
  { "uint64_t", 191 },
  { "uint8_t", 80 },
  { "uint_fast16_t", 191 },
  { "uint_fast32_t", 191 },
  { "uint_fast64_t", 191 },
  { "uint_fast8_t", 80 },
  { "uint_least16_t", 64 },
  { "uint_least32_t", 6 },
  { "uint_least64_t", 191 },
  { "uint_least8_t", 80 },
  { "uintmax_t", 191 },
  { "uintptr_t", 191 },
};

static const struct _cffi_type_context_s _cffi_type_context = {
  _cffi_types,
  _cffi_globals,
  _cffi_fields,
  _cffi_struct_unions,
  _cffi_enums,
  _cffi_typenames,
  519,  /* num_globals */
  13,  /* num_struct_unions */
  11,  /* num_enums */
  105,  /* num_typenames */
  NULL,  /* no includes */
  202,  /* num_types */
  0,  /* flags */
};

#ifdef __GNUC__
#  pragma GCC visibility push(default)  /* for -fvisibility= */
#endif

#ifdef PYPY_VERSION
PyMODINIT_FUNC
_cffi_pypyinit__libcpuid_cffi(const void *p[])
{
    p[0] = (const void *)0x2601;
    p[1] = &_cffi_type_context;
#if PY_MAJOR_VERSION >= 3
    return NULL;
#endif
}
#  ifdef _MSC_VER
     PyMODINIT_FUNC
#  if PY_MAJOR_VERSION >= 3
     PyInit__libcpuid_cffi(void) { return NULL; }
#  else
     init_libcpuid_cffi(void) { }
#  endif
#  endif
#elif PY_MAJOR_VERSION >= 3
PyMODINIT_FUNC
PyInit__libcpuid_cffi(void)
{
  return _cffi_init("libcpuid._libcpuid_cffi", 0x2601, &_cffi_type_context);
}
#else
PyMODINIT_FUNC
init_libcpuid_cffi(void)
{
  _cffi_init("libcpuid._libcpuid_cffi", 0x2601, &_cffi_type_context);
}
#endif

#ifdef __GNUC__
#  pragma GCC visibility pop
#endif
